<?xml version="1.0" encoding="UTF-8"?>
<!-- Dieses Stylesheet erzeugt aus jeweils einem TEI/XML-Reisebericht eine XHTML-Datei für die EPUB-Ausgabe (siehe <https://git.hab.de/iglesia/kommentierte-digitale-edition-der-reise-und-sammlungsbeschreibungen-philipp-hainhofers-dokumentation/-/wikis/EPUB>). -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:tei="http://www.tei-c.org/ns/1.0"
    xmlns:html="http://www.w3.org/1999/xhtml"
    exclude-result-prefixes="html tei xs"
    version="2.0">
    
    <xsl:output method="xhtml" indent="yes"/>
    
    <xsl:strip-space elements="tei:lem tei:div"/>
    
    <xsl:template match="/">
        
        <xsl:variable name="title" select="//tei:title"/>
        <xsl:result-document href="{replace(translate(replace(lower-case($title),'ü','ue'),'/– ',''),'ä','ae')}.xhtml" encoding="UTF-8">     
            <html xmlns="http://www.w3.org/1999/xhtml">
                <head>
                    <title><xsl:value-of select="$title"/></title>
                    <link type="text/css" rel="stylesheet" href="stylesheet.css" />
                </head>            
                <body xmlns="http://www.w3.org/1999/xhtml">            
                    <h1>
                        <xsl:value-of select="$title"/>
                    </h1>                    
                    <xsl:apply-templates select="//tei:body"/>                    
                </body>
            </html>
        </xsl:result-document>
    </xsl:template>
    
    <xsl:template match="tei:abbr"/>
    
    <xsl:template match="tei:add">
        <xsl:text> &lt;</xsl:text>
        <xsl:apply-templates/>
        <xsl:text>&gt; </xsl:text>
    </xsl:template>
    
    <xsl:template match="tei:corr"/>
    
    <xsl:template match="tei:div">
        <xsl:apply-templates/>
        <xsl:text>&#x0A;</xsl:text>
    </xsl:template>
    
    <!-- Kursivierung stört womöglich den Lesefluss: -->
    <!--<xsl:template match="tei:ex">
        <span xmlns="http://www.w3.org/1999/xhtml" class="expansion">
        <xsl:apply-templates/>
        </span>
        </xsl:template>-->
    
    <!-- Nicht sinnvoll, da die Schriftart Client-seitig überschrieben werden kann: -->
    <!--<xsl:template match="tei:hi[@rendition = '#aq']">
        <span xmlns="http://www.w3.org/1999/xhtml" class="latinletters">
        <xsl:apply-templates/>
        </span>
        </xsl:template>-->
    
    <xsl:template match="tei:hi[@rendition eq '#s']"/>
    
    <xsl:template match="tei:lb">
        <xsl:choose>
            <xsl:when test="ends-with(preceding::text()[1],'-')"/>
            <xsl:otherwise><xsl:text> </xsl:text></xsl:otherwise>
        </xsl:choose>        
    </xsl:template>
 
    <xsl:template match="tei:note"/>
    
    <xsl:template match="tei:p">
        <div xmlns="http://www.w3.org/1999/xhtml" class="p">
            <xsl:for-each select="tei:note[@type='contemporary']">
                <h2 class="marginnote">
                    <xsl:apply-templates/>
                </h2>   
            </xsl:for-each>
            <xsl:apply-templates/>         
        </div>
    </xsl:template> 
    
    <xsl:template match="tei:pb">
        <xsl:choose>
            <xsl:when test="ends-with(preceding::text()[1],'-')"/>
            <xsl:otherwise><xsl:text> </xsl:text></xsl:otherwise>
        </xsl:choose>        
    </xsl:template>
    
    <xsl:template match="tei:rdg"/>
    
    <xsl:template match="text()">        
        <xsl:value-of select="replace(., '\s+', ' ')"/>
    </xsl:template>
    
    <xsl:template match="text()">       
        <xsl:value-of select="replace(replace(.,'-$',''), '\s+', ' ')"/>
    </xsl:template>
    
</xsl:stylesheet>
