<?xml version="1.0" encoding="UTF-8"?>
<!-- Dieses Stylesheet erzeugt aus den Personenregisterdateien KML-Daten mit den Geburtsorten der Personen. Die Orte und Geokoordinaten werden aus der GND und Wikidata extrahiert. Die KML-Datei kann dann in den DARIAH Geo-Browser geladen werden (siehe https://hainhofer.hab.de/register/geburtsorte). Achtung: Speicher reicht eventuell nicht aus, um alle Personenregisterdokumente auf einmal zu verarbeiten. -->
<xsl:stylesheet xmlns:geo="http://www.opengis.net/ont/geosparql#" xmlns:gndo="http://d-nb.info/standards/elementset/gnd#" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:tei="http://www.tei-c.org/ns/1.0" xmlns:wgs84_pos="http://www.w3.org/2003/01/geo/wgs84_pos#" xmlns:xhtml="http://www.w3.org/1999/xhtml" xmlns:wdt="http://www.wikidata.org/prop/direct/" xmlns:foaf="http://xmlns.com/foaf/0.1/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#" xmlns:schema="http://schema.org/" exclude-result-prefixes="xs" xmlns:owl="http://www.w3.org/2002/07/owl#" version="2.0">   
    
    <xsl:template match="/">
        <!-- hier den Dateinamen des Ergebnisdokuments angeben: -->
        <xsl:result-document href="herkunftsorte-xyz.kml" method="xml" encoding="utf-8" indent="yes">
            <kml xmlns="http://www.opengis.net/kml/2.2">
                <xsl:apply-templates select="//tei:person"/>
            </kml>
        </xsl:result-document>
    </xsl:template>
    
    <xsl:template match="text()"/>
    
    <xsl:template match="tei:person">
        
        <!-- Ggf. anpassen zum Offline-Testen: -->
        <!--<xsl:variable name="psnpath">file://///FPSERVER/handschriften/Projekte/Hainhofer/Edition/HTML-Dateien/psn/</xsl:variable>-->
        
        <xsl:variable name="psnpath">https://hainhofer.hab.de/register/personen/</xsl:variable>
        
        <xsl:if test="tei:idno[@type = 'URI'][contains(., 'd-nb.info')]">
            
            <xsl:variable name="gndurl" select="normalize-space(tei:idno[@type = 'URI'][contains(., 'd-nb.info')][1])"/>
            <xsl:variable name="gndrdfurl" select="concat($gndurl, '/about/lds.rdf')"/>
            <xsl:if test="doc-available($gndrdfurl)">
            <xsl:if test="document($gndrdfurl)//owl:sameAs[contains(./@rdf:resource, 'wikidata')]">
                
                <xsl:variable name="wdurl" select="concat('https://www.wikidata.org/wiki/Special:EntityData/Q',substring-after(document($gndrdfurl)//owl:sameAs[contains(./@rdf:resource, 'wikidata')]/@rdf:resource,'/Q'),'.rdf')"/>
                <xsl:if test="doc-available($wdurl)">                   
                <xsl:if test="document($wdurl)//wdt:P19/@rdf:resource">                   
                    
                    <xsl:variable name="placewdurl" select="concat('https://www.wikidata.org/wiki/Special:EntityData/Q',substring-after(document($wdurl)//wdt:P19[@rdf:resource][1]/@rdf:resource,'/Q'),'.rdf')"/>                    
                    
                    <xsl:choose>
                        <xsl:when test="document($placewdurl)//wdt:P625 and document($placewdurl)/rdf:RDF/rdf:Description[substring-after(@rdf:about,'/Q') = substring-after(substring-before($placewdurl, '.rdf'),'/Q')]/rdfs:label[@xml:lang = 'de'] and not(document($placewdurl)//wdt:P31[@rdf:resource = ('http://www.wikidata.org/entity/Q5107', 'http://www.wikidata.org/entity/Q82794', 'http://www.wikidata.org/entity/Q6256', 'http://www.wikidata.org/entity/Q3024240', 'http://www.wikidata.org/entity/Q182547', 'http://www.wikidata.org/entity/Q107390')])">                            
                            <Placemark xmlns="http://www.opengis.net/kml/2.2">
                                <name>                                    
                                    <xsl:text>&lt;a href='</xsl:text><xsl:value-of select="concat($psnpath,@xml:id)"/><!--<xsl:text>.xhtml'&gt;</xsl:text>-->
                                    <xsl:text>'&gt;</xsl:text>
                                    <xsl:value-of select="normalize-space(tei:persName[@type = 'preferred']/tei:term)"/>
                                    <xsl:text>&lt;/a&gt;</xsl:text>
                                </name>
                                <address>                                    
                                    <xsl:value-of select="document($placewdurl)/rdf:RDF/rdf:Description[substring-after(@rdf:about,'/Q') = substring-after(substring-before($placewdurl, '.rdf'),'/Q')]/rdfs:label[@xml:lang = 'de']"/>
                                </address>
                                <Point>
                                    <coordinates>
                                        <xsl:value-of select="concat(substring-before(substring-after(document($placewdurl)//wdt:P625[1], 'Point('), ' '), ',', substring-after(substring-before(document($placewdurl)//wdt:P625[1], ')'), ' '))"/>
                                    </coordinates>
                                </Point>
                            </Placemark>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:if test="document($gndrdfurl)//gndo:placeOfBirth/@rdf:resource">
                                <xsl:variable name="placegndurl" select="document($gndrdfurl)//gndo:placeOfBirth/@rdf:resource"/>
                                <xsl:choose>
                                    <xsl:when test="document(concat($placegndurl, '/about/lds.rdf'))//geo:asWKT">
                                        
                                        <Placemark xmlns="http://www.opengis.net/kml/2.2">
                                            <name>
                                                <xsl:text>&lt;a href='</xsl:text><xsl:value-of select="concat($psnpath,@xml:id)"/><xsl:text>'&gt;</xsl:text>
                                                <xsl:value-of select="normalize-space(tei:persName[@type = 'preferred']/tei:term)"/>
                                                <xsl:text>&lt;/a&gt;</xsl:text>
                                            </name>
                                            <address>
                                                <xsl:value-of select="document(concat($placegndurl, '/about/lds.rdf'))//gndo:preferredNameForThePlaceOrGeographicName"/>
                                            </address>
                                            <Point>
                                                <coordinates>
                                                    <xsl:value-of select="substring-before(substring-after(document(concat($placegndurl, '/about/lds.rdf'))//geo:asWKT, 'Point ( +'), ' +')"/>
                                                    <xsl:text>,</xsl:text>
                                                    <xsl:value-of select="substring-before(substring-after(substring-after(document(concat($placegndurl, '/about/lds.rdf'))//geo:asWKT, 'Point ( +'), ' +'), ')')"/>
                                                </coordinates>
                                            </Point>
                                        </Placemark>
                                        
                                    </xsl:when>
                                    
                                    <xsl:when test="document(concat($placegndurl, '/about/lds.rdf'))//foaf:page[contains(./@rdf:resource, 'wikipedia')]/@rdf:resource">
                                        <xsl:variable name="wpurl" select="document(concat($placegndurl, '/about/lds.rdf'))//foaf:page[contains(./@rdf:resource, 'wikipedia')]/@rdf:resource"/>
                                        <xsl:if test="doc-available($wpurl)">
                                            <xsl:variable name="wdurl" select="concat(substring-before(document($wpurl)//a[text() = 'Wikidata-Datenobjekt']/@href, 'Page'), 'Data', substring-after(document($wpurl)//a[text() = 'Wikidata-Datenobjekt']/@href, 'Page'), '.rdf')"/>
                                            <xsl:if test="doc-available($wdurl) and not(document($wdurl)//wdt:P31[@rdf:resource = ('http://www.wikidata.org/entity/Q5107', 'http://www.wikidata.org/entity/Q82794', 'http://www.wikidata.org/entity/Q6256', 'http://www.wikidata.org/entity/Q3024240', 'http://www.wikidata.org/entity/Q182547')])">
                                                
                                                <Placemark xmlns="http://www.opengis.net/kml/2.2">
                                                    <name xml:space="default">
                                                        <xsl:text>&lt;a href='</xsl:text><xsl:value-of select="concat($psnpath,@xml:id)"/><xsl:text>'&gt;</xsl:text>
                                                        <xsl:value-of select="normalize-space(tei:persName[@type = 'preferred']/tei:term)"/>
                                                        <xsl:text>&lt;/a&gt;</xsl:text>
                                                    </name>
                                                    <address>
                                                        <xsl:value-of select="document(concat($placegndurl, '/about/lds.rdf'))//gndo:preferredNameForThePlaceOrGeographicName"/>
                                                    </address>
                                                    <Point>
                                                        <coordinates>
                                                            <xsl:value-of select="concat(substring-before(substring-after(document($wdurl)//wdt:P625[1], 'Point('), ' '), ',', substring-after(substring-before(document($wdurl)//wdt:P625[1], ')'), ' '))"/>
                                                        </coordinates>
                                                    </Point>
                                                </Placemark>
                                                
                                            </xsl:if>
                                        </xsl:if>
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:if>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:if>
                </xsl:if>
            </xsl:if>
            </xsl:if>
        </xsl:if>
    </xsl:template>
    
</xsl:stylesheet>