<?xml version="1.0" encoding="UTF-8"?>
<!-- Dieses Stylesheet erzeugt aus allen TEI/XML-Dateien des Körperschaftsregisters pro Registereintrag jeweils eine einzelne XHTML-Datei.
Es generiert Links zu den Reiseberichten und den anderen Registern; zu diesem Zweck müssen die entsprechenden TEI/XML-Dateien an den angegebenen Orten vorhanden sein.-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:tei="http://www.tei-c.org/ns/1.0" xmlns:xhtml="http://www.w3.org/1999/xhtml" exclude-result-prefixes="tei xhtml xs" version="2.0">
    <xsl:output method="xhtml" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" indent="yes"/>
    <xsl:strip-space elements="tei:bibl"/>
    
    <!-- Hier die Dateipfade angeben (werden beim Upload nach WordPress automatisch umgeschrieben): -->
    <xsl:variable name="transcrpath">../</xsl:variable>    
    <xsl:variable name="wrkpath">../wrk/</xsl:variable>
    <xsl:variable name="litpath">../lit/</xsl:variable>
    <xsl:variable name="plcpath">../plc/</xsl:variable>
    <xsl:variable name="psnpath">../psn/</xsl:variable>
    
    <xsl:template match="/">       
        <!-- Via VPN kann die Transformation sehr lange dauern; ggf. nur auf einzelne Dateien anwenden. -->
        <xsl:apply-templates select="(document('../Register/register-org/register-org-a.xml')|document('../Register/register-org/register-org-b.xml')|document('../Register/register-org/register-org-c.xml')|document('../Register/register-org/register-org-d.xml')|document('../Register/register-org/register-org-e.xml')|document('../Register/register-org/register-org-f.xml')|document('../Register/register-org/register-org-g.xml')|document('../Register/register-org/register-org-h.xml')|document('../Register/register-org/register-org-i.xml')|document('../Register/register-org/register-org-j.xml')|document('../Register/register-org/register-org-k.xml')|document('../Register/register-org/register-org-l.xml')|document('../Register/register-org/register-org-m.xml')|document('../Register/register-org/register-org-n.xml')|document('../Register/register-org/register-org-o.xml')|document('../Register/register-org/register-org-p.xml')|document('../Register/register-org/register-org-qr.xml')|document('../Register/register-org/register-org-s.xml')|document('../Register/register-org/register-org-t.xml')|document('../Register/register-org/register-org-u.xml')|document('../Register/register-org/register-org-v.xml')|document('../Register/register-org/register-org-w.xml')|document('../Register/register-org/register-org-xyz.xml'))/tei:TEI/tei:text/tei:body/tei:listOrg/tei:org[@xml:id ne '']"/>
    </xsl:template>
    
    <xsl:template match="tei:org[@xml:id ne '']">
        <xsl:result-document href="../../HTML-Dateien/org/{@xml:id}.xhtml">
            <html xmlns="http://www.w3.org/1999/xhtml">
                <head>
                    <link rel="stylesheet" type="text/css" href="org-output.css"/>
                    <title>Körperschaftsregister – <xsl:value-of select="tei:orgName[@type = 'preferred']/tei:term"/></title>
                </head>
                <body>
                    <h1 class="prefname">
                        <xsl:value-of select="tei:orgName[@type = 'preferred']/tei:term"/>
                    </h1>
                    <xsl:if test="tei:orgName[@type = 'variant']">
                        <div class="variantcontainer">
                            <xsl:choose>
                                <xsl:when test="count(tei:orgName[@type = 'variant']) > 1">
                                    <h2 class="variantnameprefix">Andere Namen</h2>
                                    <ul class="variantnames">       
                                        <xsl:for-each select="tei:orgName[@type = 'variant']">
                                            <li><xsl:value-of select="tei:term"/></li>                                           
                                        </xsl:for-each>
                                    </ul>
                                </xsl:when>
                                <xsl:otherwise>
                                    <h2 class="variantnameprefix">Andere Namen</h2>
                                    <p><xsl:value-of select="tei:orgName[@type = 'variant']/tei:term"/></p>
                                </xsl:otherwise>
                            </xsl:choose>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:idno">
                        <div class="uricontainer">
                            <h2 class="urishead">Externe Ressourcen</h2>
                            <ul class="uris">                 
                                <xsl:for-each select="tei:idno">
                                    <xsl:sort select="."/>
                                    <li>
                                        <xsl:choose>
                                            <xsl:when test="matches(., 'www.wikidata.org')">
                                                <xsl:text>Wikidata: </xsl:text>
                                                <a>
                                                    <xsl:attribute name="href" select="."/>
                                                    <xsl:value-of select="substring-after(., 'www.wikidata.org/entity/')"/>
                                                </a>
                                            </xsl:when>
                                            <xsl:when test="matches(., 'd-nb.info/gnd/')">
                                                <xsl:text>Gemeinsame Normdatei (GND): </xsl:text>
                                                <a>
                                                    <xsl:attribute name="href" select="."/>
                                                    <xsl:value-of select="substring-after(., 'd-nb.info/gnd/')"/>
                                                </a>
                                            </xsl:when>
                                        </xsl:choose>
                                    </li>
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:note[@subtype = 'desc']">
                        <div class="desc">
                            <xsl:choose>
                                <xsl:when test="tei:note[@subtype = 'desc']/tei:p">
                                    <h2 class="deschead">Weitere Angaben</h2>
                                    <xsl:apply-templates select="tei:note[@subtype = 'desc']"/>                                        
                                </xsl:when>
                                <xsl:otherwise>
                                    <h2 class="descprefix">Weitere Angaben</h2>
                                    <p>
                                        <xsl:apply-templates select="tei:note[@subtype = 'desc']"/>
                                    </p>
                                </xsl:otherwise>
                            </xsl:choose>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:note[@subtype = 'commentary']">
                        <div class="commentary">
                            <xsl:choose>
                                <xsl:when test="tei:note[@subtype = 'commentary']/tei:p">
                                    <h2 class="commentaryhead">Kommentar</h2>
                                    <xsl:apply-templates select="tei:note[@subtype = 'commentary']"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <h2 class="commentaryprefix">Kommentar</h2>
                                    <p>
                                        <xsl:apply-templates select="tei:note[@subtype = 'commentary']"/>
                                    </p>
                                </xsl:otherwise>
                            </xsl:choose>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P62_depicts']">
                        <div class="isdepictedcontainer">
                            <h2>Ist dargestellt in</h2>
                            <ul>
                                <xsl:for-each select="tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P62_depicts']">
                                    <xsl:sort select="substring-after(@target, 'wrk:')"/>
                                    <li>
                                        <a>
                                            <xsl:variable name="workid" select="substring-before(substring-after(@target, 'wrk:'), ' #')"/>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="concat($wrkpath, $workid, '.xhtml')"/>
                                            </xsl:attribute>
                                            <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term"/>
                                        </a>
                                    </li>
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:linkGrp/tei:link[@ana = 'http://purl.org/dc/elements/1.1/creator'][matches(@target, 'wrk:')]">
                        <div class="creatorcontainer">
                            <h2>Ist Urheber von</h2>
                            <ul>
                                <xsl:for-each select="tei:linkGrp/tei:link[@ana = 'http://purl.org/dc/elements/1.1/creator'][matches(@target, 'wrk:')]">
                                    <xsl:sort select="substring-after(substring-before(@target, ' #'), ':')"/>
                                    <li>
                                        <a>
                                            <xsl:variable name="workid" select="substring-after(substring-before(@target, ' #'), ':')"/>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="concat($wrkpath, $workid, '.xhtml')"/>
                                            </xsl:attribute>
                                            <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term"/>
                                        </a>
                                    </li>
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:linkGrp/tei:link[@ana = 'http://purl.org/dc/elements/1.1/creator'][matches(@target, 'lit:')]">
                        <div class="authorcontainer">
                            <h2>Ist Verfasser von</h2>
                            <ul>
                                <xsl:for-each select="tei:linkGrp/tei:link[@ana = 'http://purl.org/dc/elements/1.1/creator'][matches(@target, 'lit:')]">
                                    <xsl:sort select="substring-after(substring-before(@target, ' #'), ':')"/>
                                    <li>
                                        <a>
                                            <xsl:variable name="biblid" select="substring-after(substring-before(@target, ' #'), ':')"/>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="concat($litpath, $biblid, '.xhtml')"/>
                                            </xsl:attribute>
                                            <xsl:value-of select="(document('../Register/bibliography/bibliography-a.xml')|document('../Register/bibliography/bibliography-b.xml')|document('../Register/bibliography/bibliography-c.xml')|document('../Register/bibliography/bibliography-d.xml')|document('../Register/bibliography/bibliography-e.xml')|document('../Register/bibliography/bibliography-f.xml')|document('../Register/bibliography/bibliography-g.xml')|document('../Register/bibliography/bibliography-h.xml')|document('../Register/bibliography/bibliography-i.xml')|document('../Register/bibliography/bibliography-j.xml')|document('../Register/bibliography/bibliography-k.xml')|document('../Register/bibliography/bibliography-l.xml')|document('../Register/bibliography/bibliography-m.xml')|document('../Register/bibliography/bibliography-n.xml')|document('../Register/bibliography/bibliography-o.xml')|document('../Register/bibliography/bibliography-p.xml')|document('../Register/bibliography/bibliography-qr.xml')|document('../Register/bibliography/bibliography-s.xml')|document('../Register/bibliography/bibliography-t.xml')|document('../Register/bibliography/bibliography-u.xml')|document('../Register/bibliography/bibliography-v.xml')|document('../Register/bibliography/bibliography-w.xml')|document('../Register/bibliography/bibliography-xyz.xml'))//tei:bibl[@xml:id eq $biblid]/tei:seg/normalize-space()"/>
                                        </a>
                                    </li>
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P74_has_current_or_former_residence']">
                        <div class="residencecontainer">
                            <h2>Sitz</h2>
                            <ul>
                                <xsl:for-each select="tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P74_has_current_or_former_residence']">
                                    <xsl:sort select="substring-after(@target, ' plc:')"/>
                                    <li>
                                        <a>
                                            <xsl:variable name="plcid" select="substring-after(@target, ' plc:')"/>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="concat($plcpath, $plcid, '.xhtml')"/>
                                            </xsl:attribute>
                                            <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                        </a>
                                    </li>
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P107_has_current_or_former_member']">
                        <div class="hasmemberscontainer">
                            <h2>Mitglieder</h2>
                            <ul>
                                <xsl:for-each select="tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P107_has_current_or_former_member']">
                                    <xsl:sort select="(document('../Register/register-person/register-person-a.xml')|document('../Register/register-person/register-person-b.xml')|document('../Register/register-person/register-person-c.xml')|document('../Register/register-person/register-person-d.xml')|document('../Register/register-person/register-person-e.xml')|document('../Register/register-person/register-person-f.xml')|document('../Register/register-person/register-person-g.xml')|document('../Register/register-person/register-person-h.xml')|document('../Register/register-person/register-person-i.xml')|document('../Register/register-person/register-person-j.xml')|document('../Register/register-person/register-person-k.xml')|document('../Register/register-person/register-person-l.xml')|document('../Register/register-person/register-person-m.xml')|document('../Register/register-person/register-person-n.xml')|document('../Register/register-person/register-person-o.xml')|document('../Register/register-person/register-person-p.xml')|document('../Register/register-person/register-person-qr.xml')|document('../Register/register-person/register-person-s.xml')|document('../Register/register-person/register-person-t.xml')|document('../Register/register-person/register-person-u.xml')|document('../Register/register-person/register-person-v.xml')|document('../Register/register-person/register-person-w.xml')|document('../Register/register-person/register-person-xyz.xml'))//*[@xml:id = substring-after(current()/@target, ' psn:')]/tei:persName[@type = 'preferred']/tei:term/@sortKey"/>
                                    <li>
                                        <a>
                                            <xsl:variable name="memberid" select="substring-after(@target, ' psn:')"/>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="concat($psnpath, $memberid, '.xhtml')"/>
                                            </xsl:attribute>
                                            <xsl:value-of select="(document('../Register/register-person/register-person-a.xml')|document('../Register/register-person/register-person-b.xml')|document('../Register/register-person/register-person-c.xml')|document('../Register/register-person/register-person-d.xml')|document('../Register/register-person/register-person-e.xml')|document('../Register/register-person/register-person-f.xml')|document('../Register/register-person/register-person-g.xml')|document('../Register/register-person/register-person-h.xml')|document('../Register/register-person/register-person-i.xml')|document('../Register/register-person/register-person-j.xml')|document('../Register/register-person/register-person-k.xml')|document('../Register/register-person/register-person-l.xml')|document('../Register/register-person/register-person-m.xml')|document('../Register/register-person/register-person-n.xml')|document('../Register/register-person/register-person-o.xml')|document('../Register/register-person/register-person-p.xml')|document('../Register/register-person/register-person-qr.xml')|document('../Register/register-person/register-person-s.xml')|document('../Register/register-person/register-person-t.xml')|document('../Register/register-person/register-person-u.xml')|document('../Register/register-person/register-person-v.xml')|document('../Register/register-person/register-person-w.xml')|document('../Register/register-person/register-person-xyz.xml'))//*[@xml:id = $memberid]/tei:persName[@type = 'preferred']/tei:term/*"/>
                                        </a>
                                    </li>
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:listBibl[@type = 'references']">
                        <div class="litcontainer">
                            <h2>Literatur</h2>
                            <ul>
                                <xsl:for-each select="tei:listBibl[@type = 'references']/tei:bibl">
                                    <!--<xsl:sort select="tei:ptr/@target"/>-->
                                    <li>
                                        <a>
                                            <xsl:variable name="biblid" select="substring-after(tei:ptr/@target, ':')"/>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="concat($litpath, $biblid, '.xhtml')"/>
                                            </xsl:attribute>
                                            <xsl:value-of select="(document('../Register/bibliography/bibliography-a.xml')|document('../Register/bibliography/bibliography-b.xml')|document('../Register/bibliography/bibliography-c.xml')|document('../Register/bibliography/bibliography-d.xml')|document('../Register/bibliography/bibliography-e.xml')|document('../Register/bibliography/bibliography-f.xml')|document('../Register/bibliography/bibliography-g.xml')|document('../Register/bibliography/bibliography-h.xml')|document('../Register/bibliography/bibliography-i.xml')|document('../Register/bibliography/bibliography-j.xml')|document('../Register/bibliography/bibliography-k.xml')|document('../Register/bibliography/bibliography-l.xml')|document('../Register/bibliography/bibliography-m.xml')|document('../Register/bibliography/bibliography-n.xml')|document('../Register/bibliography/bibliography-o.xml')|document('../Register/bibliography/bibliography-p.xml')|document('../Register/bibliography/bibliography-qr.xml')|document('../Register/bibliography/bibliography-s.xml')|document('../Register/bibliography/bibliography-t.xml')|document('../Register/bibliography/bibliography-u.xml')|document('../Register/bibliography/bibliography-v.xml')|document('../Register/bibliography/bibliography-w.xml')|document('../Register/bibliography/bibliography-xyz.xml'))//tei:bibl[@xml:id eq $biblid]/tei:seg/normalize-space()"/>
                                        </a>
                                        <xsl:choose>
                                            <xsl:when test="tei:citedRange[not(@target)]">
                                                <xsl:text>, </xsl:text>
                                                <xsl:value-of select="."/>
                                            </xsl:when>
                                            <xsl:when test="tei:citedRange[@target]">
                                                <xsl:text>, </xsl:text>
                                                <a>
                                                    <xsl:attribute name="href" select="tei:citedRange/@target"/>
                                                    <xsl:value-of select="."/>
                                                </a>
                                            </xsl:when>
                                        </xsl:choose>
                                    </li>
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:if>
                    <div class="occurrencescontainer">
                        <h2>Vorkommen im Text</h2>
                        <ul>
                            <xsl:choose>
                                <xsl:when test="tei:listBibl[@type = 'occurrences'][@subtype]/tei:bibl/text()">
                                    <xsl:for-each select="tei:listBibl[@type = 'occurrences'][@subtype]/tei:bibl">                                        
                                        <xsl:variable name="pagenum" select="substring-before(substring-after(., 'fol. '),':')"/>
                                        <li>
                                            <a>
                                                <xsl:attribute name="href">
                                                    
                                                    <xsl:value-of select="concat($transcrpath, replace(replace(replace(replace(replace(substring-before(lower-case(.),', fol. '),'[\s|/]',''),'ü','ue'),'ä','ae'),'ö','oe'),'–','_'), '.xhtml#fol', $pagenum)"/>                                                 
                                                </xsl:attribute>
                                                <xsl:value-of select="text()"/>
                                            </a>
                                            <xsl:apply-templates select="tei:biblScope"/>
                                        </li>
                                    </xsl:for-each>
                                </xsl:when>
                                <xsl:when test="tei:listBibl[@type = 'occurrences'][not(@subtype)]/tei:bibl/text()">
                                    <xsl:for-each select="tei:listBibl[@type = 'occurrences'][not(@subtype)]/tei:bibl">
                                        <xsl:sort select="substring-before(.,'fol.')"/>
                                        <xsl:sort select="replace(.,'.*fol\.\s([0-9]+).*','$1')" data-type="number"/>
                                        <xsl:variable name="pagenum" select="substring-after(., 'fol. ')"/>
                                        <li>
                                            <a>
                                                <xsl:attribute name="href">
                                                    
                                                    <xsl:value-of select="concat($transcrpath, replace(replace(replace(replace(replace(substring-before(lower-case(.),', fol. '),'[\s|/]',''),'ü','ue'),'ä','ae'),'ö','oe'),'–','_'), '.xhtml#fol', $pagenum)"/>                                                   
                                                </xsl:attribute>
                                                <xsl:value-of select="."/>
                                            </a>
                                        </li>
                                    </xsl:for-each>
                                </xsl:when>
                            </xsl:choose>
                        </ul>  
                    </div>
                </body>
            </html>
        </xsl:result-document>
    </xsl:template>
    
    <xsl:template match="tei:biblScope">
        <span xmlns="http://www.w3.org/1999/xhtml" class="snippet">
            <xsl:apply-templates/>
        </span>
    </xsl:template>
    
    <xsl:template match="tei:rs">
        <xsl:choose>
            <xsl:when test="@type = 'org'">
                <a xmlns="http://www.w3.org/1999/xhtml">
                    <xsl:attribute name="href">
                        <xsl:value-of select="concat(substring-after(@ref, '#'), '.xhtml')"/>
                    </xsl:attribute>
                    <xsl:apply-templates/>
                </a>
            </xsl:when>
            <xsl:when test="@type = 'place'">
                <a xmlns="http://www.w3.org/1999/xhtml">
                    <xsl:attribute name="href">
                        <xsl:value-of select="concat($plcpath, substring-after(@ref, 'plc:'), '.xhtml')"/>
                    </xsl:attribute>
                    <xsl:apply-templates/>
                </a>
            </xsl:when>
            <xsl:when test="@type = 'person'">
                <a xmlns="http://www.w3.org/1999/xhtml">
                    <xsl:attribute name="href">
                        <xsl:value-of select="concat($psnpath, substring-after(@ref, 'psn:'), '.xhtml')"/>
                    </xsl:attribute>
                    <xsl:apply-templates/>
                </a>
            </xsl:when>
            <xsl:when test="@type = 'work'">
                <a xmlns="http://www.w3.org/1999/xhtml">
                    <xsl:attribute name="href">
                        <xsl:value-of select="concat($wrkpath, substring-after(@ref, 'wrk:'), '.xhtml')"/>
                    </xsl:attribute>
                    <xsl:apply-templates/>
                </a>
            </xsl:when>
            <xsl:when test="@type = 'quote'">
                <span xmlns="http://www.w3.org/1999/xhtml" class="rs">
                    <xsl:value-of select="."/>
                </span>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="tei:note//tei:bibl/tei:ref">
        <a xmlns="http://www.w3.org/1999/xhtml">
            <xsl:attribute name="href">
                <xsl:value-of select="concat($litpath, substring-after(@target, 'lit:'), '.xhtml')"/>
            </xsl:attribute>
            <xsl:apply-templates/>
        </a>
    </xsl:template>
    
    <xsl:template match="tei:note//tei:bibl/tei:citedRange">
        <a xmlns="http://www.w3.org/1999/xhtml">
            <xsl:attribute name="href">
                <xsl:value-of select="@target"/>
            </xsl:attribute>
            <xsl:apply-templates/>
        </a>
    </xsl:template>
    
    <xsl:template match="tei:note/tei:p//tei:ref[not(parent::tei:bibl)]">
        <a xmlns="http://www.w3.org/1999/xhtml">
            <xsl:attribute name="href">
                <xsl:value-of select="@target"/>
            </xsl:attribute>
            <xsl:apply-templates/>
        </a>
    </xsl:template>
    
    <xsl:template match="tei:note//tei:ref[not(parent::tei:bibl)]">
        <a xmlns="http://www.w3.org/1999/xhtml">
            <xsl:attribute name="href">
                <xsl:value-of select="@target"/>
            </xsl:attribute>
            <xsl:apply-templates/>
        </a>
    </xsl:template>
    
    <xsl:template match="tei:p">
        <p xmlns="http://www.w3.org/1999/xhtml">
            <xsl:apply-templates/>
        </p>
    </xsl:template>
    
    <xsl:template match="tei:hi[@rendition = '#i']">
        <span xmlns="http://www.w3.org/1999/xhtml" class="italics">
            <xsl:apply-templates/>
        </span>
    </xsl:template>
    
</xsl:stylesheet>
