<?xml version="1.0" encoding="UTF-8"?>
<!-- Dieses Stylesheet erzeugt aus allen TEI/XML-Dateien des Personenregisters pro Registereintrag jeweils eine einzelne XHTML-Datei.
    Es generiert Links zu den Reiseberichten und den anderen Registern; zu diesem Zweck müssen die entsprechenden TEI/XML-Dateien an den angegebenen Orten vorhanden sein.-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:tei="http://www.tei-c.org/ns/1.0" xmlns:xhtml="http://www.w3.org/1999/xhtml" exclude-result-prefixes="tei xhtml xs" version="2.0">
    <xsl:output method="xhtml" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" indent="yes"/>
    
    <xsl:strip-space elements="tei:bibl"/>
    
    <!-- Hier die Dateipfade angeben (werden beim Upload nach WordPress automatisch umgeschrieben): -->
    <xsl:variable name="transcrpath">../</xsl:variable>
    <xsl:variable name="wrkpath">../wrk/</xsl:variable>
    <xsl:variable name="litpath">../lit/</xsl:variable>
    <xsl:variable name="plcpath">../plc/</xsl:variable>
    <xsl:variable name="orgpath">../org/</xsl:variable>
    <xsl:variable name="psnclasspath">../klassifikation-zum-personenregister</xsl:variable>
    
    <xsl:template match="/">     
        <xsl:apply-templates select="tei:TEI/tei:text/tei:body/tei:listPerson"/>       
    </xsl:template>
    
    <xsl:template match="tei:listPerson">
        <xsl:apply-templates select="(document('../Register/register-person/register-person-a.xml')|document('../Register/register-person/register-person-b.xml')|document('../Register/register-person/register-person-c.xml')|document('../Register/register-person/register-person-d.xml')|document('../Register/register-person/register-person-e.xml')|document('../Register/register-person/register-person-f.xml')|document('../Register/register-person/register-person-g.xml')|document('../Register/register-person/register-person-h.xml')|document('../Register/register-person/register-person-i.xml')|document('../Register/register-person/register-person-j.xml')|document('../Register/register-person/register-person-k.xml')|document('../Register/register-person/register-person-l.xml')|document('../Register/register-person/register-person-m.xml')|document('../Register/register-person/register-person-n.xml')|document('../Register/register-person/register-person-o.xml')|document('../Register/register-person/register-person-p.xml')|document('../Register/register-person/register-person-qr.xml')|document('../Register/register-person/register-person-s.xml')|document('../Register/register-person/register-person-t.xml')|document('../Register/register-person/register-person-u.xml')|document('../Register/register-person/register-person-v.xml')|document('../Register/register-person/register-person-w.xml')|document('../Register/register-person/register-person-xyz.xml'))//(tei:person | tei:personGrp)">
        </xsl:apply-templates>
    </xsl:template>
    
    <xsl:template match="tei:person | tei:personGrp">
        <xsl:variable name="name">
            <xsl:choose>                
                <xsl:when test="matches(tei:persName[@type = 'preferred']/tei:term/tei:forename,' \([1-9]\)$') and tei:persName[@type = 'preferred']/tei:term/tei:surname and tei:persName[@type = 'preferred']/tei:term/tei:forename">                    
                    <xsl:value-of select="substring-before(tei:persName[@type = 'preferred']/tei:term/tei:forename,' (')"/>
                    <xsl:text> </xsl:text>
                    <xsl:value-of select="tei:persName[@type = 'preferred']/tei:term/tei:surname"/>
                    <xsl:text> (</xsl:text>
                    <xsl:value-of select="substring-after(tei:persName[@type = 'preferred']/tei:term/tei:forename,' (')"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="tei:persName[@type = 'preferred']/tei:term/*"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:result-document href="../../HTML-Dateien/psn/{@xml:id}.xhtml">
            <html xmlns="http://www.w3.org/1999/xhtml">
                <head>
                    <link rel="stylesheet" type="text/css" href="psn-output.css"/>
                    <title>Personenregister – <xsl:value-of select="$name"/></title>
                </head>
                <body>                    
                    <h1 class="prefname">
                        <xsl:value-of select="$name"/>
                        <xsl:if test="(tei:persName[@type = 'preferred']/tei:term/tei:surname ne '') and (tei:persName[@type = 'preferred']/tei:term/tei:forename eq '')">
                            <xsl:text>, ?</xsl:text>
                        </xsl:if>
                    </h1>
                    <xsl:if test="tei:birth/@when-iso or tei:birth/@notBefore-iso or tei:death/@when-iso or tei:death/@notBefore-iso">
                        <div class="birthdeath">
                            <p>
                                <xsl:if test="tei:birth">
                                    <xsl:text>* </xsl:text>
                                </xsl:if>
                                <xsl:if test="tei:birth/@precision eq 'low' and tei:birth/@when-iso">
                                    <xsl:text>ca. </xsl:text>
                                </xsl:if>
                                <xsl:choose>
                                    <xsl:when test="tei:birth/@when-iso">
                                        <xsl:choose>
                                            <xsl:when test="substring(tei:birth/@when-iso, 1, 1) = '-'">
                                                <xsl:value-of select="number(substring-after(tei:birth/@when-iso, '-')) + 1"/>
                                                <xsl:text> v. Chr.</xsl:text>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="number(tei:birth/@when-iso)"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:when>
                                    <xsl:when test="tei:birth/@notBefore-iso and tei:birth/@notAfter-iso">
                                        <xsl:text>zwischen </xsl:text>
                                        <xsl:if test="tei:birth/@precision eq 'low'">
                                            <xsl:text>ca. </xsl:text>
                                        </xsl:if>
                                        <xsl:choose>
                                            <xsl:when test="substring(tei:birth/@notBefore-iso, 1, 1) = '-'">
                                                <xsl:value-of select="number(substring-after(tei:birth/@notBefore-iso, '-')) + 1"/>
                                                <xsl:if test="substring(tei:birth/@notAfter-iso, 1, 1) != '-'">
                                                    <xsl:text> v. Chr.</xsl:text>
                                                </xsl:if>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="number(tei:birth/@notBefore-iso)"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                        <xsl:text> und </xsl:text>
                                        <xsl:choose>
                                            <xsl:when test="substring(tei:birth/@notAfter-iso, 1, 1) = '-'">
                                                <xsl:value-of select="number(substring-after(tei:birth/@notAfter-iso, '-')) + 1"/>
                                                <xsl:text> v. Chr.</xsl:text>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="number(tei:birth/@notAfter-iso)"/>
                                                <xsl:if test="substring(tei:birth/@notBefore-iso, 1, 1) = '-'">
                                                    <xsl:text> n. Chr.</xsl:text>
                                                </xsl:if>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:when>
                                    <xsl:otherwise/>
                                </xsl:choose>
                                <xsl:if test="tei:birth">
                                    <br/>
                                </xsl:if>
                                <xsl:if test="tei:death">                                    
                                    <xsl:text>✝ </xsl:text>
                                </xsl:if>
                                <xsl:if test="tei:death/@precision eq 'low' and tei:death/@when-iso">
                                    <xsl:text>ca. </xsl:text>
                                </xsl:if>
                                
                                <xsl:choose>
                                    <xsl:when test="tei:death/@when-iso">
                                        <xsl:choose>
                                            <xsl:when test="substring(tei:death/@when-iso, 1, 1) = '-'">
                                                <xsl:value-of select="number(substring-after(tei:death/@when-iso, '-')) + 1"/>
                                                <xsl:text> v. Chr.</xsl:text>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="number(tei:death/@when-iso)"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:when>
                                    <xsl:when test="tei:death/@notBefore-iso and tei:death/@notAfter-iso">
                                        <xsl:text>zwischen </xsl:text>
                                        <xsl:if test="tei:death/@precision eq 'low'">
                                            <xsl:text>ca. </xsl:text>
                                        </xsl:if>
                                        <xsl:choose>
                                            <xsl:when test="substring(tei:death/@notBefore-iso, 1, 1) = '-'">
                                                <xsl:value-of select="number(substring-after(tei:death/@notBefore-iso, '-')) + 1"/>
                                                <xsl:if test="substring(tei:death/@notAfter-iso, 1, 1) != '-'">
                                                    <xsl:text> v. Chr.</xsl:text>
                                                </xsl:if>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="number(tei:death/@notBefore-iso)"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                        <xsl:text> und </xsl:text>
                                        <xsl:choose>
                                            <xsl:when test="substring(tei:death/@notAfter-iso, 1, 1) = '-'">
                                                <xsl:value-of select="number(substring-after(tei:death/@notAfter-iso, '-')) + 1"/>
                                                <xsl:text> v. Chr.</xsl:text>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="number(tei:death/@notAfter-iso)"/>
                                                <xsl:if test="substring(tei:death/@notBefore-iso, 1, 1) = '-'">
                                                    <xsl:text> n. Chr.</xsl:text>
                                                </xsl:if>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:when>
                                    <xsl:otherwise/>
                                </xsl:choose>
                            </p>
                        </div>
                    </xsl:if>
                    
                    <xsl:if test="tei:floruit">
                        <div class="floruit">
                            <p>
                                <span>Wirkungsdaten: </span>
                                <xsl:value-of select="tei:floruit"/>
                            </p>
                        </div>
                    </xsl:if>
                    
                    <xsl:if test="tei:persName[@type = 'variant']">    
                        <div class="variantcontainer">
                            <xsl:choose>
                                <xsl:when test="count(tei:persName[@type = 'variant']) > 1">
                                    <h2 class="variantnameprefix">Andere Namen</h2>
                                    <ul class="variantnames">
                                        <xsl:for-each select="tei:persName[@type = 'variant']">
                                            <li>
                                                <xsl:value-of select="tei:term/*"/>                                                    
                                            </li>
                                        </xsl:for-each>
                                    </ul>
                                </xsl:when>
                                <xsl:otherwise>                               
                                    <h2 class="variantnameprefix">Anderer Name</h2>
                                    <p class="variantname"><xsl:value-of select="tei:persName[@type = 'variant']/tei:term/*"/></p>                                
                                </xsl:otherwise>
                            </xsl:choose>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:idno">
                        <div class="uricontainer">
                            <h2 class="urishead">Externe Ressourcen</h2>
                            <ul class="uris">
                                <xsl:for-each select="tei:idno">
                                    <xsl:sort select="."/>
                                    <li>
                                        <xsl:choose>
                                            <xsl:when test="matches(., 'www.deutsche-biographie.de')">
                                                <xsl:text>Deutsche Biographie: </xsl:text>
                                                <a>
                                                    <xsl:attribute name="href" select="."/>
                                                    <xsl:value-of select="substring-before(substring-after(., 'www.deutsche-biographie.de/'), '.html')"/>
                                                </a>
                                            </xsl:when>
                                            <xsl:when test="matches(., 'www.bbkl.de')">
                                                <xsl:text>Biographisch-Bibliographisches Kirchenlexikon (BBKL): </xsl:text>
                                                <a>
                                                    <xsl:attribute name="href" select="."/>
                                                    <xsl:choose>
                                                        <xsl:when test="matches(., 'article=')">
                                                            <xsl:value-of select="substring-before(substring-after(., 'article='), '.art')"/>
                                                        </xsl:when>
                                                        <xsl:when test="matches(.,'(-[0-9]{4,6})$')">
                                                            <xsl:value-of select="tokenize(., '/')[matches(.,'(-[0-9]{4,6})$')]"/>
                                                        </xsl:when>
                                                    </xsl:choose>                                                    
                                                </a>
                                            </xsl:when>
                                            <xsl:when test="matches(., 'vocab.getty.edu/ulan')">
                                                <xsl:text>Union List of Artist Names (ULAN): </xsl:text>
                                                <a>
                                                    <xsl:attribute name="href" select="concat('http://vocab.getty.edu/page/ulan/', substring-after(., 'vocab.getty.edu/ulan/'))"/>
                                                    <xsl:value-of select="substring-after(., 'vocab.getty.edu/ulan/')"/>
                                                </a>
                                            </xsl:when>
                                            <xsl:when test="matches(., 'd-nb.info/gnd/')">
                                                <xsl:text>Gemeinsame Normdatei (GND): </xsl:text>
                                                <a>
                                                    <xsl:attribute name="href" select="."/>
                                                    <xsl:value-of select="substring-after(., 'd-nb.info/gnd/')"/>
                                                </a>
                                            </xsl:when>
                                            <xsl:when test="matches(., 'ta.sandrart.net')">
                                                <xsl:text>Sandrart.net: </xsl:text>
                                                <a>
                                                    <xsl:attribute name="href" select="."/>
                                                    <xsl:value-of select="substring-after(., '-person-')"/>
                                                </a>
                                            </xsl:when>
                                            <xsl:when test="matches(., '/rkd.nl/')">
                                                <xsl:text>RKDartists: </xsl:text>
                                                <a>
                                                    <xsl:attribute name="href" select="."/>
                                                    <xsl:value-of select="substring-after(., '/artists/')"/>
                                                </a>
                                            </xsl:when>
                                        </xsl:choose>
                                    </li>
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:note[@subtype = 'bio']">
                        <div class="bio">
                            <xsl:choose>
                                <xsl:when test="tei:note[@subtype = 'bio']/tei:p">
                                    <h2 class="biohead">Weitere Angaben</h2>
                                    <xsl:apply-templates select="tei:note[@subtype = 'bio']"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <h2 class="bioprefix">Weitere Angaben</h2>
                                    <p>
                                        <xsl:apply-templates select="tei:note[@subtype = 'bio']"/>
                                    </p>
                                </xsl:otherwise>
                            </xsl:choose>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:note[@subtype = 'commentary']">
                        <div class="commentary">
                            <xsl:choose>
                                <xsl:when test="tei:note[@subtype = 'commentary']/tei:p">
                                    <h2 class="commentaryhead">Kommentar</h2>
                                    <xsl:apply-templates select="tei:note[@subtype = 'commentary']"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <h2 class="commentaryprefix">Kommentar</h2>
                                    <p>
                                        <xsl:apply-templates select="tei:note[@subtype = 'commentary']"/>
                                    </p>
                                </xsl:otherwise>
                            </xsl:choose>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:occupation">
                        <div class="categorycontainer">
                            <h2 class="catprefix">Kategorien</h2> 
                            <ul>
                                <xsl:for-each select="tei:occupation">
                                    <xsl:variable name="occupationcode" select="substring-after(@code, '#')"/>
                                    <li>
                                        <a>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="concat($psnclasspath,'#',$occupationcode)"/>
                                            </xsl:attribute>
                                            <xsl:if test="//tei:category[@xml:id = $occupationcode]/parent::tei:category">
                                                <xsl:value-of select="//tei:category[@xml:id = $occupationcode]/parent::tei:category/tei:catDesc"/>
                                                <xsl:text>: </xsl:text>
                                            </xsl:if>
                                            <xsl:value-of select="//tei:category[@xml:id = $occupationcode]/tei:catDesc"/>
                                        </a>
                                    </li>
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:faith/*">
                        <div class="faithcontainer">
                            <h2>Konfession</h2>
                            <ul>
                                <xsl:for-each select="tei:faith/tei:gloss">
                                    <li>
                                        <xsl:value-of select="."/>
                                    </li>
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:if>
                    <xsl:if test="self::tei:personGrp and tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P107_has_current_or_former_member']">
                        <div class="hasmemberscontainer">
                            <h2>Mitglieder</h2>
                            <xsl:variable name="hasmemberslist">                        
                                <xsl:for-each select="tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P107_has_current_or_former_member']">                                    
                                    <li>
                                        <xsl:variable name="memberid" select="substring-after(@target, ' #')"/>
                                        <xsl:attribute name="title">
                                            <xsl:value-of select="(document('../Register/register-person/register-person-a.xml')|document('../Register/register-person/register-person-b.xml')|document('../Register/register-person/register-person-c.xml')|document('../Register/register-person/register-person-d.xml')|document('../Register/register-person/register-person-e.xml')|document('../Register/register-person/register-person-f.xml')|document('../Register/register-person/register-person-g.xml')|document('../Register/register-person/register-person-h.xml')|document('../Register/register-person/register-person-i.xml')|document('../Register/register-person/register-person-j.xml')|document('../Register/register-person/register-person-k.xml')|document('../Register/register-person/register-person-l.xml')|document('../Register/register-person/register-person-m.xml')|document('../Register/register-person/register-person-n.xml')|document('../Register/register-person/register-person-o.xml')|document('../Register/register-person/register-person-p.xml')|document('../Register/register-person/register-person-qr.xml')|document('../Register/register-person/register-person-s.xml')|document('../Register/register-person/register-person-t.xml')|document('../Register/register-person/register-person-u.xml')|document('../Register/register-person/register-person-v.xml')|document('../Register/register-person/register-person-w.xml')|document('../Register/register-person/register-person-xyz.xml'))//tei:person[@xml:id = $memberid]/tei:persName[@type = 'preferred']/tei:term/@sortKey"/>
                                        </xsl:attribute>
                                        <a>                                            
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="concat($memberid, '.xhtml')"/>
                                            </xsl:attribute>
                                            <xsl:value-of select="(document('../Register/register-person/register-person-a.xml')|document('../Register/register-person/register-person-b.xml')|document('../Register/register-person/register-person-c.xml')|document('../Register/register-person/register-person-d.xml')|document('../Register/register-person/register-person-e.xml')|document('../Register/register-person/register-person-f.xml')|document('../Register/register-person/register-person-g.xml')|document('../Register/register-person/register-person-h.xml')|document('../Register/register-person/register-person-i.xml')|document('../Register/register-person/register-person-j.xml')|document('../Register/register-person/register-person-k.xml')|document('../Register/register-person/register-person-l.xml')|document('../Register/register-person/register-person-m.xml')|document('../Register/register-person/register-person-n.xml')|document('../Register/register-person/register-person-o.xml')|document('../Register/register-person/register-person-p.xml')|document('../Register/register-person/register-person-qr.xml')|document('../Register/register-person/register-person-s.xml')|document('../Register/register-person/register-person-t.xml')|document('../Register/register-person/register-person-u.xml')|document('../Register/register-person/register-person-v.xml')|document('../Register/register-person/register-person-w.xml')|document('../Register/register-person/register-person-xyz.xml'))//tei:person[@xml:id = $memberid]/tei:persName[@type = 'preferred']/tei:term/*"/>
                                        </a>
                                    </li>
                                </xsl:for-each>
                            </xsl:variable>
                            <ul>
                                <xsl:for-each select="$hasmemberslist/xhtml:li">
                                    <xsl:sort select="@title"/>
                                    <li>
                                        <xsl:copy-of select="./xhtml:a"/>
                                    </li>
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:if>
                    <xsl:if test="self::tei:person and tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P107_has_current_or_former_member']">
                        <div class="ismembercontainer">
                            <h2>Ist Mitglied von</h2>
                            <xsl:variable name="ismemberlist">
                                <xsl:for-each select="tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P107_has_current_or_former_member']">            
                                    <xsl:choose>
                                        <xsl:when test="starts-with(substring-before(@target, ' #'),'#')">
                                            <li>
                                                <xsl:variable name="groupid" select="substring-before(@target, ' #')"/>
                                                <xsl:attribute name="title">
                                                    <xsl:value-of select="(document('../Register/register-person/register-person-a.xml')|document('../Register/register-person/register-person-b.xml')|document('../Register/register-person/register-person-c.xml')|document('../Register/register-person/register-person-d.xml')|document('../Register/register-person/register-person-e.xml')|document('../Register/register-person/register-person-f.xml')|document('../Register/register-person/register-person-g.xml')|document('../Register/register-person/register-person-h.xml')|document('../Register/register-person/register-person-i.xml')|document('../Register/register-person/register-person-j.xml')|document('../Register/register-person/register-person-k.xml')|document('../Register/register-person/register-person-l.xml')|document('../Register/register-person/register-person-m.xml')|document('../Register/register-person/register-person-n.xml')|document('../Register/register-person/register-person-o.xml')|document('../Register/register-person/register-person-p.xml')|document('../Register/register-person/register-person-qr.xml')|document('../Register/register-person/register-person-s.xml')|document('../Register/register-person/register-person-t.xml')|document('../Register/register-person/register-person-u.xml')|document('../Register/register-person/register-person-v.xml')|document('../Register/register-person/register-person-w.xml')|document('../Register/register-person/register-person-xyz.xml'))//tei:personGrp[@xml:id = substring-after($groupid, '#')]/tei:persName[@type = 'preferred']/tei:term/@sortKey"/>
                                                </xsl:attribute>
                                                <a>                                                                                                
                                                    <xsl:attribute name="href">
                                                        <xsl:value-of select="concat(substring-after($groupid, '#'), '.xhtml')"/>
                                                    </xsl:attribute>
                                                    <xsl:value-of select="(document('../Register/register-person/register-person-a.xml')|document('../Register/register-person/register-person-b.xml')|document('../Register/register-person/register-person-c.xml')|document('../Register/register-person/register-person-d.xml')|document('../Register/register-person/register-person-e.xml')|document('../Register/register-person/register-person-f.xml')|document('../Register/register-person/register-person-g.xml')|document('../Register/register-person/register-person-h.xml')|document('../Register/register-person/register-person-i.xml')|document('../Register/register-person/register-person-j.xml')|document('../Register/register-person/register-person-k.xml')|document('../Register/register-person/register-person-l.xml')|document('../Register/register-person/register-person-m.xml')|document('../Register/register-person/register-person-n.xml')|document('../Register/register-person/register-person-o.xml')|document('../Register/register-person/register-person-p.xml')|document('../Register/register-person/register-person-qr.xml')|document('../Register/register-person/register-person-s.xml')|document('../Register/register-person/register-person-t.xml')|document('../Register/register-person/register-person-u.xml')|document('../Register/register-person/register-person-v.xml')|document('../Register/register-person/register-person-w.xml')|document('../Register/register-person/register-person-xyz.xml'))//tei:personGrp[@xml:id = substring-after($groupid, '#')]/tei:persName[@type = 'preferred']/tei:term/*"/>
                                                </a>
                                            </li>
                                        </xsl:when>
                                        <xsl:when test="starts-with(substring-before(@target, ' #'),'org:')">                                                                                      
                                            <li>
                                                <xsl:variable name="groupid" select="substring-after(substring-before(@target, ' #'),'org:')"/>  
                                                <xsl:attribute name="title">
                                                    <xsl:value-of select="(document('../Register/register-org/register-org-a.xml')|document('../Register/register-org/register-org-b.xml')|document('../Register/register-org/register-org-c.xml')|document('../Register/register-org/register-org-d.xml')|document('../Register/register-org/register-org-e.xml')|document('../Register/register-org/register-org-f.xml')|document('../Register/register-org/register-org-g.xml')|document('../Register/register-org/register-org-h.xml')|document('../Register/register-org/register-org-i.xml')|document('../Register/register-org/register-org-j.xml')|document('../Register/register-org/register-org-k.xml')|document('../Register/register-org/register-org-l.xml')|document('../Register/register-org/register-org-m.xml')|document('../Register/register-org/register-org-n.xml')|document('../Register/register-org/register-org-o.xml')|document('../Register/register-org/register-org-p.xml')|document('../Register/register-org/register-org-qr.xml')|document('../Register/register-org/register-org-s.xml')|document('../Register/register-org/register-org-t.xml')|document('../Register/register-org/register-org-u.xml')|document('../Register/register-org/register-org-v.xml')|document('../Register/register-org/register-org-w.xml')|document('../Register/register-org/register-org-xyz.xml'))//tei:org[@xml:id eq $groupid]/tei:orgName[@type = 'preferred']/tei:term/@sortKey"/>                                                        
                                                </xsl:attribute>
                                                <a>
                                                    <xsl:attribute name="href">
                                                        <xsl:value-of select="concat($orgpath, $groupid, '.xhtml')"/>
                                                    </xsl:attribute> 
                                                    <xsl:value-of select="(document('../Register/register-org/register-org-a.xml')|document('../Register/register-org/register-org-b.xml')|document('../Register/register-org/register-org-c.xml')|document('../Register/register-org/register-org-d.xml')|document('../Register/register-org/register-org-e.xml')|document('../Register/register-org/register-org-f.xml')|document('../Register/register-org/register-org-g.xml')|document('../Register/register-org/register-org-h.xml')|document('../Register/register-org/register-org-i.xml')|document('../Register/register-org/register-org-j.xml')|document('../Register/register-org/register-org-k.xml')|document('../Register/register-org/register-org-l.xml')|document('../Register/register-org/register-org-m.xml')|document('../Register/register-org/register-org-n.xml')|document('../Register/register-org/register-org-o.xml')|document('../Register/register-org/register-org-p.xml')|document('../Register/register-org/register-org-qr.xml')|document('../Register/register-org/register-org-s.xml')|document('../Register/register-org/register-org-t.xml')|document('../Register/register-org/register-org-u.xml')|document('../Register/register-org/register-org-v.xml')|document('../Register/register-org/register-org-w.xml')|document('../Register/register-org/register-org-xyz.xml'))//tei:org[@xml:id eq $groupid]/tei:orgName[@type = 'preferred']/tei:term"/>
                                                </a>
                                            </li>
                                        </xsl:when>
                                    </xsl:choose>                                        
                                </xsl:for-each>
                            </xsl:variable>
                            <ul>
                                <xsl:for-each select="$ismemberlist/xhtml:li">
                                    <xsl:sort select="@title"/>
                                    <li>
                                        <xsl:copy-of select="./xhtml:a"/>
                                    </li>
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P62_depicts']">
                        <div class="isdepictedcontainer">
                            <h2>Ist dargestellt in</h2>
                            <xsl:variable name="isdepictedlist">                            
                                <xsl:for-each select="tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P62_depicts']">                                    
                                    <li>
                                        <a>
                                            <xsl:variable name="workid" select="substring-after(substring-before(@target, ' #'), ':')"/>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="concat($wrkpath, $workid, '.xhtml')"/>
                                            </xsl:attribute>
                                            
                                            <xsl:if test="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location'] and (document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:objectType[@n eq '1'][@ref eq '#architektur']">
                                                <xsl:choose>
                                                    <xsl:when test="starts-with(substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' '), 'plc:')">
                                                        <xsl:variable name="plcid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' plc:')"/>
                                                        
                                                        <xsl:if test="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']">
                                                            <xsl:variable name="plcid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' #')"/>
                                                            <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                            <xsl:text>, </xsl:text>
                                                        </xsl:if>
                                                        
                                                        <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                        <xsl:text>, </xsl:text>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:variable name="workid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' #')"/>
                                                        
                                                        <xsl:if test="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']">
                                                            <xsl:variable name="plcid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' plc:')"/>
                                                            <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                            <xsl:text>, </xsl:text>
                                                        </xsl:if>
                                                        <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term"/>
                                                        <xsl:text>, </xsl:text>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </xsl:if>
                                            
                                            <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term"/>
                                        </a>
                                    </li>
                                </xsl:for-each>
                            </xsl:variable>
                            <ul>
                                <xsl:for-each select="$isdepictedlist/xhtml:li">
                                    <xsl:sort select="xhtml:a"/>
                                    <xsl:copy-of select="."/>
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:linkGrp/tei:link[@ana = 'http://purl.org/dc/elements/1.1/creator'][matches(@target, 'wrk:')]">
                        <div class="creatorcontainer">
                            <h2>Ist Urheber von</h2>
                            <xsl:variable name="creatorlist">                            
                                <xsl:for-each select="tei:linkGrp/tei:link[@ana = 'http://purl.org/dc/elements/1.1/creator'][matches(@target, 'wrk:')]">                                    
                                    <li>
                                        <a>
                                            <xsl:variable name="workid" select="substring-after(substring-before(@target, ' #'), ':')"/>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="concat($wrkpath, $workid, '.xhtml')"/>
                                            </xsl:attribute>
                                            
                                            <xsl:if test="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location'] and (document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:objectType[@n eq '1'][@ref eq '#architektur']">
                                                <xsl:choose>
                                                    <xsl:when test="starts-with(substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' '), 'plc:')">
                                                        <xsl:variable name="plcid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' plc:')"/>
                                                        
                                                        <xsl:if test="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']">
                                                            <xsl:variable name="plcid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' #')"/>
                                                            <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                            <xsl:text>, </xsl:text>
                                                        </xsl:if>
                                                        
                                                        <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                        <xsl:text>, </xsl:text>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:variable name="workid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' #')"/>
                                                        
                                                        <xsl:if test="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']">
                                                            <xsl:variable name="plcid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' plc:')"/>
                                                            <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                            <xsl:text>, </xsl:text>
                                                        </xsl:if>
                                                        <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term"/>
                                                        <xsl:text>, </xsl:text>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </xsl:if>
                                            
                                            <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term"/>
                                        </a>
                                    </li>
                                </xsl:for-each>                            
                            </xsl:variable>
                            <ul>
                                <xsl:for-each select="$creatorlist/xhtml:li">
                                    <xsl:sort select="xhtml:a"/>
                                    <xsl:copy-of select="."/>
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:linkGrp/tei:link[@ana = 'http://purl.org/dc/elements/1.1/creator'][matches(@target, 'lit:')]">
                        <div class="authorcontainer">
                            <h2>Ist Verfasser von</h2>
                            <ul>
                                <xsl:for-each select="tei:linkGrp/tei:link[@ana = 'http://purl.org/dc/elements/1.1/creator'][matches(@target, 'lit:')]">
                                    <xsl:sort select="substring-after(substring-before(@target, ' #'), ':')"/>
                                    <li>
                                        <a>
                                            <xsl:variable name="biblid" select="substring-after(substring-before(@target, ' #'), ':')"/>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="concat($litpath, $biblid, '.xhtml')"/>
                                            </xsl:attribute>
                                            <xsl:value-of select="(document('../Register/bibliography/bibliography-a.xml')|document('../Register/bibliography/bibliography-b.xml')|document('../Register/bibliography/bibliography-c.xml')|document('../Register/bibliography/bibliography-d.xml')|document('../Register/bibliography/bibliography-e.xml')|document('../Register/bibliography/bibliography-f.xml')|document('../Register/bibliography/bibliography-g.xml')|document('../Register/bibliography/bibliography-h.xml')|document('../Register/bibliography/bibliography-i.xml')|document('../Register/bibliography/bibliography-j.xml')|document('../Register/bibliography/bibliography-k.xml')|document('../Register/bibliography/bibliography-l.xml')|document('../Register/bibliography/bibliography-m.xml')|document('../Register/bibliography/bibliography-n.xml')|document('../Register/bibliography/bibliography-o.xml')|document('../Register/bibliography/bibliography-p.xml')|document('../Register/bibliography/bibliography-qr.xml')|document('../Register/bibliography/bibliography-s.xml')|document('../Register/bibliography/bibliography-t.xml')|document('../Register/bibliography/bibliography-u.xml')|document('../Register/bibliography/bibliography-v.xml')|document('../Register/bibliography/bibliography-w.xml')|document('../Register/bibliography/bibliography-xyz.xml'))//tei:bibl[@xml:id eq $biblid]/tei:seg/normalize-space()"/>
                                        </a>
                                    </li>
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:listBibl[@type = 'references']">
                        <div class="litcontainer">
                            <h2>Literatur</h2>
                            <ul>
                                <xsl:for-each select="tei:listBibl[@type = 'references']/tei:bibl">
                                    <!--<xsl:sort select="tei:ptr/@target"/>-->
                                    <li>
                                        <a>
                                            <xsl:variable name="biblid" select="substring-after(tei:ptr/@target, ':')"/>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="concat($litpath, $biblid, '.xhtml')"/>
                                            </xsl:attribute>
                                            <xsl:value-of select="(document('../Register/bibliography/bibliography-a.xml')|document('../Register/bibliography/bibliography-b.xml')|document('../Register/bibliography/bibliography-c.xml')|document('../Register/bibliography/bibliography-d.xml')|document('../Register/bibliography/bibliography-e.xml')|document('../Register/bibliography/bibliography-f.xml')|document('../Register/bibliography/bibliography-g.xml')|document('../Register/bibliography/bibliography-h.xml')|document('../Register/bibliography/bibliography-i.xml')|document('../Register/bibliography/bibliography-j.xml')|document('../Register/bibliography/bibliography-k.xml')|document('../Register/bibliography/bibliography-l.xml')|document('../Register/bibliography/bibliography-m.xml')|document('../Register/bibliography/bibliography-n.xml')|document('../Register/bibliography/bibliography-o.xml')|document('../Register/bibliography/bibliography-p.xml')|document('../Register/bibliography/bibliography-qr.xml')|document('../Register/bibliography/bibliography-s.xml')|document('../Register/bibliography/bibliography-t.xml')|document('../Register/bibliography/bibliography-u.xml')|document('../Register/bibliography/bibliography-v.xml')|document('../Register/bibliography/bibliography-w.xml')|document('../Register/bibliography/bibliography-xyz.xml'))//tei:bibl[@xml:id eq $biblid]/tei:seg/normalize-space()"/>
                                        </a>
                                        <xsl:choose>
                                            <xsl:when test="tei:citedRange[not(@target)]">
                                                <xsl:text>, </xsl:text>
                                                <xsl:value-of select="."/>
                                            </xsl:when>
                                            <xsl:when test="tei:citedRange[@target]">
                                                <xsl:text>, </xsl:text>
                                                <a>
                                                    <xsl:attribute name="href" select="tei:citedRange/@target"/>
                                                    <xsl:value-of select="."/>
                                                </a>
                                            </xsl:when>
                                        </xsl:choose>
                                    </li>
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:listBibl[@type = 'occurrences']/tei:bibl/text()">
                        <div class="occurrencescontainer">
                            <h2>Vorkommen im Text</h2>
                            <ul>
                                <xsl:choose>
                                    <xsl:when test="tei:listBibl[@type = 'occurrences'][@subtype]/tei:bibl/text()">
                                        <xsl:for-each select="tei:listBibl[@type = 'occurrences'][@subtype]/tei:bibl">
                                            <xsl:variable name="pagenum" select="substring-before(substring-after(., 'fol. '), ':')"/>
                                            <li>
                                                <a>
                                                    <xsl:attribute name="href">
                                                        
                                                        <xsl:value-of select="concat($transcrpath, replace(replace(replace(replace(replace(substring-before(lower-case(.),', fol. '),'[\s|/]',''),'ü','ue'),'ä','ae'),'ö','oe'),'–','_'), '.xhtml#fol', $pagenum)"/>                                                                                                                              
                                                    </xsl:attribute>
                                                    <xsl:value-of select="text()"/>
                                                </a>
                                                <xsl:apply-templates select="tei:biblScope"/>
                                            </li>
                                        </xsl:for-each>
                                    </xsl:when>
                                    <xsl:when test="tei:listBibl[@type = 'occurrences'][not(@subtype)]/tei:bibl/text()">
                                        <xsl:for-each select="tei:listBibl[@type = 'occurrences'][not(@subtype)]/tei:bibl">
                                            <xsl:sort select="substring-before(.,'fol.')"/>
                                            <xsl:sort select="replace(.,'.*fol\.\s([0-9]+).*','$1')" data-type="number"/>
                                            <xsl:variable name="pagenum" select="substring-after(., 'fol. ')"/>
                                            <li>
                                                <a>
                                                    <xsl:attribute name="href">
                                                        
                                                        <xsl:value-of select="concat($transcrpath, replace(replace(replace(replace(replace(substring-before(lower-case(.),', fol. '),'[\s|/]',''),'ü','ue'),'ä','ae'),'ö','oe'),'–','_'), '.xhtml#fol', $pagenum)"/>         
                                                    </xsl:attribute>
                                                    <xsl:value-of select="."/>
                                                </a>
                                            </li>
                                        </xsl:for-each>
                                    </xsl:when>
                                </xsl:choose>
                            </ul>
                        </div></xsl:if>
                    
                </body>
            </html>
        </xsl:result-document>
    </xsl:template>
    
    <xsl:template match="tei:biblScope">
        <span xmlns="http://www.w3.org/1999/xhtml" class="snippet">
            <xsl:apply-templates/>
        </span>
    </xsl:template>
    
    <xsl:template match="tei:rs">
        <xsl:choose>
            <xsl:when test="@type = 'person'">
                <a xmlns="http://www.w3.org/1999/xhtml">
                    <xsl:attribute name="href">
                        <xsl:value-of select="concat(substring-after(@ref, '#'), '.xhtml')"/>
                    </xsl:attribute>
                    <xsl:apply-templates/>
                </a>
            </xsl:when>
            <xsl:when test="@type = 'place'">
                <a xmlns="http://www.w3.org/1999/xhtml">
                    <xsl:attribute name="href">
                        <xsl:value-of select="concat($plcpath, substring-after(@ref, 'plc:'), '.xhtml')"/>
                    </xsl:attribute>
                    <xsl:apply-templates/>
                </a>
            </xsl:when>
            <xsl:when test="@type = 'org'">
                <a xmlns="http://www.w3.org/1999/xhtml">
                    <xsl:attribute name="href">
                        <xsl:value-of select="concat($orgpath, substring-after(@ref, 'org:'), '.xhtml')"/>
                    </xsl:attribute>
                    <xsl:apply-templates/>
                </a>
            </xsl:when>
            <xsl:when test="@type = 'work'">
                <a xmlns="http://www.w3.org/1999/xhtml">
                    <xsl:attribute name="href">
                        <xsl:value-of select="concat($wrkpath, substring-after(@ref, 'wrk:'), '.xhtml')"/>
                    </xsl:attribute>
                    <xsl:apply-templates/>
                </a>
            </xsl:when>
            <xsl:when test="@type = 'quote'">
                <span xmlns="http://www.w3.org/1999/xhtml" class="rs">
                    <xsl:value-of select="."/>
                </span>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="tei:note//tei:bibl/tei:ref">
        <a xmlns="http://www.w3.org/1999/xhtml">
            <xsl:attribute name="href">
                <xsl:value-of select="concat($litpath, substring-after(@target, 'lit:'), '.xhtml')"/>
            </xsl:attribute>
            <xsl:apply-templates/>
        </a>
    </xsl:template>
    
    <xsl:template match="tei:note//tei:bibl/tei:citedRange">
        <a xmlns="http://www.w3.org/1999/xhtml">
            <xsl:attribute name="href">
                <xsl:value-of select="@target"/>
            </xsl:attribute>
            <xsl:apply-templates/>
        </a>
    </xsl:template>
    
    <xsl:template match="tei:note/tei:p//tei:ref[not(parent::tei:bibl)]">
        <a xmlns="http://www.w3.org/1999/xhtml">
            <xsl:attribute name="href">
                <xsl:value-of select="@target"/>
            </xsl:attribute>
            <xsl:apply-templates/>
        </a>
    </xsl:template>
    
    <xsl:template match="tei:note//tei:ref[not(parent::tei:bibl)]">
        <a xmlns="http://www.w3.org/1999/xhtml">
            <xsl:attribute name="href">
                <xsl:value-of select="@target"/>
            </xsl:attribute>
            <xsl:apply-templates/>
        </a>
    </xsl:template>
    
    <xsl:template match="tei:p">
        <p xmlns="http://www.w3.org/1999/xhtml">
            <xsl:apply-templates/>
        </p>
    </xsl:template>
    
    <xsl:template match="tei:hi[@rendition = '#i']">
        <span xmlns="http://www.w3.org/1999/xhtml" class="italics">
            <xsl:apply-templates/>
        </span>
    </xsl:template>
    
</xsl:stylesheet>