<?xml version="1.0" encoding="UTF-8"?>
<!-- Dieses Stylesheet erzeugt den XHTML-Code für https://hainhofer.hab.de/register/klassifikation-zum-personenregister - eine Unterteilung des Personenregisters in die Berufskategorien im weitesten Sinn (Künstler - Architektur, Künstler - Malerei, Mythologischer Personen usw.) -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:tei="http://www.tei-c.org/ns/1.0" xmlns:xhtml="http://www.w3.org/1999/xhtml" version="2.0" exclude-result-prefixes="tei xs xhtml">
    <xsl:strip-space elements="*"/>
    <xsl:variable name="psnpath">https://hainhofer.hab.de/register/personen/</xsl:variable>
    
    <xsl:template match="/">
        <xsl:result-document href="../HTML-Dateien/psnklassen.xhtml">
            <html xmlns="http://www.w3.org/1999/xhtml">
                <head>                
                    <title>Klassifikation zum Personenregister</title>
                </head>
                <body>                
                    <ul>
                        <xsl:if test="//tei:TEI/tei:teiHeader/tei:encodingDesc/tei:classDecl/tei:taxonomy/tei:category/tei:category">
                            <xsl:for-each select="//tei:TEI/tei:teiHeader/tei:encodingDesc/tei:classDecl/tei:taxonomy/tei:category[tei:category]">
                                <li>
                                    <xsl:value-of select="tei:catDesc"/>
                                    <ul>
                                        <xsl:for-each select="tei:category">
                                            <xsl:variable name="catid" select="@xml:id"/>                            
                                            <li>
                                                <a>
                                                    <xsl:attribute name="href">
                                                        <xsl:value-of select="concat('#', $catid)"/>
                                                    </xsl:attribute>                                
                                                    <xsl:value-of select="tei:catDesc"/>
                                                </a>                           
                                            </li>
                                        </xsl:for-each>
                                    </ul>
                                </li>
                            </xsl:for-each>
                        </xsl:if>
                        
                        <xsl:for-each select="//tei:TEI/tei:teiHeader/tei:encodingDesc/tei:classDecl/tei:taxonomy/tei:category[not(./tei:category)]">
                            <xsl:variable name="catid" select="@xml:id"/>
                            <li>
                                <a>
                                    <xsl:attribute name="href">
                                        <xsl:value-of select="concat('#', $catid)"/>
                                    </xsl:attribute>                                
                                    <xsl:value-of select="tei:catDesc"/>
                                </a>                           
                            </li>
                        </xsl:for-each>
                    </ul>
                    <xsl:apply-templates select="tei:TEI/tei:text/tei:body/tei:listPerson"/>
                </body>
            </html>
        </xsl:result-document>
    </xsl:template>
    
    <xsl:template match="tei:listPerson">       
        <xsl:for-each select="//tei:TEI/tei:teiHeader/tei:encodingDesc/tei:classDecl/tei:taxonomy/tei:category[not(./tei:category)]|//tei:TEI/tei:teiHeader/tei:encodingDesc/tei:classDecl/tei:taxonomy/tei:category/tei:category">
            <xsl:variable name="catid" select="@xml:id"/>
            
            <h2 xmlns="http://www.w3.org/1999/xhtml">
                <xsl:attribute name="id">
                    <xsl:value-of select="$catid"/>
                </xsl:attribute>
                <xsl:if test="parent::tei:category">
                    <xsl:value-of select="parent::tei:category/tei:catDesc"/>
                    <xsl:text>: </xsl:text>
                </xsl:if>
                <xsl:value-of select="tei:catDesc"/>
            </h2>
            <ul xmlns="http://www.w3.org/1999/xhtml">
                <xsl:apply-templates select="(document('../Register/register-person/register-person-a.xml')|document('../Register/register-person/register-person-b.xml')|document('../Register/register-person/register-person-c.xml')|document('../Register/register-person/register-person-d.xml')|document('../Register/register-person/register-person-e.xml')|document('../Register/register-person/register-person-f.xml')|document('../Register/register-person/register-person-g.xml')|document('../Register/register-person/register-person-h.xml')|document('../Register/register-person/register-person-i.xml')|document('../Register/register-person/register-person-j.xml')|document('../Register/register-person/register-person-k.xml')|document('../Register/register-person/register-person-l.xml')|document('../Register/register-person/register-person-m.xml')|document('../Register/register-person/register-person-n.xml')|document('../Register/register-person/register-person-o.xml')|document('../Register/register-person/register-person-p.xml')|document('../Register/register-person/register-person-qr.xml')|document('../Register/register-person/register-person-s.xml')|document('../Register/register-person/register-person-t.xml')|document('../Register/register-person/register-person-u.xml')|document('../Register/register-person/register-person-v.xml')|document('../Register/register-person/register-person-w.xml')|document('../Register/register-person/register-person-xyz.xml'))//tei:person[tei:occupation[@code eq concat('#', $catid)]]">
                    <xsl:sort select="tei:persName[@type='preferred']/tei:term/@sortKey"/>
                </xsl:apply-templates>
            </ul>              
        </xsl:for-each>
        
    </xsl:template>
    
    <xsl:template match="tei:person">
        <li xmlns="http://www.w3.org/1999/xhtml">
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="concat($psnpath, @xml:id)"/>
                </xsl:attribute>             
                
                <xsl:choose>
                    <xsl:when test="tei:persName[@type = 'preferred']/tei:term/tei:forename">
                        <xsl:value-of select="tei:persName[@type = 'preferred']/tei:term/tei:surname"/>
                        <xsl:if test="tei:persName[@type = 'preferred']/tei:term/tei:surname[not(text())]">
                            <xsl:text>?</xsl:text>    
                        </xsl:if>
                        <xsl:text>, </xsl:text>
                        <xsl:value-of select="tei:persName[@type = 'preferred']/tei:term/tei:forename"/>
                        <xsl:if test="tei:persName[@type = 'preferred']/tei:term/tei:forename[not(text())]">
                            <xsl:text>?</xsl:text>    
                        </xsl:if>
                        
                        <!-- Disambiguierung durch Lebensdaten: -->
                        <xsl:if test="(preceding::tei:person|following::tei:person)[tei:persName[@type='preferred']/tei:term/tei:surname eq current()/tei:persName[@type='preferred']/tei:term/tei:surname][tei:persName[@type='preferred']/tei:term/tei:forename eq current()/tei:persName[@type='preferred']/tei:term/tei:forename]">
                            <span class="birthdeath">
                                <xsl:text> (</xsl:text>
                                
                                <xsl:if test="tei:birth">
                                    <xsl:text>* </xsl:text>
                                </xsl:if>
                                <xsl:if test="tei:birth/@precision eq 'low' and ../tei:birth/@when-iso">
                                    <xsl:text>ca. </xsl:text>
                                </xsl:if>
                                <xsl:choose>
                                    <xsl:when test="tei:birth/@when-iso">
                                        <xsl:choose>
                                            <xsl:when test="substring(tei:birth/@when-iso, 1, 1) = '-'">
                                                <xsl:value-of select="number(substring-after(../tei:birth/@when-iso, '-')) + 1"/>
                                                <xsl:text> v. Chr.</xsl:text>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="number(tei:birth/@when-iso)"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:when>
                                    <xsl:when test="tei:birth/@notBefore-iso and tei:birth/@notAfter-iso">
                                        <xsl:text>zwischen </xsl:text>
                                        <xsl:if test="tei:birth/@precision eq 'low'">
                                            <xsl:text>ca. </xsl:text>
                                        </xsl:if>
                                        <xsl:choose>
                                            <xsl:when test="substring(tei:birth/@notBefore-iso, 1, 1) = '-'">
                                                <xsl:value-of select="number(substring-after(tei:birth/@notBefore-iso, '-')) + 1"/>
                                                <xsl:if test="substring(tei:birth/@notAfter-iso, 1, 1) != '-'">
                                                    <xsl:text> v. Chr.</xsl:text>
                                                </xsl:if>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="number(tei:birth/@notBefore-iso)"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                        <xsl:text> und </xsl:text>
                                        <xsl:choose>
                                            <xsl:when test="substring(tei:birth/@notAfter-iso, 1, 1) = '-'">
                                                <xsl:value-of select="number(substring-after(tei:birth/@notAfter-iso, '-')) + 1"/>
                                                <xsl:text> v. Chr.</xsl:text>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="number(tei:birth/@notAfter-iso)"/>
                                                <xsl:if test="substring(tei:birth/@notBefore-iso, 1, 1) = '-'">
                                                    <xsl:text> n. Chr.</xsl:text>
                                                </xsl:if>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:when>
                                    <xsl:when test="tei:floruit">
                                        <xsl:value-of select="tei:floruit"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:text>* ?</xsl:text>
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:if test="not(tei:floruit)">
                                    <xsl:text>, ✝ </xsl:text>
                                </xsl:if>
                                <xsl:if test="tei:death/@precision eq 'low' and tei:death/@when-iso">
                                    <xsl:text>ca. </xsl:text>
                                </xsl:if>
                                
                                <xsl:choose>
                                    <xsl:when test="tei:death/@when-iso">
                                        <xsl:choose>
                                            <xsl:when test="substring(tei:death/@when-iso, 1, 1) = '-'">
                                                <xsl:value-of select="number(substring-after(tei:death/@when-iso, '-')) + 1"/>
                                                <xsl:text> v. Chr.</xsl:text>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="number(tei:death/@when-iso)"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:when>
                                    <xsl:when test="tei:death/@notBefore-iso and tei:death/@notAfter-iso">
                                        <xsl:text>zwischen </xsl:text>
                                        <xsl:if test="tei:death/@precision eq 'low'">
                                            <xsl:text>ca. </xsl:text>
                                        </xsl:if>
                                        <xsl:choose>
                                            <xsl:when test="substring(tei:death/@notBefore-iso, 1, 1) = '-'">
                                                <xsl:value-of select="number(substring-after(tei:death/@notBefore-iso, '-')) + 1"/>
                                                <xsl:if test="substring(tei:death/@notAfter-iso, 1, 1) != '-'">
                                                    <xsl:text> v. Chr.</xsl:text>
                                                </xsl:if>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="number(tei:death/@notBefore-iso)"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                        <xsl:text> und </xsl:text>
                                        <xsl:choose>
                                            <xsl:when test="substring(tei:death/@notAfter-iso, 1, 1) = '-'">
                                                <xsl:value-of select="number(substring-after(tei:death/@notAfter-iso, '-')) + 1"/>
                                                <xsl:text> v. Chr.</xsl:text>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="number(tei:death/@notAfter-iso)"/>
                                                <xsl:if test="substring(tei:death/@notBefore-iso, 1, 1) = '-'">
                                                    <xsl:text> n. Chr.</xsl:text>
                                                </xsl:if>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:when>
                                    <xsl:when test="tei:floruit"/>
                                    <xsl:otherwise>
                                        <xsl:text>?</xsl:text>
                                    </xsl:otherwise>
                                </xsl:choose>
                                
                                <xsl:text>)</xsl:text>
                            </span>
                        </xsl:if>                                    
                        <!-- Disambiguierung Ende -->
                        
                    </xsl:when>
                    <xsl:when test="tei:persName[@type = 'preferred']/tei:term/tei:name">
                        
                        <!-- Disambiguierung durch Lebensdaten: -->
                        <xsl:choose>
                            <xsl:when test="(preceding::tei:person|following::tei:person)[tei:persName[@type='preferred']/tei:term/tei:sname eq current()/tei:term/tei:name]">
                                <xsl:value-of select="tei:persName[@type='preferred']/tei:term/tei:name/normalize-space()"/>
                                <span class="birthdeath">
                                    <xsl:text> (</xsl:text>
                                    
                                    <xsl:if test="tei:birth">
                                        <xsl:text>* </xsl:text>
                                    </xsl:if>
                                    <xsl:if test="tei:birth/@precision eq 'low' and tei:birth/@when-iso">
                                        <xsl:text>ca. </xsl:text>
                                    </xsl:if>
                                    <xsl:choose>
                                        <xsl:when test="tei:birth/@when-iso">
                                            <xsl:choose>
                                                <xsl:when test="substring(tei:birth/@when-iso, 1, 1) = '-'">
                                                    <xsl:value-of select="number(substring-after(tei:birth/@when-iso, '-')) + 1"/>
                                                    <xsl:text> v. Chr.</xsl:text>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="number(tei:birth/@when-iso)"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:when>
                                        <xsl:when test="tei:birth/@notBefore-iso and tei:birth/@notAfter-iso">
                                            <xsl:text>zwischen </xsl:text>
                                            <xsl:if test="tei:birth/@precision eq 'low'">
                                                <xsl:text>ca. </xsl:text>
                                            </xsl:if>
                                            <xsl:choose>
                                                <xsl:when test="substring(tei:birth/@notBefore-iso, 1, 1) = '-'">
                                                    <xsl:value-of select="number(substring-after(../tei:birth/@notBefore-iso, '-')) + 1"/>
                                                    <xsl:if test="substring(tei:birth/@notAfter-iso, 1, 1) != '-'">
                                                        <xsl:text> v. Chr.</xsl:text>
                                                    </xsl:if>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="number(tei:birth/@notBefore-iso)"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                            <xsl:text> und </xsl:text>
                                            <xsl:choose>
                                                <xsl:when test="substring(tei:birth/@notAfter-iso, 1, 1) = '-'">
                                                    <xsl:value-of select="number(substring-after(tei:birth/@notAfter-iso, '-')) + 1"/>
                                                    <xsl:text> v. Chr.</xsl:text>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="number(tei:birth/@notAfter-iso)"/>
                                                    <xsl:if test="substring(tei:birth/@notBefore-iso, 1, 1) = '-'">
                                                        <xsl:text> n. Chr.</xsl:text>
                                                    </xsl:if>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:when>
                                        <xsl:when test="tei:floruit">
                                            <xsl:value-of select="tei:floruit"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:text>* ?</xsl:text>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                    <xsl:if test="not(tei:floruit)">
                                        <xsl:text>, ✝ </xsl:text>
                                    </xsl:if>
                                    <xsl:if test="tei:death/@precision eq 'low' and tei:death/@when-iso">
                                        <xsl:text>ca. </xsl:text>
                                    </xsl:if>
                                    
                                    <xsl:choose>
                                        <xsl:when test="tei:death/@when-iso">
                                            <xsl:choose>
                                                <xsl:when test="substring(tei:death/@when-iso, 1, 1) = '-'">
                                                    <xsl:value-of select="number(substring-after(tei:death/@when-iso, '-')) + 1"/>
                                                    <xsl:text> v. Chr.</xsl:text>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="number(tei:death/@when-iso)"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:when>
                                        <xsl:when test="tei:death/@notBefore-iso and tei:death/@notAfter-iso">
                                            <xsl:text>zwischen </xsl:text>
                                            <xsl:if test="tei:death/@precision eq 'low'">
                                                <xsl:text>ca. </xsl:text>
                                            </xsl:if>
                                            <xsl:choose>
                                                <xsl:when test="substring(tei:death/@notBefore-iso, 1, 1) = '-'">
                                                    <xsl:value-of select="number(substring-after(tei:death/@notBefore-iso, '-')) + 1"/>
                                                    <xsl:if test="substring(tei:death/@notAfter-iso, 1, 1) != '-'">
                                                        <xsl:text> v. Chr.</xsl:text>
                                                    </xsl:if>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="number(tei:death/@notBefore-iso)"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                            <xsl:text> und </xsl:text>
                                            <xsl:choose>
                                                <xsl:when test="substring(tei:death/@notAfter-iso, 1, 1) = '-'">
                                                    <xsl:value-of select="number(substring-after(tei:death/@notAfter-iso, '-')) + 1"/>
                                                    <xsl:text> v. Chr.</xsl:text>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="number(tei:death/@notAfter-iso)"/>
                                                    <xsl:if test="substring(tei:death/@notBefore-iso, 1, 1) = '-'">
                                                        <xsl:text> n. Chr.</xsl:text>
                                                    </xsl:if>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:when>
                                        <xsl:when test="tei:floruit"/>
                                        <xsl:otherwise>
                                            <xsl:text>?</xsl:text>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                    
                                    <xsl:text>)</xsl:text>
                                </span>
                            </xsl:when>
                            <!-- Disambiguierung Ende -->
                        
                            <xsl:otherwise>
                                <xsl:value-of select="tei:persName[@type='preferred']/tei:term/normalize-space()"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                </xsl:choose> 
            </a>
        </li>
    </xsl:template>
    
</xsl:stylesheet>
