<?xml version="1.0" encoding="UTF-8"?>
<!--Dieses Stylesheet wird in Oxygen-Transformationsszenarien verwendet, um aus der TEI/XML-Datei eines Reiseberichts eine PDF-Datei zu erzeugen.-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:tei="http://www.tei-c.org/ns/1.0" exclude-result-prefixes="xs fo" version="2.0">    
    
    <xsl:template name="start">
        <xsl:apply-templates select="tei:TEI" mode="step1"/>
    </xsl:template>
    
    <xsl:variable name="step1">
        <xsl:call-template name="start"/>
    </xsl:variable>
    
    <xsl:variable name="step2">
        <xsl:apply-templates select="$step1" mode="step2"/>
    </xsl:variable>
    
    <xsl:template match="/">
        <xsl:variable name="output">
            <xsl:sequence select="$step2"/>
        </xsl:variable>
        
        <xsl:apply-templates mode="step3" select="$output"/>            
        
    </xsl:template>
    
    <xsl:template match="@*|node()" mode="step1">
        <xsl:copy>
            <xsl:apply-templates select="@*|node()" mode="step1"/>
        </xsl:copy>
    </xsl:template>
    
    <!-- Zunächst werden die tei:pb-Elemente expandiert: -->
    <xsl:template match="tei:p" mode="step1">
        <xsl:choose>
            <xsl:when test="tei:pb">
                <xsl:for-each-group select="node()" group-starting-with="tei:pb">
                    <!-- Copies the only lb in the group first (N.B the first group does not contain lb) --><!-- Quelle: https://wiki.tei-c.org/index.php/MilestoneXSLT -->
                    <xsl:sequence select="current-group()/descendant-or-self::tei:pb"/>
                    <p xmlns="http://www.tei-c.org/ns/1.0">
                        <xsl:sequence select="current()/ancestor::matched-element/@*"/>
                        <!-- Copies the elements in the group except lb -->
                        <xsl:sequence select="current-group()[not(self::tei:pb)]"/>
                    </p>
                </xsl:for-each-group>
            </xsl:when>
            <xsl:otherwise>
                <xsl:sequence select="."/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="@*|node()" mode="step2">
        <xsl:copy>
            <xsl:apply-templates select="@*|node()" mode="step2"/>
        </xsl:copy>
    </xsl:template>
    
    <xsl:template match="tei:div" mode="step2">
        
        <div xmlns="http://www.tei-c.org/ns/1.0">
            
            <xsl:if test="@*">
                <xsl:attribute name="rend">
                    <xsl:value-of select="@rend"/>
                </xsl:attribute>
                <xsl:attribute name="hand">
                    <xsl:value-of select="@hand"/>
                </xsl:attribute>
                <xsl:if test="@corresp">
                    <xsl:attribute name="corresp">
                        <xsl:value-of select="@corresp"/>
                    </xsl:attribute>
                </xsl:if>
            </xsl:if>
            
            <xsl:choose>
                <xsl:when test="descendant::tei:pb">
                    
                    <xsl:for-each select=".//tei:pb">                        
                        <pb> 
                            <xsl:copy-of select="@*"/>
                            
                            <xsl:call-template name="continue">
                                <xsl:with-param name="next" select="following-sibling::*[1]" />
                            </xsl:call-template>                         
                        </pb>
                    </xsl:for-each>
                    
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates mode="step2"/>
                </xsl:otherwise>
            </xsl:choose>
        </div>
    </xsl:template>
    
    <xsl:template name="continue"> <!-- Quelle: http://www.tek-tips.com/viewthread.cfm?qid=1604222 -->
        <xsl:param name="next" />
        <xsl:choose>
            <xsl:when test="$next[self::tei:pb]">
                <!-- do nothing -->
            </xsl:when>
            <xsl:otherwise>
                <xsl:copy-of select="$next" />
                <xsl:if test="$next/following-sibling::*[not(self::tei:pb)]">
                    <xsl:call-template name="continue">
                        <xsl:with-param name="next" select="$next/following-sibling::*[1]" />
                    </xsl:call-template>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>    
    
    <xsl:template match="tei:p" mode="step2">
        <p xmlns="http://www.tei-c.org/ns/1.0">
            <xsl:apply-templates mode="step2"/>
        </p>
    </xsl:template>
    
    <!-- ********************************************** XSL-FO: ************************************* -->
    
    <xsl:template match="/" mode="step3">     
        <xsl:variable name="output2">
            <fo:root font-family="Open Sans, Arial Unicode MS">
                <fo:layout-master-set>
                    <fo:simple-page-master master-name="title" page-height="297mm" page-width="210mm" margin-top="3cm" margin-bottom="5cm" margin-left="3cm" margin-right="3cm">
                        <fo:region-body/>                  
                    </fo:simple-page-master>
                    <fo:simple-page-master master-name="A4" page-height="297mm" page-width="210mm" margin-top="1.5cm" margin-bottom="2cm" margin-left="1.5cm" margin-right="2cm">
                        <fo:region-body margin-top="1cm" column-count="3" column-gap="0.0cm"/>                                       
                        <fo:region-before extent="1cm"/>
                    </fo:simple-page-master>
                    <fo:simple-page-master master-name="register" page-height="297mm" page-width="210mm" margin-top="1.5cm" margin-bottom="2cm" margin-left="1.5cm" margin-right="2cm">
                        <fo:region-body margin-top="1cm" column-count="2" column-gap="1.0cm"/>
                        <fo:region-before extent="1cm"/>
                    </fo:simple-page-master>
                </fo:layout-master-set>
                
                <fo:page-sequence master-reference="title">
                    <fo:flow flow-name="xsl-region-body">
                        <fo:block-container font-family="serif">
                            <fo:block>                           
                                <xsl:choose>
                                    <xsl:when test="doc-available('file://///SERVER/handschriften/Projekte/Hainhofer/Edition/oxygen-projekt/hab-logo_schwarz.svg')">
                                        <fo:external-graphic src="url(file://///SERVER/handschriften/Projekte/Hainhofer/Edition/oxygen-projekt/hab-logo_schwarz.svg)" height="2cm"
                                            content-width="scale-to-fit" content-height="scale-to-fit"     />
                                    </xsl:when>
                                    <xsl:when test="doc-available('file://///SERVER/handschriften/Projekte/Hainhofer/Edition/oxygen-projekt/hab-logo_schwarz.svg')">
                                        <fo:external-graphic src="url(file://///SERVER/handschriften/Projekte/Hainhofer/Edition/oxygen-projekt/hab-logo_schwarz.svg)" height="2cm"
                                            content-width="scale-to-fit" content-height="scale-to-fit"     />
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:text>Herzog August Bibliothek Wolfenbüttel</xsl:text>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </fo:block>
                            <fo:block space-before="2cm" font-size="14pt">
                                <xsl:apply-templates select="//tei:titleStmt/tei:author" mode="step3"/>
                            </fo:block>
                            <fo:block font-style="italic" font-size="14pt">
                                <xsl:text>Reiseberichte &amp; Sammlungsbeschreibungen</xsl:text>
                            </fo:block>
                            <fo:block font-style="italic" font-size="14pt">
                                <xsl:text>1594–1636</xsl:text>
                            </fo:block>
                            <!-- <fo:block space-before="0.5cm">
                                <xsl:text>Edition und Datensammlung zur Kunst- und Kulturgeschichte der ersten Hälfte des 17. Jahrhunderts</xsl:text>
                                </fo:block>-->
                            <fo:block space-before="0.5cm" font-family="monospace" font-size="12pt">
                                <fo:basic-link external-destination="https://hainhofer.hab.de">hainhofer.hab.de</fo:basic-link>
                            </fo:block>
                            <fo:block space-before="2cm" font-size="16pt" font-weight="bold">
                                <xsl:apply-templates select="//tei:titleStmt/tei:title" mode="step3"/>
                            </fo:block>
                            <fo:block space-before="2cm">
                                <xsl:choose>
                                    <xsl:when test="contains(//tei:title, 'Wildbad/Heidelberg/Durlach 1615')">
                                        <xsl:value-of select="substring-before(//tei:sourceDesc/tei:msDesc/tei:msIdentifier/tei:repository,' / ')"/>
                                        <xsl:text>, </xsl:text>
                                        <xsl:value-of select="substring-before(//tei:sourceDesc/tei:msDesc/tei:msIdentifier/tei:idno,' / ')"/>
                                        <xsl:text> / </xsl:text>
                                        <xsl:value-of select="substring-after(//tei:sourceDesc/tei:msDesc/tei:msIdentifier/tei:repository,' / ')"/>
                                        <xsl:text>, </xsl:text>
                                        <xsl:value-of select="substring-after(//tei:sourceDesc/tei:msDesc/tei:msIdentifier/tei:idno,' / ')"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:apply-templates select="//tei:sourceDesc/tei:msDesc/tei:msIdentifier/tei:repository" mode="step3"/>
                                        <xsl:text>, </xsl:text>
                                        <xsl:apply-templates select="//tei:sourceDesc/tei:msDesc/tei:msIdentifier/tei:idno" mode="step3"/>
                                    </xsl:otherwise>
                                </xsl:choose>                                
                            </fo:block>
                            <xsl:if test="//tei:listWit">
                                <fo:block space-before="2cm">
                                    <xsl:text>Weitere Überlieferungen:</xsl:text>
                                </fo:block>
                            </xsl:if>
                            <xsl:for-each select="//tei:witness">
                                <fo:block line-height="150%">
                                    <xsl:choose>
                                        <xsl:when test="count(preceding-sibling::tei:witness) = 0">
                                            <xsl:text>(a) </xsl:text>
                                        </xsl:when>
                                        <xsl:when test="count(preceding-sibling::tei:witness) = 1">
                                            <xsl:text>(b) </xsl:text>
                                        </xsl:when>
                                        <xsl:when test="count(preceding-sibling::tei:witness) = 2">
                                            <xsl:text>(c) </xsl:text>
                                        </xsl:when>
                                        <xsl:when test="count(preceding-sibling::tei:witness) = 3">
                                            <xsl:text>(d) </xsl:text>
                                        </xsl:when>
                                        <xsl:when test="count(preceding-sibling::tei:witness) = 4">
                                            <xsl:text>(e) </xsl:text>
                                        </xsl:when>
                                        <xsl:when test="count(preceding-sibling::tei:witness) = 5">
                                            <xsl:text>(f) </xsl:text>
                                        </xsl:when>
                                        <xsl:when test="count(preceding-sibling::tei:witness) = 6">
                                            <xsl:text>(g) </xsl:text>
                                        </xsl:when>
                                        <xsl:when test="count(preceding-sibling::tei:witness) = 7">
                                            <xsl:text>(h) </xsl:text>
                                        </xsl:when>
                                        <xsl:when test="count(preceding-sibling::tei:witness) = 8">
                                            <xsl:text>(i) </xsl:text>
                                        </xsl:when>
                                        <xsl:when test="count(preceding-sibling::tei:witness) = 9">
                                            <xsl:text>(j) </xsl:text>
                                        </xsl:when>
                                    </xsl:choose>
                                    <xsl:value-of select="."/>
                                </fo:block>
                            </xsl:for-each>
                            <fo:block font-size="9pt">
                                <fo:footnote>     
                                    <fo:inline/>
                                    <fo:footnote-body>
                                        <xsl:variable name="heute" select="current-date()"/>
                                        <fo:block><xsl:text>Dieses PDF wurde erzeugt am </xsl:text><xsl:value-of select="format-date($heute,'[D1].[M1].[Y0001]')"/><xsl:text>.</xsl:text></fo:block>
                                        <fo:block space-before="0.5cm"><fo:basic-link external-destination="https://creativecommons.org/licenses/by-sa/4.0/">                                        
                                            <xsl:choose>
                                                <xsl:when test="doc-available('file://///SERVER/handschriften/Projekte/Hainhofer/Edition/oxygen-projekt/by-sa.svg')">
                                                    <fo:external-graphic src="url(file://///SERVER/handschriften/Projekte/Hainhofer/Edition/oxygen-projekt/by-sa.svg)" height="0.5cm"
                                                        content-width="scale-to-fit" content-height="scale-to-fit"     />
                                                </xsl:when>
                                                <xsl:when test="doc-available('file://///SERVER/handschriften/Projekte/Hainhofer/Edition/oxygen-projekt/by-sa.svg')">
                                                    <fo:external-graphic src="url(file://///SERVER/handschriften/Projekte/Hainhofer/Edition/oxygen-projekt/by-sa.svg)" height="0.5cm"
                                                        content-width="scale-to-fit" content-height="scale-to-fit"     />
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:text>CC BY-SA</xsl:text>
                                                </xsl:otherwise>
                                            </xsl:choose></fo:basic-link> 
                                            <xsl:text> Dieses Werk ist lizenziert unter einer </xsl:text><fo:basic-link external-destination="https://creativecommons.org/licenses/by-sa/4.0/">Creative Commons Namensnennung - Weitergabe unter gleichen Bedingungen 4.0 International Lizenz</fo:basic-link><xsl:text>.</xsl:text></fo:block></fo:footnote-body>                              
                                </fo:footnote>
                            </fo:block>
                        </fo:block-container>
                        
                    </fo:flow>
                </fo:page-sequence>
                
                <fo:page-sequence master-reference="A4">
                    <fo:static-content flow-name="xsl-footnote-separator">
                        <fo:block>
                            <fo:leader leader-pattern="rule" leader-length="100%"/>
                        </fo:block>
                    </fo:static-content>
                    <xsl:choose>
                        <xsl:when test="contains(//tei:title, 'Wildbad/Heidelberg/Durlach 1615')">
                            <fo:static-content flow-name="xsl-region-before">
                                <fo:block text-align="left">
                                    <xsl:value-of select="//tei:title"/>
                                </fo:block>
                            </fo:static-content>    
                        </xsl:when>
                        <xsl:otherwise>
                            <fo:static-content flow-name="xsl-region-before">
                                <fo:block text-align="left">
                                    <xsl:value-of select="//tei:title"/>
                                </fo:block>
                            </fo:static-content>    
                        </xsl:otherwise>
                        </xsl:choose>
                    <fo:flow flow-name="xsl-region-body">
                        <xsl:for-each select="//tei:pb[tei:p/node()]">
                            <fo:block-container>
                                <xsl:choose>
                                    <xsl:when test="matches(@n, '^fol. 74r$') and contains(//tei:title, 'München 1613')">
                                        <xsl:attribute name="width">2.3cm</xsl:attribute>
                                    </xsl:when>
                                    <xsl:when test="(matches(@n, '^fol. 18r$') and contains(//tei:title, 'München 1636')) or (matches(@n, '^fol. (15v|26v|29v)$') and contains(//tei:title, 'Eichstätt 1611'))">
                                        <xsl:attribute name="width">3.0cm</xsl:attribute>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:attribute name="width">4.3cm</xsl:attribute>
                                    </xsl:otherwise>
                                </xsl:choose>
                                
                                <xsl:if test="(matches(@n, '^fol. 199v-200r$') and contains(//tei:title, 'München 1611')) or (matches(@n, '^fol. 50v$') and contains(//tei:title, 'München 1636')) or (matches(@n, '(^fol\. 3[5-7][0-9]v-3[5-7][0-9]r$)') and contains(//tei:title, 'Wildbad/Heidelberg/Durlach 1615'))">
                                    <xsl:attribute name="break-after">page</xsl:attribute>
                                </xsl:if>
                                <fo:block text-align="justify" hyphenate="true" xml:lang="de">
                                    <xsl:for-each select=".//tei:note[@subtype != 'addition']">
                                        <fo:block line-height-shift-adjustment="disregard-shifts" margin-bottom="0.5em">
                                            <xsl:choose>
                                                <xsl:when test="(matches(ancestor::tei:pb/@n, '^fol. 199v-200r$') and contains(//tei:title, 'München 1611'))">                             
                                                    <xsl:attribute name="font-size">7.5pt</xsl:attribute>
                                                </xsl:when>                                                                                           
                                                
                                                <!-- vorläufig - kann wegfallen, wenn Stellenkommentar gekürzt wird: -->
                                                <xsl:when test="(matches(ancestor::tei:pb/@n, '^fol. (5r|15r|22v|23v|29v|34v|40v|56v)$') and contains(//tei:title, 'Eichstätt 1611')) or (matches(ancestor::tei:pb/@n, '^fol. (12v|18v|24v|31v|36r|39v|42r)$') and contains(//tei:title, 'Regensburg 1613')) or (matches(ancestor::tei:pb/@n, '^fol. (265r)$') and contains(//tei:title, 'Nürnberg 1612')) or (matches(ancestor::tei:pb/@n, '^fol. (166v)$') and contains(//tei:title, 'Neuburg 1614')) or (matches(ancestor::tei:pb/@n, '(^fol\. 250v$)') and contains(//tei:title, 'Wildbad/Heidelberg/Durlach 1615')) or (matches(ancestor::tei:pb/@n, '^fol. 229v01r$') and contains(//tei:title, 'Stuttgart 1616'))">                             
                                                    <xsl:attribute name="font-size">8pt</xsl:attribute>
                                                </xsl:when>                                                  
                                                <xsl:when test="(matches(ancestor::tei:pb/@n, '^fol. (72r|89r|90r|110v|112r|114v|118v|121r|123r|123v|126v04r)$') and contains(//tei:title, 'München 1613')) or (matches(ancestor::tei:pb/@n, '^fol. (50r|75r|118v-119r)$') and contains(//tei:title, 'München 1636')) or (matches(ancestor::tei:pb/@n, '^fol. (5r|22v|23v|29v|34v|40v|48r|56v)$') and contains(//tei:title, 'Eichstätt 1611')) or (matches(ancestor::tei:pb/@n, '^fol. 44r$') and contains(//tei:title, 'Regensburg 1613')) or (matches(ancestor::tei:pb/@n, '^fol. (258r|259r|263r|283r|283v|284r|284v|285r|285v|286r|287r|288r|288v|289r|289v|291r|291v|292r|293r|293v)$') and contains(//tei:title, 'Nürnberg 1612'))">                              
                                                    <xsl:attribute name="font-size">7.5pt</xsl:attribute>
                                                </xsl:when>    
                                                <xsl:when test="(matches(ancestor::tei:pb/@n, '^fol. (271v)$') and contains(//tei:title, 'Nürnberg 1612')) or (matches(ancestor::tei:pb/@n, '^fol. (164r)$') and contains(//tei:title, 'Neuburg 1614'))">                              
                                                    <xsl:attribute name="font-size">7pt</xsl:attribute>
                                                </xsl:when>
                                                <xsl:when test="(matches(ancestor::tei:pb/@n, '^fol. (75r|107v|126v04v)$') and contains(//tei:title, 'München 1613')) or (matches(ancestor::tei:pb/@n, '^fol. (11r|24r|26v|45v|46v|86r)$') and contains(//tei:title, 'Eichstätt 1611')) or (matches(ancestor::tei:pb/@n, '^fol. 30v$') and contains(//tei:title, 'Regensburg 1613')) or (matches(ancestor::tei:pb/@n, '^fol. (263v|271v|290r|292v|294v|295v)$') and contains(//tei:title, 'Nürnberg 1612')) or (matches(ancestor::tei:pb/@n, '(^fol\. 251v$)') and contains(//tei:title, 'Wildbad/Heidelberg/Durlach 1615'))">
                                                    <xsl:attribute name="font-size">6.5pt</xsl:attribute>       
                                                </xsl:when>
                                                <xsl:when test="matches(ancestor::tei:pb/@n, '^fol. 74r$') and contains(//tei:title, 'München 1613')">                             
                                                    <xsl:attribute name="font-size">6pt</xsl:attribute>
                                                </xsl:when>      
                                                <xsl:otherwise>
                                                    <xsl:attribute name="font-size">9pt</xsl:attribute>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                            
                                            <fo:inline font-size="60%" baseline-shift="super">
                                                <xsl:value-of select="count(preceding::tei:note[@subtype != 'addition']) + count(ancestor::tei:note[@subtype != 'addition']) + count(ancestor::tei:reg) + count(preceding::tei:reg) + 1"/>
                                            </fo:inline>
                                            <xsl:text> </xsl:text>
                                            <xsl:if test="@subtype = 'translation'">                                      
                                                <fo:inline font-family="sans-serif" font-style="italic">Übers.: </fo:inline>                                      
                                            </xsl:if>
                                            <xsl:apply-templates mode="step3"/>
                                        </fo:block>
                                    </xsl:for-each>
                                    <fo:leader/>
                                </fo:block>
                            </fo:block-container>
                            
                            <fo:block-container>
                                
                                <xsl:choose>
                                    <!-- reguläre Werte:
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="width">12.5cm</xsl:attribute>
                                        <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>
                                        <xsl:attribute name="wrap-option">no-wrap</xsl:attribute>
                                        <xsl:attribute name="font-size">10pt</xsl:attribute>
                                        </xsl>
                                    -->
                                    <xsl:when test="matches(@n, '(^fol. (15v|26v|29v)$)') and contains(//tei:title, 'Eichstätt 1611')">
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="width">14.0cm</xsl:attribute>
                                        <xsl:attribute name="height">29.0cm</xsl:attribute>
                                        <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
                                        <xsl:attribute name="margin-left">-1.0cm</xsl:attribute>
                                        <xsl:attribute name="font-size">6.8pt</xsl:attribute>
                                    </xsl:when>
                                    <xsl:when test="matches(@n, '(^fol. 128r$|^fol. 160v$)') and contains(//tei:title, 'München 1611')">
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="reference-orientation">-90</xsl:attribute>
                                        <xsl:attribute name="width">26.5cm</xsl:attribute>
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>
                                        <xsl:attribute name="margin-top">0.5cm</xsl:attribute>
                                        <xsl:attribute name="font-size">8pt</xsl:attribute>
                                    </xsl:when>                                    
                                    <xsl:when test="matches(@n, '^fol. 172v$') and contains(//tei:title, 'München 1611')">
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        
                                        <xsl:attribute name="width">11cm</xsl:attribute>
                                        
                                        <!--<xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>-->
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>
                                        <!--<xsl:attribute name="wrap-option">no-wrap</xsl:attribute>--> 
                                        <xsl:attribute name="font-size">8.5pt</xsl:attribute>                                   
                                        
                                        <xsl:attribute name="break-after">page</xsl:attribute>
                                        
                                        <!-- Die reguläre Folio-Angabe wird weiter unten deaktiviert. -->
                                        <fo:block-container break-before="column" margin-top="-1cm">
                                            <fo:block text-align="right" wrap-option="no-wrap" font-size="12pt">
                                                <fo:inline>
                                                    <xsl:text>HAB, </xsl:text>
                                                    <xsl:apply-templates select="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:msDesc/tei:msIdentifier/tei:idno" mode="step3"/>
                                                    <xsl:text>, </xsl:text>
                                                    <xsl:apply-templates select="@n" mode="step3"/>
                                                </fo:inline>
                                            </fo:block>
                                        </fo:block-container>
                                    </xsl:when>
                                    <xsl:when test="matches(@n, '^fol. 173r$') and contains(//tei:title, 'München 1611')">
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="reference-orientation">-90</xsl:attribute>
                                        <xsl:attribute name="width">26.5cm</xsl:attribute>
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>
                                        <xsl:attribute name="margin-top">0.5cm</xsl:attribute>
                                        <xsl:attribute name="font-size">8pt</xsl:attribute>
                                        <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
                                    </xsl:when>
                                    <xsl:when test="matches(@n, '(^fol. 176v$|^fol. 209r$|^fol. 210r$|^fol. 214r$|^fol. 215r$|^fol. 217r$|^fol. 219r$|^fol. 219v$)') and contains(//tei:title, 'München 1611')">
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="width">12.5cm</xsl:attribute>
                                        <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>
                                        <xsl:attribute name="font-size">10pt</xsl:attribute>
                                    </xsl:when>
                                    <xsl:when test="matches(@n, '^fol. 199v-200r$') and contains(//tei:title, 'München 1611') or (matches(@n, '^fol. 50v$') and contains(//tei:title, 'München 1636'))">
                                        <xsl:attribute name="reference-orientation">-90</xsl:attribute>
                                        <xsl:attribute name="width">27.7cm</xsl:attribute>
                                        <xsl:attribute name="font-size">5.8pt</xsl:attribute>
                                        <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
                                        <xsl:attribute name="margin-top">-0.5cm</xsl:attribute>
                                    </xsl:when>
                                    
                                    <xsl:when test="matches(@n, '(^fol\. 3[5-7][0-9]v-3[5-7][0-9]r$)') and contains(//tei:title, 'Wildbad/Heidelberg/Durlach 1615')">                                                
                                        <xsl:attribute name="width">13cm</xsl:attribute>                                                                                
                                        <xsl:attribute name="font-size">7pt</xsl:attribute>                                                                                
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>                                        
                                        <xsl:attribute name="wrap-option">wrap</xsl:attribute>   
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="break-after">page</xsl:attribute>
                                        <!-- Die reguläre Folio-Angabe wird weiter unten deaktiviert. -->                                        
                                        <fo:block-container break-before="column" margin-top="-1cm">
                                            <fo:block text-align="right" wrap-option="no-wrap" font-size="12pt">
                                                <fo:inline>
                                                    <xsl:text>HAB, Cod. Guelf. 83 Extrav., </xsl:text>
                                                    <xsl:apply-templates select="@n" mode="step3"/>
                                                </fo:inline>
                                            </fo:block>
                                        </fo:block-container>
                                    </xsl:when>  
                                    <xsl:when test="matches(@n, '(^fol\. 353r$)') and contains(//tei:title, 'Wildbad/Heidelberg/Durlach 1615')">                                                
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="width">12.5cm</xsl:attribute>
                                        <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>
                                        <xsl:attribute name="wrap-option">no-wrap</xsl:attribute>
                                        <xsl:attribute name="font-size">10pt</xsl:attribute>
                                        <xsl:attribute name="break-after">page</xsl:attribute>
                                        <!-- Die reguläre Folio-Angabe wird weiter unten deaktiviert. -->                                        
                                        <fo:block-container break-before="column" margin-top="-1cm">
                                            <fo:block text-align="right" wrap-option="no-wrap" font-size="12pt">
                                                <fo:inline>
                                                    <xsl:text>HAB, Cod. Guelf. 83 Extrav., </xsl:text>
                                                    <xsl:apply-templates select="@n" mode="step3"/>
                                                </fo:inline>
                                            </fo:block>
                                        </fo:block-container>
                                    </xsl:when>  
                                    
                                    <xsl:when test="matches(@n, '^fol. 208v$') and contains(//tei:title, 'München 1611') or (matches(@n, '^fol. (25r)$') and contains(//tei:title, 'Eichstätt 1611'))">
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="width">12.5cm</xsl:attribute>
                                        <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>
                                        <xsl:attribute name="wrap-option">no-wrap</xsl:attribute>
                                        <xsl:attribute name="font-size">8pt</xsl:attribute>
                                    </xsl:when>
                                    <xsl:when test="(matches(@n, '^fol. 211v-212r$') and contains(//tei:title, 'München 1611')) or matches(@n, '^fol. (32r$)') and contains(//tei:title, 'Eichstätt 1611')">  
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="width">13.5cm</xsl:attribute>
                                        <xsl:attribute name="height">29.0cm</xsl:attribute>
                                        <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>
                                        <xsl:attribute name="font-size">6.8pt</xsl:attribute>
                                    </xsl:when>                            
                                    <xsl:when test="matches(@n, '^fol. 74r$') and contains(//tei:title, 'München 1613')">  
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="width">13.5cm</xsl:attribute>                                    
                                        <xsl:attribute name="margin-left">-1.7cm</xsl:attribute>
                                        <xsl:attribute name="margin-top">-1.7cm</xsl:attribute>
                                        <xsl:attribute name="font-size">6pt</xsl:attribute>                                  
                                        <xsl:attribute name="wrap-option">wrap</xsl:attribute>         
                                        <xsl:attribute name="break-after">page</xsl:attribute>
                                        <!-- Die reguläre Folio-Angabe wird weiter unten deaktiviert. -->
                                        <fo:block-container break-before="column" margin-top="-1cm">
                                            <fo:block text-align="right" wrap-option="no-wrap" font-size="12pt">
                                                <fo:inline>
                                                    <xsl:text>HAB, </xsl:text>
                                                    <xsl:apply-templates select="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:msDesc/tei:msIdentifier/tei:idno" mode="step3"/>
                                                    <xsl:text>, </xsl:text>
                                                    <xsl:apply-templates select="@n" mode="step3"/>
                                                </fo:inline>
                                            </fo:block>
                                        </fo:block-container>
                                    </xsl:when>
                                    <xsl:when test="matches(@n, '^fol. 126v0(5v|6r)$') and contains(//tei:title, 'München 1613')">                             
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="width">12.5cm</xsl:attribute>
                                        <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>
                                        <xsl:attribute name="wrap-option">no-wrap</xsl:attribute>
                                        <xsl:attribute name="font-size">7.0pt</xsl:attribute>
                                        <xsl:attribute name="break-after">page</xsl:attribute>
                                        
                                        <!-- Die reguläre Folio-Angabe wird weiter unten deaktiviert. -->
                                        <fo:block-container break-before="column" margin-top="-1cm">
                                            <fo:block text-align="right" wrap-option="no-wrap" font-size="12pt">
                                                <fo:inline>
                                                    <xsl:text>HAB, </xsl:text>
                                                    <xsl:apply-templates select="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:msDesc/tei:msIdentifier/tei:idno" mode="step3"/>
                                                    <xsl:text>, </xsl:text>
                                                    <xsl:apply-templates select="@n" mode="step3"/>
                                                </fo:inline>
                                            </fo:block>
                                        </fo:block-container>
                                    </xsl:when>  
                                    <xsl:when test="matches(@n, '^fol. 126v04r$') and contains(//tei:title, 'München 1613')">          <!-- kombiniert mit 7.5pt für Randspalte, s.o. -->                
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="width">12.5cm</xsl:attribute>
                                        <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>
                                        <xsl:attribute name="wrap-option">no-wrap</xsl:attribute>
                                        <xsl:attribute name="font-size">8pt</xsl:attribute>                                    
                                    </xsl:when>
                                    <xsl:when test="(matches(@n, '^fol. (126v05r|126v09v-126v10r)$') and contains(//tei:title, 'München 1613')) or (matches(@n, '(^fol. 248v$)') and contains(//tei:title, 'Wildbad/Heidelberg/Durlach 1615'))">   
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="width">12.5cm</xsl:attribute>
                                        <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>
                                        <xsl:attribute name="wrap-option">no-wrap</xsl:attribute>
                                        <xsl:attribute name="font-size">8pt</xsl:attribute>                                    
                                    </xsl:when>
                                    <xsl:when test="(matches(@n, '^fol. (87v|126v0(3r|3v|4v))$') and contains(//tei:title, 'München 1613'))">                        <!-- bei 04v kombiniert mit 7.5pt für Randspalte, s.o. -->      
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="width">12.5cm</xsl:attribute>
                                        <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>
                                        <xsl:attribute name="wrap-option">no-wrap</xsl:attribute>
                                        <xsl:attribute name="font-size">9pt</xsl:attribute>  
                                    </xsl:when>     
                                    <xsl:when test="(matches(@n, '^fol. (75r|76r)$') and contains(//tei:title, 'München 1613')) or (matches(@n, '^fol. (265r|284r)$') and contains(//tei:title, 'Nürnberg 1612')) or (matches(@n, '^fol. (358r|359r)$') and contains(//tei:title, 'Neuburg 1613'))">  
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="width">12.5cm</xsl:attribute>                                    
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>
                                        <xsl:attribute name="font-size">10pt</xsl:attribute>                                  
                                        <xsl:attribute name="wrap-option">wrap</xsl:attribute>           
                                    </xsl:when>
                                    <xsl:when test="matches(@n, '^fol. 18r$') and contains(//tei:title, 'München 1636')">  
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="width">12.5cm</xsl:attribute>                                    
                                        <xsl:attribute name="margin-left">-1.3cm</xsl:attribute>
                                        <!--   <xsl:attribute name="margin-top">-0.3em</xsl:attribute>-->
                                        <xsl:attribute name="font-size">7pt</xsl:attribute>       
                                        <!--         <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>-->
                                        <xsl:attribute name="wrap-option">wrap</xsl:attribute>         
                                        <xsl:attribute name="break-after">page</xsl:attribute>
                                        <!-- Die reguläre Folio-Angabe wird weiter unten deaktiviert. -->
                                        <fo:block-container break-before="column" margin-top="-1cm">
                                            <fo:block text-align="right" wrap-option="no-wrap" font-size="12pt">
                                                <fo:inline>
                                                    <xsl:text>HAB, </xsl:text>
                                                    <xsl:apply-templates select="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:msDesc/tei:msIdentifier/tei:idno" mode="step3"/>
                                                    <xsl:text>, </xsl:text>
                                                    <xsl:apply-templates select="@n" mode="step3"/>
                                                </fo:inline>
                                            </fo:block>
                                        </fo:block-container>
                                    </xsl:when>
                                    <xsl:when test="matches(@n, '^fol. 50r$') and contains(//tei:title, 'München 1636')">
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="width">12.5cm</xsl:attribute>
                                        <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>
                                        <xsl:attribute name="wrap-option">no-wrap</xsl:attribute>
                                        <xsl:attribute name="font-size">7.5pt</xsl:attribute>                                    
                                    </xsl:when>        
                                    <!-- <xsl:when test="matches(@n, '^fol. 50v$') and contains(//tei:title, 'München 1636')">
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="reference-orientation">-90</xsl:attribute>
                                        <xsl:attribute name="width">27.7cm</xsl:attribute>
                                        <xsl:attribute name="font-size">7.0pt</xsl:attribute>
                                        <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
                                        <xsl:attribute name="margin-top">-0.5cm</xsl:attribute>                                 
                                        </xsl:when>     -->
                                    <xsl:when test="matches(@n, '^fol. 55v$') and contains(//tei:title, 'München 1636') or (matches(@n, '^fol. 229v08v$|^fol. 229v05v$') and contains(//tei:title, 'Stuttgart 1616'))">  
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="width">12.5cm</xsl:attribute>                                    
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>
                                        <xsl:attribute name="font-size">9pt</xsl:attribute>                                  
                                        <xsl:attribute name="wrap-option">wrap</xsl:attribute>           
                                    </xsl:when>           
                                    <xsl:when test="matches(@n, '^fol. 97r$') and contains(//tei:title, 'München 1636') or (matches(@n, '^fol. 229v07r$') and contains(//tei:title, 'Stuttgart 1616'))">  
                                        <xsl:attribute name="break-before">column</xsl:attribute> 
                                        <xsl:attribute name="width">12.5cm</xsl:attribute>                                     
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>
                                        <xsl:attribute name="font-size">8pt</xsl:attribute>                                  
                                        <xsl:attribute name="wrap-option">wrap</xsl:attribute>           
                                    </xsl:when>    
                                    <xsl:when test="((ancestor::tei:div/@hand = '#druckgraphik' or ancestor::tei:div/@hand = '#druckschrift') and contains(//tei:title, 'München 1636')) or (matches(@n, '^fol. (3v|28v|36r|48r|49r|49v|50r|50v|51r|51v|52r|52v|53r|53v|54r|54v|57r|58v|72v)$') and contains(//tei:title, 'Eichstätt 1611')) or ((ancestor::tei:div/@hand = '#druckgraphik') and contains(//tei:title, 'Regensburg 1613')) or (matches(@n, '^fol. 57v81r$') and contains(//tei:title, 'Regensburg 1613')) or (matches(@n, '^fol. 229v02r$') and contains(//tei:title, 'Stuttgart 1616'))">                                          
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="width">12.5cm</xsl:attribute>                                    
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>
                                        <xsl:attribute name="font-size">10pt</xsl:attribute>
                                        <!--<xsl:attribute name="linefeed-treatment">treat-as-space</xsl:attribute>-->
                                        <xsl:attribute name="wrap-option">wrap</xsl:attribute>                                    
                                    </xsl:when>
                                    <xsl:when test="matches(@n, '^fol. 111r$') and contains(//tei:title, 'München 1636')">
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="width">12.5cm</xsl:attribute>
                                        <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>
                                        <xsl:attribute name="wrap-option">no-wrap</xsl:attribute>
                                        <xsl:attribute name="font-size">9pt</xsl:attribute>
                                        
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:attribute name="break-before">column</xsl:attribute>
                                        <xsl:attribute name="width">12.5cm</xsl:attribute>
                                        <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
                                        <xsl:attribute name="margin-left">-0.5cm</xsl:attribute>
                                        <xsl:attribute name="wrap-option">no-wrap</xsl:attribute>
                                        <xsl:attribute name="font-size">10pt</xsl:attribute>
                                    </xsl:otherwise>
                                </xsl:choose>
                                
                                <xsl:choose>
                                    <xsl:when test="matches(@n, '^fol. 199v-200r$') and contains(//tei:title, 'München 1611')">
                                        
                                        <fo:block font-size="10pt" font-family="sans-serif" font-style="italic" margin-top="-11.5cm">[eingebundene Druckgraphik]</fo:block>
                                        
                                        <fo:block line-height-shift-adjustment="disregard-shifts" line-stacking-strategy="font-height" margin-top="0.5cm">
                                            <fo:table break-after="page">
                                                <fo:table-body>
                                                    <xsl:for-each select=".//tei:row[position() &lt; 15]">
                                                        <fo:table-row>
                                                            <xsl:apply-templates mode="step3"/>
                                                        </fo:table-row>
                                                    </xsl:for-each>
                                                </fo:table-body>
                                            </fo:table>
                                            <fo:leader/>
                                        </fo:block>
                                    </xsl:when>
                                    <xsl:when test="matches(@n, '^fol. 211v-212r$') and contains(//tei:title, 'München 1611')">
                                        
                                        <fo:block font-size="10pt" font-family="sans-serif" font-style="italic" margin-top="-2.0cm">[eingebundene Druckschrift]</fo:block>
                                        
                                        <fo:block line-height-shift-adjustment="disregard-shifts" line-stacking-strategy="font-height" margin-top="0.2cm">
                                            <xsl:for-each select="tei:p[position() &lt; 5]">
                                                <xsl:apply-templates mode="step3"/>
                                            </xsl:for-each>
                                            <fo:leader/>
                                        </fo:block>
                                    </xsl:when>
                                    <xsl:when test="matches(@n, '^fol. 50v$') and contains(//tei:title, 'München 1636')">
                                        
                                        <fo:block font-size="10pt" font-family="sans-serif" font-style="italic" margin-top="-12.0cm">[eingebundene Druckschrift]</fo:block>
                                        
                                        <fo:block line-height-shift-adjustment="disregard-shifts" line-stacking-strategy="font-height" margin-top="0.2cm">
                                            <fo:table break-after="page">
                                                <fo:table-body>
                                                    <xsl:for-each select=".//tei:row[position() &lt; 8]">
                                                        <fo:table-row>
                                                            <xsl:apply-templates mode="step3"/>
                                                        </fo:table-row>
                                                    </xsl:for-each>
                                                </fo:table-body>
                                            </fo:table>
                                            <fo:leader/>
                                        </fo:block>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        
                                        <xsl:choose>
                                            <xsl:when test="ancestor::tei:div/@hand = '#druckgraphik'">
                                                <fo:block font-size="10pt" font-family="sans-serif" font-style="italic">[eingebundene Druckgraphik]</fo:block>
                                            </xsl:when>
                                            <xsl:when test="ancestor::tei:div/@hand = '#druckschrift'">
                                                <fo:block font-size="10pt" font-family="sans-serif" font-style="italic">[eingebundene Druckschrift]</fo:block>
                                            </xsl:when>
                                            <xsl:when test="ancestor::tei:div/@hand = '#handzeichnung'">
                                                <fo:block font-size="10pt" font-family="sans-serif" font-style="italic">[eingebundene Handzeichnung]</fo:block>
                                            </xsl:when>
                                            <xsl:when test="(ancestor::tei:div/@hand = '#fremde_hand' or ancestor::tei:div/@hand = '#PH') and ancestor::tei:div/@rend = 'accMat'">
                                                <fo:block font-size="10pt" font-family="sans-serif" font-style="italic">[eingebundene Handschrift]</fo:block>
                                            </xsl:when>
                                        </xsl:choose>
                                        
                                        <fo:block line-height-shift-adjustment="disregard-shifts" line-stacking-strategy="font-height">                                        
                                            <xsl:apply-templates select="." mode="step3"/>
                                            <fo:leader/>
                                        </fo:block>
                                    </xsl:otherwise>
                                </xsl:choose>
                                
                                <xsl:if test=".//tei:app">
                                    <fo:block border-top-style="solid" font-family="Open Sans, Arial Unicode MS" wrap-option="wrap" font-size="8pt" padding="0.5em"> 
                                        <xsl:for-each select=".//tei:app">
                                            
                                            <fo:block linefeed-treatment="treat-as-space">
                                                <xsl:choose>
                                                    <xsl:when test="matches(ancestor::tei:pb/@n, '^fol. (11v|15v|29r|29v|35r)$') and contains(//tei:title, 'Eichstätt 1611')">
                                                        <xsl:attribute name="font-size">6.5pt</xsl:attribute>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:attribute name="padding-top">0.5em</xsl:attribute>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                                
                                                
                                                <xsl:apply-templates mode="app"/>
                                                
                                                <xsl:for-each select="tei:rdg">
                                                    <xsl:sort select="//tei:listWit/tei:witness[@xml:id eq substring(current()/@wit,2)]/count(preceding-sibling::tei:witness)"/>
                                                    <xsl:variable name="witid" select="substring-after(@wit, '#')"/>
                                                    <xsl:text> </xsl:text>
                                                    <xsl:choose>
                                                        <xsl:when test="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[@xml:id = $witid] = /tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[position() = 1]">
                                                            <fo:inline>(a)</fo:inline>
                                                        </xsl:when>
                                                        <xsl:when test="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[@xml:id = $witid] = /tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[position() = 2]">
                                                            <fo:inline>(b)</fo:inline>
                                                        </xsl:when>
                                                        <xsl:when test="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[@xml:id = $witid] = /tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[position() = 3]">
                                                            <fo:inline>(c)</fo:inline>
                                                        </xsl:when>
                                                        <xsl:when test="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[@xml:id = $witid] = /tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[position() = 4]">
                                                            <fo:inline>(d)</fo:inline>
                                                        </xsl:when>
                                                        <xsl:when test="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[@xml:id = $witid] = /tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[position() = 5]">
                                                            <fo:inline>(e)</fo:inline>
                                                        </xsl:when>
                                                        <xsl:when test="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[@xml:id = $witid] = /tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[position() = 6]">
                                                            <fo:inline>(f)</fo:inline>
                                                        </xsl:when>
                                                        <xsl:when test="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[@xml:id = $witid] = /tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[position() = 7]">
                                                            <fo:inline>(g)</fo:inline>
                                                        </xsl:when>
                                                        <xsl:when test="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[@xml:id = $witid] = /tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[position() = 8]">
                                                            <fo:inline>(h)</fo:inline>
                                                        </xsl:when>
                                                        <xsl:when test="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[@xml:id = $witid] = /tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[position() = 9]">
                                                            <fo:inline>(i)</fo:inline>
                                                        </xsl:when>
                                                        <xsl:when test="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[@xml:id = $witid] = /tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[position() = 10]">
                                                            <fo:inline>(j)</fo:inline>
                                                        </xsl:when>
                                                    </xsl:choose>
                                                    <xsl:text> </xsl:text>
                                                    <xsl:value-of select="@n"/>
                                                    <xsl:text>: </xsl:text>
                                                    <xsl:choose>
                                                        <xsl:when test=". = ''">
                                                            <fo:inline font-family="sans-serif" font-style="italic">[Zeichenfolge nicht vorhanden]</fo:inline>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <xsl:apply-templates mode="step3"/>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </xsl:for-each>
                                                
                                            </fo:block>
                                        </xsl:for-each>
                                    </fo:block>
                                </xsl:if>
                            </fo:block-container>
                            
                            <xsl:if test="matches(@n, '^fol. 199v-200r$') and contains(//tei:title, 'München 1611')">
                                <fo:block-container break-before="page">
                                    <xsl:attribute name="reference-orientation">-90</xsl:attribute>
                                    <xsl:attribute name="width">26.5cm</xsl:attribute>
                                    <xsl:attribute name="font-size">7pt</xsl:attribute>
                                    <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
                                    
                                    <fo:block font-size="10pt" font-family="sans-serif" font-style="italic" margin-top="-8cm">[eingebundene Druckgraphik]</fo:block>
                                    
                                    <fo:block line-height-shift-adjustment="disregard-shifts" line-stacking-strategy="font-height" margin-top="0.5cm">
                                        <fo:table>
                                            <fo:table-body>
                                                <xsl:for-each select=".//tei:row[position() &gt; 14]">
                                                    <fo:table-row>
                                                        <xsl:apply-templates mode="step3"/>
                                                    </fo:table-row>
                                                </xsl:for-each>
                                            </fo:table-body>
                                        </fo:table>
                                    </fo:block>
                                </fo:block-container>
                            </xsl:if>
                            
                            <xsl:if test="matches(@n, '^fol. 211v-212r$') and contains(//tei:title, 'München 1611')">
                                <fo:block-container break-before="page">
                                    <xsl:attribute name="width">12.5cm</xsl:attribute>
                                    <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
                                    <xsl:attribute name="margin-left">0</xsl:attribute>
                                    <xsl:attribute name="font-size">8pt</xsl:attribute>
                                    
                                    <fo:block font-size="10pt" font-family="sans-serif" font-style="italic">[eingebundene Druckschrift]</fo:block>
                                    
                                    <fo:block line-height-shift-adjustment="disregard-shifts" line-stacking-strategy="font-height" margin-top="0.5cm">
                                        <xsl:for-each select="tei:p[position() &gt; 4]">
                                            <xsl:apply-templates mode="step3"/>
                                        </xsl:for-each>
                                    </fo:block>
                                </fo:block-container>
                            </xsl:if>
                            
                            <xsl:if test="matches(@n, '^fol. 50v$') and contains(//tei:title, 'München 1636')">
                                <fo:block-container break-before="page">
                                    <xsl:attribute name="reference-orientation">-90</xsl:attribute>
                                    <xsl:attribute name="width">26.5cm</xsl:attribute>
                                    <xsl:attribute name="font-size">6.5pt</xsl:attribute>
                                    <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
                                    
                                    <fo:block font-size="10pt" font-family="sans-serif" font-style="italic" margin-top="-8cm">[eingebundene Druckgraphik]</fo:block>
                                    
                                    <fo:block line-height-shift-adjustment="disregard-shifts" line-stacking-strategy="font-height" margin-top="0.5cm">
                                        <fo:table>
                                            <fo:table-body>
                                                <xsl:for-each select=".//tei:row[position() &gt; 7]">
                                                    <fo:table-row>
                                                        <xsl:apply-templates mode="step3"/>
                                                    </fo:table-row>
                                                </xsl:for-each>
                                            </fo:table-body>
                                        </fo:table>
                                    </fo:block>
                                </fo:block-container>
                            </xsl:if>
                            
                            <xsl:if test="not(matches(@n, '^fol. 172v$') and contains(//tei:title, 'München 1611') or (matches(@n, '^fol. (74r|126v0(5v|6r))$') and contains(//tei:title, 'München 1613')) or (matches(@n, '^fol. 18r$') and contains(//tei:title, 'München 1636')) or (matches(@n, '(^fol\. 3[5-7][0-9])') and contains(//tei:title, 'Wildbad/Heidelberg/Durlach 1615') and contains(//tei:title, 'Wildbad/Heidelberg/Durlach 1615')))">
                                <fo:block-container break-before="column" break-after="page" margin-top="-1cm">
                                    <fo:block text-align="right" wrap-option="no-wrap">
                                        <fo:inline>
                                            <xsl:choose>
                                                <xsl:when test="contains(//tei:title, 'Wildbad/Heidelberg/Durlach 1615')">
                                                    <xsl:text>München, UB, 2° Cod. Ms. 403, </xsl:text>
                                                    <xsl:apply-templates select="@n" mode="step3"/>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:text>HAB, </xsl:text>
                                                    <xsl:apply-templates select="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:msDesc/tei:msIdentifier/tei:idno" mode="step3"/>
                                                    <xsl:text>, </xsl:text>
                                                    <xsl:apply-templates select="@n" mode="step3"/>
                                                </xsl:otherwise>
                                            </xsl:choose>                                            
                                        </fo:inline>
                                    </fo:block>
                                </fo:block-container>
                            </xsl:if>
                        </xsl:for-each>
                    </fo:flow>
                </fo:page-sequence>
                
                <xsl:call-template name="register">
                    <xsl:with-param name="reise">
                        <xsl:value-of select="//tei:title"/>
                    </xsl:with-param>
                </xsl:call-template>
                
            </fo:root>
        </xsl:variable>
        <xsl:apply-templates mode="step4" select="$output2"/>
    </xsl:template>
    
    <xsl:template match="tei:app" mode="step3">
        <xsl:apply-templates select="tei:lem" mode="step3"/>
        <fo:inline font-size="60%" baseline-shift="super">           
            <xsl:for-each select="tei:rdg">
                <xsl:sort select="//tei:listWit/tei:witness[@xml:id eq substring(current()/@wit,2)]/count(preceding-sibling::tei:witness)"/>
                <xsl:variable name="witid" select="substring-after(@wit, '#')"/>
                <xsl:choose>
                    <xsl:when test="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[@xml:id = $witid] = /tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[position() = 1]">
                        <xsl:text>a</xsl:text>
                    </xsl:when>
                    <xsl:when test="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[@xml:id = $witid] = /tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[position() = 2]">
                        <xsl:text>b</xsl:text>
                    </xsl:when>
                    <xsl:when test="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[@xml:id = $witid] = /tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[position() = 3]">
                        <xsl:text>c</xsl:text>
                    </xsl:when>
                    <xsl:when test="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[@xml:id = $witid] = /tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[position() = 4]">
                        <xsl:text>d</xsl:text>
                    </xsl:when>
                    <xsl:when test="/tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[@xml:id = $witid] = /tei:TEI/tei:teiHeader/tei:fileDesc/tei:sourceDesc/tei:listWit/tei:witness[position() = 5]">
                        <xsl:text>e</xsl:text>
                    </xsl:when>
                </xsl:choose>
            </xsl:for-each>
        </fo:inline>
    </xsl:template>
    
    <xsl:template match="tei:abbr/text()" mode="step3 app">
        <fo:inline font-family="Open Sans, Arial Unicode MS">
            <xsl:value-of select="normalize-space()"/>
        </fo:inline>
    </xsl:template>
    
    <xsl:template match="tei:abbr/tei:g/text()" mode="step3">
        <xsl:value-of select="normalize-space()"/>
    </xsl:template>
    
    <xsl:template match="tei:add" mode="step3">
        <xsl:text>&lt;</xsl:text>
        <xsl:apply-templates mode="step3"/> 
        <xsl:text>&gt;</xsl:text>
    </xsl:template>
    
    <xsl:template match="tei:cb" mode="step3">
        <xsl:text>&#xA;</xsl:text>
    </xsl:template>
    
    <xsl:template match="tei:corr" mode="step3">
        <xsl:choose>
            <xsl:when test="ancestor::tei:hi[@rendition = '#aq']">
                <fo:inline font-family="serif" font-style="italic">
                    <xsl:text>[d. i. </xsl:text>
                    <xsl:apply-templates mode="step3"/>
                    <xsl:text>]</xsl:text>
                </fo:inline>
            </xsl:when>
            <xsl:when test="ancestor::tei:foreign[@xml:lang = 'grc']">
                <fo:inline font-family="sans-serif" font-style="italic">
                    <xsl:text>[d. i. </xsl:text></fo:inline>
                <xsl:apply-templates mode="step3"/>
                <fo:inline font-family="sans-serif" font-style="italic"><xsl:text>]</xsl:text></fo:inline>
            </xsl:when>
            <xsl:otherwise>
                <fo:inline font-family="sans-serif" font-style="italic">
                    <xsl:text>[d. i. </xsl:text>
                    <xsl:apply-templates mode="step3"/>
                    <xsl:text>]</xsl:text>
                </fo:inline>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="tei:ex" mode="step3"> 
        <xsl:choose>
            <xsl:when test="ancestor::tei:hi[@rendition = '#aq']">
                <fo:inline font-family="serif" font-style="italic">
                    <xsl:apply-templates mode="step3"/>
                </fo:inline>
            </xsl:when>
            <xsl:otherwise>
                <fo:inline font-family="sans-serif" font-style="italic">
                    <xsl:apply-templates mode="step3"/>
                </fo:inline>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="tei:expan" mode="step3"/>
    
    <xsl:template match="tei:expan" mode="app"/>
    
    <xsl:template match="tei:hi[@rendition = '#aq']" mode="step3">
        <xsl:choose>
            <xsl:when test="not(.//text()[contains(.,'ӱ')] and  contains(//tei:title, 'Eichstätt 1611'))">
                <fo:inline font-family="serif, Arial Unicode MS" font-size="110%">
                    <xsl:apply-templates mode="step3"/>
                </fo:inline>
            </xsl:when>
            <xsl:otherwise>               
                <xsl:apply-templates mode="step3"/>                
            </xsl:otherwise>
        </xsl:choose>
        
    </xsl:template>
    
    <xsl:template match="tei:hi[@rendition = '#s']" mode="step3">
        <fo:inline text-decoration="line-through">
            <xsl:apply-templates mode="step3"/>
        </fo:inline>
    </xsl:template>
    
    <xsl:template match="tei:hi[not(@rendition)]" mode="step3">
        <fo:inline font-weight="bold">
            <xsl:apply-templates mode="step3"/>
        </fo:inline>
    </xsl:template>
    
    <xsl:template match="tei:lb[not(local-name(preceding-sibling::node()[1]) = 'pb')][not(parent::tei:p and (count(preceding-sibling::node()) = 0))]" mode="step3">
        <xsl:text>&#xA;</xsl:text>
        <xsl:apply-templates mode="step3"/>
    </xsl:template>
    
    <xsl:template match="tei:note[@subtype != 'addition'][@type != 'contemporary']" mode="step3">
        <xsl:choose>
            <xsl:when test="name(preceding-sibling::node()[1]) = 'table'">
                <fo:block font-size="60%" vertical-align="super" font-family="sans-serif" text-align="right">
                    <xsl:value-of select="count(preceding::tei:note[@subtype != 'addition']) + count(ancestor::tei:note[@subtype != 'addition']) + count(ancestor::tei:reg) + count(preceding::tei:reg) + 1"/>
                </fo:block>
            </xsl:when>
            <xsl:otherwise>
                <fo:inline font-size="60%" vertical-align="super" font-family="sans-serif">                    
                    <xsl:if test="preceding-sibling::node()[1][not(@subtype = 'addition')][not(@type = 'contemporary')][local-name() eq 'note' or local-name() eq 'app'] or (preceding-sibling::node()[1][local-name() eq 'foreign' or local-name() eq 'hi']/node()[last()][local-name() eq 'app'])">
                        <xsl:text>, </xsl:text>
                    </xsl:if>
                    <xsl:value-of select="count(preceding::tei:note[@subtype != 'addition']) + count(ancestor::tei:note[@subtype != 'addition']) + count(ancestor::tei:reg) + count(preceding::tei:reg) + 1"/>                    
                </fo:inline>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="tei:note[@subtype = 'addition']" mode="step3">
        <fo:inline font-family="sans-serif" font-style="italic">
            <xsl:text> [</xsl:text>
            <xsl:apply-templates mode="step3"/>
            <xsl:text>] </xsl:text>
        </fo:inline>
    </xsl:template>
    
    <xsl:template match="tei:note[@type = 'contemporary']" mode="step3">
        <xsl:choose>
            <xsl:when test="contains(@place, 'margin left')">
                <fo:block-container margin-top="0.3em" margin-bottom="0.4em" width="5cm" margin-left="-0.3cm" font-size="smaller">
                    <fo:block border-width="thin" border-style="solid" padding-top="0.2em" padding-bottom="0" padding-left="0.2em" padding-right="0.2em" text-align="center">
                        <xsl:apply-templates mode="step3"/>
                    </fo:block>
                </fo:block-container>
            </xsl:when>
            <xsl:when test="contains(@place, 'margin right')">
                <xsl:choose>
                    <xsl:when test="matches(ancestor::tei:pb/@n, '^fol. 18r$') and contains(//tei:title, 'München 1636')">                   
                        <fo:inline><xsl:text> </xsl:text></fo:inline><fo:inline border-width="thin" border-style="solid" padding-top="0.2em" padding-bottom="0" padding-left="0.2em" padding-right="0.2em" text-align="center" font-size="smaller"><xsl:apply-templates mode="step3"/></fo:inline>
                        <fo:inline><xsl:text> </xsl:text></fo:inline>
                    </xsl:when>
                    <xsl:otherwise>
                        <fo:table margin-bottom="-1.3em" margin-top="-1.3em" font-size="smaller">
                            <fo:table-body>
                                <fo:table-row>
                                    <fo:table-cell width="10cm">
                                        <fo:block/>
                                    </fo:table-cell>
                                    <fo:table-cell>
                                        <fo:block border-width="thin" border-style="solid" padding-top="0.2em" padding-bottom="0" padding-left="0.2em" padding-right="0.2em" text-align="center">
                                            <xsl:apply-templates mode="step3"/>
                                        </fo:block>
                                    </fo:table-cell>
                                </fo:table-row>
                            </fo:table-body>
                        </fo:table>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:when test="@place = 'above'">
                <xsl:text>&lt;</xsl:text>
                <xsl:apply-templates mode="step3"/>
                <xsl:text>&gt;</xsl:text>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="tei:p[name(./*[1]) ne 'pb']" mode="step3">
        <fo:block space-before="1em">
            <xsl:apply-templates mode="step3"/>
        </fo:block>
    </xsl:template>
    
    <xsl:template match="tei:table" mode="step3">
        <fo:table space-before="0.5em" space-after="0.5em">
            <fo:table-body>
                <xsl:apply-templates mode="step3"/>
            </fo:table-body>
        </fo:table>
    </xsl:template>
    
    <xsl:template match="tei:row" mode="step3">
        <fo:table-row>
            <xsl:apply-templates mode="step3"/>
        </fo:table-row>
    </xsl:template>
    
    <xsl:template match="tei:cell" mode="step3">
        <fo:table-cell display-align="center" text-align="center" padding-left="4mm" padding-top="1mm" padding-bottom="1mm" padding-right="1mm">
            <xsl:if test="@rows">
                <xsl:attribute name="number-rows-spanned">
                    <xsl:value-of select="@rows"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="@cols">
                <xsl:attribute name="number-columns-spanned">
                    <xsl:value-of select="@cols"/>
                </xsl:attribute>
            </xsl:if>
            <fo:block>
                <xsl:apply-templates mode="step3"/>
            </fo:block>
        </fo:table-cell>
    </xsl:template>
    
    <xsl:template match="text()[not(string-length(normalize-space()))]" mode="step3">
        <xsl:text> </xsl:text>
    </xsl:template>
    
    <xsl:template match="text()[string-length(normalize-space()) > 0]" mode="step3">
        
        
        <xsl:choose>
            <!-- entfernt Leerzeichen vor <note>/Fussnotenzeichen: -->
            <xsl:when test="following-sibling::*[1][self::tei:note]">
                <xsl:choose>
                    <xsl:when test="contains(., '₰')">
                        <fo:inline font-family="Times New Roman">
                            <xsl:value-of select="translate(translate(replace(., '\s$', ''), '&#xA;&#xD;', '  '), 'v̈', 'v&#x0308;')"/>
                        </fo:inline>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="translate(translate(replace(., '\s$', ''), '&#xA;&#xD;', '  '), 'v̈', 'v&#x0308;')"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>
                <xsl:choose>
                    <xsl:when test="contains(., '₰')">
                        <fo:inline font-family="Times New Roman">
                            <xsl:value-of select="translate(translate(., '&#xA;&#xD;', '  '), 'v̈', 'v&#x0308;')"/>
                        </fo:inline>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="translate(translate(., '&#xA;&#xD;', '  '), 'v̈', 'v&#x0308;')"/>           
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="tei:lem" mode="app">        
        <fo:inline font-family="Open Sans, Arial Unicode MS" font-weight="bold">
            <xsl:apply-templates mode="app"/>
        </fo:inline>
    </xsl:template>
    
    <xsl:template match="tei:lb" mode="app">
        <xsl:text> / </xsl:text>
    </xsl:template>
    
    <xsl:template match="tei:ex" mode="app">
        <fo:inline font-style="italic">
            <xsl:value-of select="."/>
        </fo:inline>
    </xsl:template>
    
    <xsl:template match="tei:note" mode="app"/>
    
    <xsl:template match="tei:rdg" mode="app"/>
    
    <xsl:template name="register">
        <xsl:param name="reise"/>       
        <xsl:if test="not(matches(//tei:title, '(Stettin 1617)'))">   <!--kann wegfallen sobald Personenregister für die besagten Reiseberichte fertig -->
            <fo:page-sequence master-reference="register">
                <fo:static-content flow-name="xsl-region-before">
                    <fo:block text-align="left">
                        <xsl:value-of select="//tei:title"/>
                        <xsl:text> &#x2013; Personenregister</xsl:text>
                    </fo:block>
                </fo:static-content>
                <fo:flow flow-name="xsl-region-body">
                    <fo:block-container font-size="10pt">
                        
                        <xsl:for-each select="(document('../Register/register-person/register-person-a.xml')|document('../Register/register-person/register-person-b.xml')|document('../Register/register-person/register-person-c.xml')|document('../Register/register-person/register-person-d.xml')|document('../Register/register-person/register-person-e.xml')|document('../Register/register-person/register-person-f.xml')|document('../Register/register-person/register-person-g.xml')|document('../Register/register-person/register-person-h.xml')|document('../Register/register-person/register-person-i.xml')|document('../Register/register-person/register-person-j.xml')|document('../Register/register-person/register-person-k.xml')|document('../Register/register-person/register-person-l.xml')|document('../Register/register-person/register-person-m.xml')|document('../Register/register-person/register-person-n.xml')|document('../Register/register-person/register-person-o.xml')|document('../Register/register-person/register-person-p.xml')|document('../Register/register-person/register-person-qr.xml')|document('../Register/register-person/register-person-s.xml')|document('../Register/register-person/register-person-t.xml')|document('../Register/register-person/register-person-u.xml')|document('../Register/register-person/register-person-v.xml')|document('../Register/register-person/register-person-w.xml')|document('../Register/register-person/register-person-xyz.xml'))//*[local-name() eq 'person' or local-name() eq 'personGrp'][tei:listBibl[@type = 'occurrences']/tei:bibl[starts-with(., $reise)]]">
                            <xsl:sort select="tei:persName[@type = 'preferred']/tei:term/@sortKey"/>
                            <fo:block start-indent="1em" end-indent="1em" text-indent="-1em" text-align="justify">
                                <xsl:choose>
                                    <xsl:when test="tei:persName[@type = 'preferred']/tei:term/tei:forename">
                                        <xsl:value-of select="tei:persName[@type = 'preferred']/tei:term/tei:surname"/>
                                        <xsl:if test="tei:persName[@type = 'preferred']/tei:term/tei:surname eq ''">
                                            <xsl:text>?</xsl:text>
                                        </xsl:if>
                                        <xsl:text>, </xsl:text>
                                        <xsl:value-of select="tei:persName[@type = 'preferred']/tei:term/tei:forename"/>
                                        <xsl:if test="tei:persName[@type = 'preferred']/tei:term/tei:forename eq ''">
                                            <xsl:text>?</xsl:text>
                                        </xsl:if>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:value-of select="tei:persName[@type = 'preferred']/tei:term/tei:name"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                                
                                <!-- Disambiguierung durch Lebensdaten: -->
                                <xsl:if test="(preceding::tei:person|following::tei:person)[tei:persName[@type='preferred']/tei:term/tei:surname eq current()/tei:persName[@type = 'preferred']/tei:term/tei:surname][tei:persName[@type='preferred']/tei:term/tei:forename eq current()/tei:persName[@type = 'preferred']/tei:term/tei:forename]">
                                    <xsl:text> (</xsl:text>
                                    
                                    <xsl:if test="tei:birth">
                                        <xsl:text>* </xsl:text>
                                    </xsl:if>
                                    <xsl:if test="tei:birth/@precision eq 'low' and tei:birth/@when-iso">
                                        <xsl:text>ca. </xsl:text>
                                    </xsl:if>
                                    <xsl:choose>
                                        <xsl:when test="tei:birth/@when-iso">
                                            <xsl:choose>
                                                <xsl:when test="substring(../tei:birth/@when-iso, 1, 1) = '-'">
                                                    <xsl:value-of select="number(substring-after(tei:birth/@when-iso, '-')) + 1"/>
                                                    <xsl:text> v. Chr.</xsl:text>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="number(tei:birth/@when-iso)"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:when>
                                        <xsl:when test="tei:birth/@notBefore-iso and tei:birth/@notAfter-iso">
                                            <xsl:text>zwischen </xsl:text>
                                            <xsl:if test="tei:birth/@precision eq 'low'">
                                                <xsl:text>ca. </xsl:text>
                                            </xsl:if>
                                            <xsl:choose>
                                                <xsl:when test="substring(tei:birth/@notBefore-iso, 1, 1) = '-'">
                                                    <xsl:value-of select="number(substring-after(tei:birth/@notBefore-iso, '-')) + 1"/>
                                                    <xsl:if test="substring(tei:birth/@notAfter-iso, 1, 1) != '-'">
                                                        <xsl:text> v. Chr.</xsl:text>
                                                    </xsl:if>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="number(tei:birth/@notBefore-iso)"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                            <xsl:text> und </xsl:text>
                                            <xsl:choose>
                                                <xsl:when test="substring(tei:birth/@notAfter-iso, 1, 1) = '-'">
                                                    <xsl:value-of select="number(substring-after(tei:birth/@notAfter-iso, '-')) + 1"/>
                                                    <xsl:text> v. Chr.</xsl:text>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="number(tei:birth/@notAfter-iso)"/>
                                                    <xsl:if test="substring(tei:birth/@notBefore-iso, 1, 1) = '-'">
                                                        <xsl:text> n. Chr.</xsl:text>
                                                    </xsl:if>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:when>
                                        <xsl:when test="tei:floruit">
                                            <xsl:value-of select="tei:floruit"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:text>* ?</xsl:text>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                    <xsl:if test="not(tei:floruit)">
                                        <xsl:text>, ✝ </xsl:text>
                                    </xsl:if>
                                    <xsl:if test="tei:death/@precision eq 'low' and tei:death/@when-iso">
                                        <xsl:text>ca. </xsl:text>
                                    </xsl:if>
                                    
                                    <xsl:choose>
                                        <xsl:when test="tei:death/@when-iso">
                                            <xsl:choose>
                                                <xsl:when test="substring(tei:death/@when-iso, 1, 1) = '-'">
                                                    <xsl:value-of select="number(substring-after(tei:death/@when-iso, '-')) + 1"/>
                                                    <xsl:text> v. Chr.</xsl:text>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="number(tei:death/@when-iso)"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:when>
                                        <xsl:when test="tei:death/@notBefore-iso and tei:death/@notAfter-iso">
                                            <xsl:text>zwischen </xsl:text>
                                            <xsl:if test="tei:death/@precision eq 'low'">
                                                <xsl:text>ca. </xsl:text>
                                            </xsl:if>
                                            <xsl:choose>
                                                <xsl:when test="substring(tei:death/@notBefore-iso, 1, 1) = '-'">
                                                    <xsl:value-of select="number(substring-after(tei:death/@notBefore-iso, '-')) + 1"/>
                                                    <xsl:if test="substring(tei:death/@notAfter-iso, 1, 1) != '-'">
                                                        <xsl:text> v. Chr.</xsl:text>
                                                    </xsl:if>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="number(tei:death/@notBefore-iso)"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                            <xsl:text> und </xsl:text>
                                            <xsl:choose>
                                                <xsl:when test="substring(tei:death/@notAfter-iso, 1, 1) = '-'">
                                                    <xsl:value-of select="number(substring-after(tei:death/@notAfter-iso, '-')) + 1"/>
                                                    <xsl:text> v. Chr.</xsl:text>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="number(tei:death/@notAfter-iso)"/>
                                                    <xsl:if test="substring(tei:death/@notBefore-iso, 1, 1) = '-'">
                                                        <xsl:text> n. Chr.</xsl:text>
                                                    </xsl:if>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:when>
                                        <xsl:when test="tei:floruit"/>
                                        <xsl:otherwise>
                                            <xsl:text>?</xsl:text>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                    
                                    <xsl:text>)</xsl:text>                               
                                </xsl:if>    
                                
                                <xsl:if test="(preceding::tei:person|following::tei:person)[tei:persName[@type='preferred']/tei:term/tei:sname eq current()/tei:persName[@type='preferred']/tei:term/tei:name]">
                                    <xsl:value-of select="tei:term/tei:name/normalize-space()"/>
                                    <span class="birthdeath">
                                        <xsl:text> (</xsl:text>
                                        
                                        <xsl:if test="tei:birth">
                                            <xsl:text>* </xsl:text>
                                        </xsl:if>
                                        <xsl:if test="tei:birth/@precision eq 'low' and tei:birth/@when-iso">
                                            <xsl:text>ca. </xsl:text>
                                        </xsl:if>
                                        <xsl:choose>
                                            <xsl:when test="tei:birth/@when-iso">
                                                <xsl:choose>
                                                    <xsl:when test="substring(tei:birth/@when-iso, 1, 1) = '-'">
                                                        <xsl:value-of select="number(substring-after(tei:birth/@when-iso, '-')) + 1"/>
                                                        <xsl:text> v. Chr.</xsl:text>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:value-of select="number(tei:birth/@when-iso)"/>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </xsl:when>
                                            <xsl:when test="tei:birth/@notBefore-iso and tei:birth/@notAfter-iso">
                                                <xsl:text>zwischen </xsl:text>
                                                <xsl:if test="tei:birth/@precision eq 'low'">
                                                    <xsl:text>ca. </xsl:text>
                                                </xsl:if>
                                                <xsl:choose>
                                                    <xsl:when test="substring(tei:birth/@notBefore-iso, 1, 1) = '-'">
                                                        <xsl:value-of select="number(substring-after(tei:birth/@notBefore-iso, '-')) + 1"/>
                                                        <xsl:if test="substring(tei:birth/@notAfter-iso, 1, 1) != '-'">
                                                            <xsl:text> v. Chr.</xsl:text>
                                                        </xsl:if>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:value-of select="number(tei:birth/@notBefore-iso)"/>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                                <xsl:text> und </xsl:text>
                                                <xsl:choose>
                                                    <xsl:when test="substring(tei:birth/@notAfter-iso, 1, 1) = '-'">
                                                        <xsl:value-of select="number(substring-after(tei:birth/@notAfter-iso, '-')) + 1"/>
                                                        <xsl:text> v. Chr.</xsl:text>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:value-of select="number(tei:birth/@notAfter-iso)"/>
                                                        <xsl:if test="substring(tei:birth/@notBefore-iso, 1, 1) = '-'">
                                                            <xsl:text> n. Chr.</xsl:text>
                                                        </xsl:if>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </xsl:when>
                                            <xsl:when test="tei:floruit">
                                                <xsl:value-of select="tei:floruit"/>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:text>* ?</xsl:text>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                        <xsl:if test="not(tei:floruit)">
                                            <xsl:text>, ✝ </xsl:text>
                                        </xsl:if>
                                        <xsl:if test="tei:death/@precision eq 'low' and tei:death/@when-iso">
                                            <xsl:text>ca. </xsl:text>
                                        </xsl:if>
                                        
                                        <xsl:choose>
                                            <xsl:when test="tei:death/@when-iso">
                                                <xsl:choose>
                                                    <xsl:when test="substring(tei:death/@when-iso, 1, 1) = '-'">
                                                        <xsl:value-of select="number(substring-after(tei:death/@when-iso, '-')) + 1"/>
                                                        <xsl:text> v. Chr.</xsl:text>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:value-of select="number(tei:death/@when-iso)"/>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </xsl:when>
                                            <xsl:when test="tei:death/@notBefore-iso and tei:death/@notAfter-iso">
                                                <xsl:text>zwischen </xsl:text>
                                                <xsl:if test="tei:death/@precision eq 'low'">
                                                    <xsl:text>ca. </xsl:text>
                                                </xsl:if>
                                                <xsl:choose>
                                                    <xsl:when test="substring(tei:death/@notBefore-iso, 1, 1) = '-'">
                                                        <xsl:value-of select="number(substring-after(tei:death/@notBefore-iso, '-')) + 1"/>
                                                        <xsl:if test="substring(tei:death/@notAfter-iso, 1, 1) != '-'">
                                                            <xsl:text> v. Chr.</xsl:text>
                                                        </xsl:if>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:value-of select="number(tei:death/@notBefore-iso)"/>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                                <xsl:text> und </xsl:text>
                                                <xsl:choose>
                                                    <xsl:when test="substring(tei:death/@notAfter-iso, 1, 1) = '-'">
                                                        <xsl:value-of select="number(substring-after(tei:death/@notAfter-iso, '-')) + 1"/>
                                                        <xsl:text> v. Chr.</xsl:text>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:value-of select="number(tei:death/@notAfter-iso)"/>
                                                        <xsl:if test="substring(tei:death/@notBefore-iso, 1, 1) = '-'">
                                                            <xsl:text> n. Chr.</xsl:text>
                                                        </xsl:if>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </xsl:when>
                                            <xsl:when test="tei:floruit"/>
                                            <xsl:otherwise>
                                                <xsl:text>?</xsl:text>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                        
                                        <xsl:text>)</xsl:text>
                                    </span>
                                </xsl:if>
                                <!-- Disambiguierung Ende -->
                                
                                <xsl:text>: </xsl:text>
                                <xsl:choose>
                                    <xsl:when test="tei:listBibl[@subtype = 'auto'][@type = 'occurrences']/tei:bibl[starts-with(., $reise)]">
                                        <xsl:for-each select="tei:listBibl[@subtype = 'auto'][@type = 'occurrences']/tei:bibl[starts-with(., $reise)]">
                                            <xsl:if test="not(preceding-sibling::tei:bibl[substring-before(substring-after(., $reise),':') eq substring-before(substring-after(current(), $reise),':')])">
                                                <xsl:if test="preceding-sibling::tei:bibl[starts-with(., $reise)]">                                               
                                                    <xsl:text>, </xsl:text>
                                                </xsl:if>
                                                <xsl:value-of select="substring-before(substring-after(., concat($reise, ', ')),':')"/>                                            
                                            </xsl:if>
                                        </xsl:for-each>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:for-each select="tei:listBibl[@type = 'occurrences']/tei:bibl[starts-with(., $reise)][not(preceding-sibling::tei:bibl[substring-after(., concat($reise,', ')) eq substring-after(current(), concat($reise,', '))])]">                           
                                            <xsl:if test="preceding-sibling::tei:bibl[starts-with(., $reise)]">                                               
                                                <xsl:text>, </xsl:text>
                                            </xsl:if>
                                            <xsl:value-of select="substring-after(., concat($reise, ', '))"/>                                          
                                        </xsl:for-each>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </fo:block>
                        </xsl:for-each>
                        
                    </fo:block-container>
                </fo:flow>
            </fo:page-sequence>
        </xsl:if>        
        <xsl:if test="not(matches(//tei:title, '(Stettin 1617)'))">  <!--kann wegfallen sobald Ortsregister für die besagten Reiseberichte fertig -->
        <fo:page-sequence master-reference="register">
            <fo:static-content flow-name="xsl-region-before">
                <fo:block text-align="left">
                    <xsl:value-of select="//tei:title"/>
                    <xsl:text> &#x2013; Ortsregister</xsl:text>
                </fo:block>
            </fo:static-content>
            <fo:flow flow-name="xsl-region-body">
                <fo:block-container font-size="10pt" class="ortsregister">
                    <xsl:for-each select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[tei:listBibl[@type = 'occurrences']/tei:bibl[starts-with(., $reise)]]">
                        <xsl:sort select="tei:placeName[@type = 'preferred']/tei:term/@sortKey"/>
                        <fo:block start-indent="1em" end-indent="1em" text-indent="-1em" text-align="justify" class="ort">
                            
                            <xsl:choose>
                                <xsl:when test="starts-with(substring-after(tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' '), '#')">
                                    <xsl:variable name="containsid" select="substring-after(tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' #')"/>
                                    <xsl:if test="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $containsid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']">
                                        <xsl:variable name="containsid2" select="substring-after((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $containsid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' #')"/>
                                        <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $containsid2]/tei:placeName[@type = 'preferred']/tei:term/normalize-space()"/>
                                        <xsl:text>, </xsl:text>
                                    </xsl:if>
                                    <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $containsid]/tei:placeName[@type = 'preferred']/tei:term/normalize-space()"/>
                                    <xsl:text>, </xsl:text>
                                    
                                </xsl:when>
                                <xsl:when test="starts-with(substring-after(tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' '), 'wrk:')">
                                    <xsl:variable name="workid" select="substring-after(tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' wrk:')"/>
                                    <xsl:if test="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']">
                                        <xsl:variable name="containsid2" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' plc:')"/>
                                        <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $containsid2]/tei:placeName[@type = 'preferred']/tei:term/normalize-space()"/>
                                        <xsl:text>, </xsl:text>
                                    </xsl:if>
                                    <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term"/>
                                    <xsl:text>, </xsl:text>
                                </xsl:when>
                            </xsl:choose>
                            
                            <xsl:value-of select="tei:placeName[@type = 'preferred']/tei:term"/>
                            <xsl:text>: </xsl:text>
                            <xsl:choose>
                                <xsl:when test="tei:listBibl[@subtype = 'auto'][@type = 'occurrences']/tei:bibl[starts-with(., $reise)]">
                                    <xsl:for-each select="tei:listBibl[@subtype = 'auto'][@type = 'occurrences']/tei:bibl[starts-with(., $reise)]">
                                        <xsl:if test="not(preceding-sibling::tei:bibl[substring-before(substring-after(., $reise),':') eq substring-before(substring-after(current(), $reise),':')])">
                                            <xsl:if test="preceding-sibling::tei:bibl[starts-with(., $reise)]">                                               
                                                <xsl:text>, </xsl:text>
                                            </xsl:if>
                                            <xsl:value-of select="substring-before(substring-after(., concat($reise, ', ')),':')"/>                                         
                                        </xsl:if>
                                    </xsl:for-each>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:for-each select="tei:listBibl[@type = 'occurrences']/tei:bibl[starts-with(., $reise)]">
                                        <xsl:if test="not(preceding-sibling::tei:bibl[substring-after(., concat($reise,', ')) eq substring-after(current(), concat($reise,', '))])">
                                            <xsl:if test="preceding-sibling::tei:bibl[starts-with(., $reise)]">                                               
                                                <xsl:text>, </xsl:text>
                                            </xsl:if>
                                            <xsl:value-of select="substring-after(., concat($reise, ', '))"/>                                  
                                        </xsl:if>
                                    </xsl:for-each>
                                </xsl:otherwise>
                            </xsl:choose>
                        </fo:block>
                    </xsl:for-each>
                </fo:block-container>
            </fo:flow>
        </fo:page-sequence>
        </xsl:if>
        
        <xsl:if test="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[tei:listBibl[@type = 'occurrences']/tei:bibl[starts-with(., $reise)]]">
            <xsl:if test="not(matches(//tei:title, '(Stettin 1617)'))">  <!--kann wegfallen sobald Objektregister für die besagten Reiseberichte fertig -->
                <fo:page-sequence master-reference="register">
                    <fo:static-content flow-name="xsl-region-before">
                        <fo:block text-align="left">
                            <xsl:value-of select="//tei:title"/>
                            <xsl:text> &#x2013; Objektregister</xsl:text>
                        </fo:block>
                    </fo:static-content>
                    <fo:flow flow-name="xsl-region-body">
                        <fo:block-container font-size="10pt" class="objektregister">                            
                            <xsl:for-each select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[tei:listBibl[@type = 'occurrences']/tei:bibl[starts-with(., $reise)]]">
                                <xsl:sort select="tei:name[@type = 'preferred']/tei:term/@sortKey"/>
                                <fo:block start-indent="1em" end-indent="1em" text-indent="-1em" text-align="justify" class="objekt">
                                    
                                    <xsl:choose>
                                        <xsl:when test="tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location'][starts-with(substring-after(@target, ' '), '#')] and tei:objectType[@n eq '1'][@ref eq '#architektur']">
                                            <xsl:variable name="workid" select="substring-after(tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' #')"/>
                                            <xsl:if test="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']">
                                                <xsl:choose>
                                                    <xsl:when test="starts-with(substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' '), '#')">
                                                        <xsl:variable name="workid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' #')"/>
                                                        <xsl:if test="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']">
                                                            <xsl:variable name="placeid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' plc:')"/>
                                                            <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $placeid]/tei:placeName[@type = 'preferred']/tei:term/normalize-space()"/>
                                                            <xsl:text>, </xsl:text>
                                                        </xsl:if>
                                                        <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term/normalize-space()"/>
                                                    </xsl:when>
                                                    <xsl:when test="starts-with(substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' '), 'plc:')">
                                                        <xsl:variable name="placeid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' plc:')"/>
                                                        <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $placeid]/tei:placeName[@type = 'preferred']/tei:term/normalize-space()"/>
                                                    </xsl:when>
                                                </xsl:choose>
                                                <xsl:text>, </xsl:text>
                                            </xsl:if>
                                            <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term/normalize-space()"/>
                                            <xsl:text>, </xsl:text>
                                        </xsl:when>
                                        <xsl:when test="tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location'][starts-with(substring-after(@target, ' '), 'plc:')] and tei:objectType[@n eq '1'][@ref eq '#architektur']">
                                            <xsl:variable name="placeid" select="substring-after(tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' plc:')"/>
                                            <xsl:if test="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $placeid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']">
                                                <xsl:choose>
                                                    <xsl:when test="starts-with(substring-after((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $placeid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' '), '#')">
                                                        <xsl:variable name="placeid" select="substring-after((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $placeid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' #')"/>
                                                        <xsl:if test="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $placeid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']">
                                                            <xsl:variable name="placeid" select="substring-after((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $placeid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' #')"/>
                                                            <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $placeid]/tei:placeName[@type = 'preferred']/tei:term/normalize-space()"/>
                                                            <xsl:text>, </xsl:text>
                                                        </xsl:if>
                                                        <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $placeid]/tei:placeName[@type = 'preferred']/tei:term/normalize-space()"/>
                                                    </xsl:when>
                                                    <xsl:when test="starts-with(substring-after((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $placeid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' '), 'wrk:')">
                                                        <xsl:variable name="workid" select="substring-after((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $placeid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' wrk:')"/>
                                                        <xsl:if test="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']">
                                                            <xsl:variable name="placeid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' plc:')"/>
                                                            <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $placeid]/tei:placeName[@type = 'preferred']/tei:term/normalize-space()"/>
                                                            <xsl:text>, </xsl:text>
                                                        </xsl:if>
                                                        <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term/normalize-space()"/>
                                                    </xsl:when>
                                                </xsl:choose>
                                                <xsl:text>, </xsl:text>
                                            </xsl:if>
                                            <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $placeid]/tei:placeName[@type = 'preferred']/tei:term/normalize-space()"/>
                                            <xsl:text>, </xsl:text>
                                        </xsl:when>
                                    </xsl:choose>
                                    
                                    <xsl:value-of select="tei:name[@type = 'preferred']/tei:term/normalize-space()"/>
                                    <xsl:text>: </xsl:text>
                                    <xsl:choose>
                                        <xsl:when test="tei:listBibl[@subtype = 'auto'][@type = 'occurrences']/tei:bibl[starts-with(., $reise)]">
                                            <xsl:for-each select="tei:listBibl[@subtype = 'auto'][@type = 'occurrences']/tei:bibl[starts-with(., $reise)]">
                                                <xsl:if test="not(preceding-sibling::tei:bibl[substring-before(substring-after(., $reise),':') eq substring-before(substring-after(current(), $reise),':')] and contains(.,':'))"> 
                                                    <xsl:if test="preceding-sibling::tei:bibl[starts-with(., $reise)]">                                               
                                                        <xsl:text>, </xsl:text>
                                                    </xsl:if>
                                                    <xsl:choose>
                                                        <xsl:when test="contains(.,'eingebunden')">
                                                            <xsl:value-of select="substring-before(substring-after(., concat($reise, ', ')),' [')"/>
                                                        </xsl:when>
                                                        
                                                        <xsl:when test="contains(.,':')">  
                                                            <xsl:value-of select="substring-before(substring-after(., concat($reise, ', ')),':')"/> 
                                                        </xsl:when>
                                                    </xsl:choose>                                            
                                                </xsl:if>                                     
                                            </xsl:for-each>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:for-each select="tei:listBibl[@type = 'occurrences']/tei:bibl[starts-with(., $reise)]">
                                                <xsl:if test="not(preceding-sibling::tei:bibl[substring-after(., concat($reise,', ')) eq substring-after(current(), concat($reise,', '))])">
                                                    <xsl:if test="preceding-sibling::tei:bibl[starts-with(., $reise)]">                                               
                                                        <xsl:text>, </xsl:text>
                                                    </xsl:if>
                                                    <xsl:value-of select="substring-after(., concat($reise, ', '))"/>                                                
                                                </xsl:if>
                                            </xsl:for-each>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </fo:block>
                            </xsl:for-each>
                        </fo:block-container>
                    </fo:flow>
                </fo:page-sequence>
            </xsl:if>
        </xsl:if>
        
        <xsl:if test="(document('../Register/register-org/register-org-a.xml')|document('../Register/register-org/register-org-b.xml')|document('../Register/register-org/register-org-c.xml')|document('../Register/register-org/register-org-d.xml')|document('../Register/register-org/register-org-e.xml')|document('../Register/register-org/register-org-f.xml')|document('../Register/register-org/register-org-g.xml')|document('../Register/register-org/register-org-h.xml')|document('../Register/register-org/register-org-i.xml')|document('../Register/register-org/register-org-j.xml')|document('../Register/register-org/register-org-k.xml')|document('../Register/register-org/register-org-l.xml')|document('../Register/register-org/register-org-m.xml')|document('../Register/register-org/register-org-n.xml')|document('../Register/register-org/register-org-o.xml')|document('../Register/register-org/register-org-p.xml')|document('../Register/register-org/register-org-qr.xml')|document('../Register/register-org/register-org-s.xml')|document('../Register/register-org/register-org-t.xml')|document('../Register/register-org/register-org-u.xml')|document('../Register/register-org/register-org-v.xml')|document('../Register/register-org/register-org-w.xml')|document('../Register/register-org/register-org-xyz.xml'))//tei:org[tei:listBibl[@type = 'occurrences']/tei:bibl[starts-with(., $reise)]]">
            <fo:page-sequence master-reference="register">
                <fo:static-content flow-name="xsl-region-before">
                    <fo:block text-align="left">
                        <xsl:value-of select="//tei:title"/>
                        <xsl:text> &#x2013; Körperschaftsregister</xsl:text>
                    </fo:block>
                </fo:static-content>
                <fo:flow flow-name="xsl-region-body">
                    <fo:block-container font-size="10pt">
                        <xsl:for-each select="(document('../Register/register-org/register-org-a.xml')|document('../Register/register-org/register-org-b.xml')|document('../Register/register-org/register-org-c.xml')|document('../Register/register-org/register-org-d.xml')|document('../Register/register-org/register-org-e.xml')|document('../Register/register-org/register-org-f.xml')|document('../Register/register-org/register-org-g.xml')|document('../Register/register-org/register-org-h.xml')|document('../Register/register-org/register-org-i.xml')|document('../Register/register-org/register-org-j.xml')|document('../Register/register-org/register-org-k.xml')|document('../Register/register-org/register-org-l.xml')|document('../Register/register-org/register-org-m.xml')|document('../Register/register-org/register-org-n.xml')|document('../Register/register-org/register-org-o.xml')|document('../Register/register-org/register-org-p.xml')|document('../Register/register-org/register-org-qr.xml')|document('../Register/register-org/register-org-s.xml')|document('../Register/register-org/register-org-t.xml')|document('../Register/register-org/register-org-u.xml')|document('../Register/register-org/register-org-v.xml')|document('../Register/register-org/register-org-w.xml')|document('../Register/register-org/register-org-xyz.xml'))//tei:org[tei:listBibl[@type = 'occurrences']/tei:bibl[starts-with(., $reise)]]">
                            <xsl:sort select="tei:orgName[@type = 'preferred']/tei:term/@sortKey"/>
                            <fo:block start-indent="1em" end-indent="1em" text-indent="-1em" text-align="justify">
                                <xsl:value-of select="tei:orgName[@type = 'preferred']/tei:term/normalize-space()"/>
                                <xsl:text>: </xsl:text>
                                <xsl:choose>
                                    <xsl:when test="tei:listBibl[@subtype = 'auto'][@type = 'occurrences']/tei:bibl[starts-with(., $reise)]">
                                        <xsl:for-each select="tei:listBibl[@subtype = 'auto'][@type = 'occurrences']/tei:bibl[starts-with(., $reise)]">
                                            <xsl:if test="not(preceding-sibling::tei:bibl[substring-before(substring-after(., $reise),':') eq substring-before(substring-after(current(), $reise),':')])">
                                                <xsl:if test="preceding-sibling::tei:bibl[starts-with(., $reise)]">                                               
                                                    <xsl:text>, </xsl:text>
                                                </xsl:if>
                                                <xsl:value-of select="substring-before(substring-after(., concat($reise, ', ')),':')"/>                                           
                                            </xsl:if>
                                        </xsl:for-each>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:for-each select="tei:listBibl[@type = 'occurrences']/tei:bibl[starts-with(., $reise)]">
                                            <xsl:if test="not(preceding-sibling::tei:bibl[substring-after(., concat($reise,', ')) eq substring-after(current(), concat($reise,', '))])">
                                                <xsl:if test="preceding-sibling::tei:bibl[starts-with(., $reise)]">                                               
                                                    <xsl:text>, </xsl:text>
                                                </xsl:if>
                                                <xsl:value-of select="substring-after(., concat($reise, ', '))"/>                                         
                                            </xsl:if>
                                        </xsl:for-each>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </fo:block>
                        </xsl:for-each>
                    </fo:block-container>
                </fo:flow>
            </fo:page-sequence>
        </xsl:if>
        
        <xsl:if test="(document('../Register/bibliography/bibliography-a.xml')|document('../Register/bibliography/bibliography-b.xml')|document('../Register/bibliography/bibliography-c.xml')|document('../Register/bibliography/bibliography-d.xml')|document('../Register/bibliography/bibliography-e.xml')|document('../Register/bibliography/bibliography-f.xml')|document('../Register/bibliography/bibliography-g.xml')|document('../Register/bibliography/bibliography-h.xml')|document('../Register/bibliography/bibliography-i.xml')|document('../Register/bibliography/bibliography-j.xml')|document('../Register/bibliography/bibliography-k.xml')|document('../Register/bibliography/bibliography-l.xml')|document('../Register/bibliography/bibliography-m.xml')|document('../Register/bibliography/bibliography-n.xml')|document('../Register/bibliography/bibliography-o.xml')|document('../Register/bibliography/bibliography-p.xml')|document('../Register/bibliography/bibliography-qr.xml')|document('../Register/bibliography/bibliography-s.xml')|document('../Register/bibliography/bibliography-t.xml')|document('../Register/bibliography/bibliography-u.xml')|document('../Register/bibliography/bibliography-v.xml')|document('../Register/bibliography/bibliography-w.xml')|document('../Register/bibliography/bibliography-xyz.xml'))//tei:bibl[tei:linkGrp[@ana = 'http://purl.org/dc/terms/references']/tei:link/@target[starts-with(., concat('transcr:', substring-before($reise, ' '), '%20', substring-after($reise, ' '), '.xml'))] or tei:linkGrp[@ana = 'http://schema.org/mentions']/tei:link/@target[starts-with(., concat('transcr:', substring-before($reise, ' '), '%20', substring-after($reise, ' '), '.xml'))]]">
            <fo:page-sequence master-reference="register">
                <fo:static-content flow-name="xsl-region-before">
                    <fo:block text-align="left">
                        <xsl:value-of select="//tei:title"/>
                        <xsl:text> &#x2013; Bibliographie</xsl:text>
                    </fo:block>
                </fo:static-content>
                <fo:flow flow-name="xsl-region-body">
                    <fo:block-container font-size="10pt">
                        <xsl:for-each select="(document('../Register/bibliography/bibliography-a.xml')|document('../Register/bibliography/bibliography-b.xml')|document('../Register/bibliography/bibliography-c.xml')|document('../Register/bibliography/bibliography-d.xml')|document('../Register/bibliography/bibliography-e.xml')|document('../Register/bibliography/bibliography-f.xml')|document('../Register/bibliography/bibliography-g.xml')|document('../Register/bibliography/bibliography-h.xml')|document('../Register/bibliography/bibliography-i.xml')|document('../Register/bibliography/bibliography-j.xml')|document('../Register/bibliography/bibliography-k.xml')|document('../Register/bibliography/bibliography-l.xml')|document('../Register/bibliography/bibliography-m.xml')|document('../Register/bibliography/bibliography-n.xml')|document('../Register/bibliography/bibliography-o.xml')|document('../Register/bibliography/bibliography-p.xml')|document('../Register/bibliography/bibliography-qr.xml')|document('../Register/bibliography/bibliography-s.xml')|document('../Register/bibliography/bibliography-t.xml')|document('../Register/bibliography/bibliography-u.xml')|document('../Register/bibliography/bibliography-v.xml')|document('../Register/bibliography/bibliography-w.xml')|document('../Register/bibliography/bibliography-xyz.xml'))//tei:bibl[tei:linkGrp[@ana = 'http://purl.org/dc/terms/references']/tei:link/@target[starts-with(., concat('transcr:', substring-before($reise, ' '), '%20', substring-after($reise, ' '), '.xml'))] or tei:linkGrp[@ana = 'http://schema.org/mentions']/tei:link/@target[starts-with(., concat('transcr:', substring-before($reise, ' '), '%20', substring-after($reise, ' '), '.xml'))]]">
                            <xsl:sort select="@sortKey"/>
                            <fo:block start-indent="1em" end-indent="1em" text-indent="-1em" text-align="justify">
                                <xsl:value-of select="tei:seg"/>
                            </fo:block>
                        </xsl:for-each>
                    </fo:block-container>
                </fo:flow>
            </fo:page-sequence>
        </xsl:if>
    </xsl:template>
    
    <!-- ******************************* Registersortierung (bei Objekt- und Ortsregister wird der Sortierschlüssel derzeit nicht berücksichtigt): ******************************** -->
    
    <xsl:template match="@* | node()" mode="step4">
        <xsl:copy>
            <xsl:apply-templates select="@* | node()" mode="step4"/>
        </xsl:copy>
    </xsl:template>
    
    <xsl:template match="fo:block-container[@class = 'objektregister']" mode="step4">
        <fo:block-container>
            <xsl:copy>
                <xsl:apply-templates select="@*[name()!='class']" mode="step4"/>
                <xsl:apply-templates select="fo:block[@class = 'objekt']" mode="step4">
                    <xsl:sort select="replace(replace(replace(lower-case(replace(substring-before(./text(), ': fol.'), '\W', '')), 'ä', 'ae'), 'ö', 'oe'), 'ü', 'ue')" lang="de"/>
                </xsl:apply-templates>
            </xsl:copy>
        </fo:block-container>
    </xsl:template>
    
    <xsl:template match="fo:block[@class = 'objekt']" mode="step4">
        <xsl:copy>
            <xsl:apply-templates select="@*[name()!='class'] | node()" mode="step4"/>              
        </xsl:copy>        
    </xsl:template>
    
    <xsl:template match="fo:block-container[@class = 'ortsregister']" mode="step4">        
        <fo:block-container>
            <xsl:copy>
                <xsl:apply-templates select="@*[name()!='class']" mode="step4"/>
                <xsl:apply-templates select="fo:block[@class = 'ort']" mode="step4">
                    <xsl:sort select="replace(replace(replace(lower-case(translate(substring-before(./text(), ': fol.'), '()', '')), 'ä', 'ae'), 'ö', 'oe'), 'ü', 'ue')" lang="de"/>
                </xsl:apply-templates>
            </xsl:copy>
        </fo:block-container>
    </xsl:template>
    
    <xsl:template match="fo:block[@class = 'ort']" mode="step4">
        <xsl:copy>
            <xsl:apply-templates select="@*[name()!='class'] | node()" mode="step4"/>             
        </xsl:copy>
    </xsl:template>
    
</xsl:stylesheet>
