<?xml version="1.0" encoding="UTF-8"?>
<!-- Dieses Stylesheet konvertiert die TEI/XML-Datei eines Reiseberichts nach XHTML. -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xhtml="http://www.w3.org/1999/xhtml" exclude-result-prefixes="#all" version="2.0" xpath-default-namespace="http://www.tei-c.org/ns/1.0">
    
    <xsl:output method="xhtml" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" indent="yes"/>
    
    <xsl:template name="start">
        <xsl:apply-templates select="TEI" mode="step1"/>
    </xsl:template>
    
    <xsl:variable name="step1">
        <xsl:call-template name="start"/>
    </xsl:variable>
    
    <xsl:variable name="step2">
        <xsl:apply-templates select="$step1" mode="step2"/>
    </xsl:variable>
    
    <xsl:template match="/">        
        <xsl:variable name="output">
            <xsl:sequence select="$step2"/>
        </xsl:variable>
        <xsl:variable name="outputpath" select="concat(replace(replace(replace(replace(lower-case(translate(//title, '/ ', '')), 'ä', 'ae'), 'ö', 'oe'), 'ü', 'ue'), '–', '_'),'.xhtml')"/>
        <xsl:variable name="output_step3"> 
            <xsl:apply-templates mode="step3" select="$output"/>            
        </xsl:variable> 
        <xsl:result-document href="../HTML-Dateien/{$outputpath}"> 
            <xsl:apply-templates mode="step4" select="$output_step3"/>            
        </xsl:result-document>
    </xsl:template>
    
    <xsl:template match="@*|node()" mode="step1">
        <xsl:copy>
            <xsl:apply-templates select="@*|node()" mode="step1"/>
        </xsl:copy>
    </xsl:template>
    
    <xsl:template match="p" mode="step1">
        <xsl:choose>
            <xsl:when test="pb">
                <xsl:for-each-group select="node()" group-starting-with="pb">
                    <!-- Copies the only lb in the group first (N.B the first group does not contain lb) -->
                    <xsl:sequence select="current-group()/descendant-or-self::pb"/>
                    <p xmlns="http://www.tei-c.org/ns/1.0">
                        <xsl:sequence select="current()/ancestor::matched-element/@*"/>
                        <!-- Copies the elements in the group except lb -->
                        <xsl:sequence select="current-group()[not(self::pb)]"/>
                    </p>
                </xsl:for-each-group>
            </xsl:when>
            <xsl:otherwise>
                <xsl:sequence select="."/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="@*|node()" mode="step2">
        
        <xsl:copy>
            <xsl:apply-templates select="@*|node()" mode="step2"/>
        </xsl:copy>
        
        
    </xsl:template>
    
    <xsl:template match="div" mode="step2">
        
        <div xmlns="http://www.tei-c.org/ns/1.0">
            
            <xsl:if test="@*">
                <xsl:attribute name="rend">
                    <xsl:value-of select="@rend"/>
                </xsl:attribute>
                <xsl:attribute name="hand">
                    <xsl:value-of select="@hand"/>
                </xsl:attribute>
                <xsl:if test="@corresp">
                    <xsl:attribute name="corresp">
                        <xsl:value-of select="@corresp"/>
                    </xsl:attribute>
                </xsl:if>
            </xsl:if>
            
            <xsl:choose>
                <xsl:when test="descendant::pb">
                    
                    <xsl:for-each select=".//pb">
                        
                        <pb>
                            <xsl:copy-of select="@*"/>
                            
                            <xsl:call-template name="continue">
                                <xsl:with-param name="next" select="following-sibling::*[1]" />
                            </xsl:call-template>
                            
                        </pb>
                    </xsl:for-each>
                    
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates mode="step2"/>
                </xsl:otherwise>
            </xsl:choose>
        </div>
    </xsl:template>
    
    <xsl:template name="continue"> <!-- http://www.tek-tips.com/viewthread.cfm?qid=1604222 -->
        <xsl:param name="next" />
        <xsl:choose>
            <xsl:when test="$next[self::pb]">
                <!-- do nothing -->
            </xsl:when>
            <xsl:otherwise>
                <xsl:copy-of select="$next" />
                <xsl:if test="$next/following-sibling::*[not(self::pb)]">
                    <xsl:call-template name="continue">
                        <xsl:with-param name="next" select="$next/following-sibling::*[1]" />
                    </xsl:call-template>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>    
    
    <xsl:template match="p" mode="step2">
        <p xmlns="http://www.tei-c.org/ns/1.0">
            <xsl:apply-templates mode="step2"/>
        </p>
    </xsl:template>
    
    
    
    
    <!-- ************************************** step 3: ********************************************* -->
    
    <!-- Hier die Dateipfade angeben: -->
    <xsl:variable name="psnpath">psn/</xsl:variable>
    <xsl:variable name="wrkpath">wrk/</xsl:variable>
    <xsl:variable name="litpath">lit/</xsl:variable>
    <xsl:variable name="plcpath">plc/</xsl:variable>
    <xsl:variable name="orgpath">org/</xsl:variable>
    <!-- Die folgenden wären die Pfade für die WordPress-Webseite. Die vorgenannten Pfade werden allerdings beim Upload automatisch in die folgenden umgeschrieben. -->
    
    <!--<xsl:variable name="psnpath">register/personen/</xsl:variable>
        <xsl:variable name="wrkpath">register/objekte/</xsl:variable>
        <xsl:variable name="litpath">informationen-zur-edition/bibliographie/</xsl:variable>
        <xsl:variable name="plcpath">register/orte/</xsl:variable>
        <xsl:variable name="orgpath">register/koerperschaftsregister/</xsl:variable>-->
    
    <xsl:variable name="imgpath" select="substring-before(/TEI/teiHeader/encodingDesc/listPrefixDef/prefixDef[@ident='img']/@replacementPattern,'$1')"/>
    <xsl:variable name="imgpath2" select="substring-before(/TEI/teiHeader/encodingDesc/listPrefixDef/prefixDef[@ident='img2']/@replacementPattern,'$1')"/>
    <xsl:variable name="imgpath3" select="substring-before(/TEI/teiHeader/encodingDesc/listPrefixDef/prefixDef[@ident='img3']/@replacementPattern,'$1')"/> <!-- für Hirsau in Wildbad 1615 -->
    
    <xsl:variable name="cRef-biblical-start">https://www.biblija.net/biblija.cgi?m=</xsl:variable>
    <xsl:variable name="cRef-biblical-end">&amp;id12=1&amp;id8=1&amp;set=1&amp;l=en</xsl:variable>
    
    <xsl:template match="TEI" mode="step3">
        <html xmlns="http://www.w3.org/1999/xhtml">
            <head>
                <meta name="publisher" content="Herzog August Bibliothek Wolfenbüttel"/>
                <link rel="license" href="http://creativecommons.org/licenses/by-sa/3.0/de/"/>
                <link rel="stylesheet" type="text/css" href="transkription-output.css"/>
                <title>
                    <xsl:value-of select="teiHeader/fileDesc/titleStmt/title"/>
                </title>
            </head>
            <xsl:apply-templates select="text/body" mode="step3"/>
        </html>
    </xsl:template>
    
    <xsl:template match="body" mode="step3">
        <body xmlns="http://www.w3.org/1999/xhtml">
            <xsl:apply-templates mode="step3"/>
        </body>
    </xsl:template>
    
    <xsl:template match="pb" mode="step3">
        <div xmlns="http://www.w3.org/1999/xhtml" class="page">
            <xsl:attribute name="id" select="concat('fol', substring-after(./@n, 'fol. '))"/>
            <div class="notescol">
                <xsl:for-each select=".//note[@subtype != 'addition']">
                    <div class="note">
                        <xsl:variable name="noteid" select="count(preceding::note[@subtype != 'addition']) + count(ancestor::note[@subtype != 'addition']) + count(ancestor::reg) + count(preceding::reg) + 1"/>
                        <xsl:attribute name="id" select="concat('note',$noteid)"/>
                        <span class="notenumber">
                            <xsl:value-of select="$noteid"/>
                        </span>
                        <span>
                            <xsl:attribute name="class" select="@subtype"/>
                            <xsl:if test="@subtype eq 'translation'">
                                <span class="translationprefix">Übers.: </span>
                            </xsl:if>
                            <xsl:apply-templates mode="step3"/>
                        </span>
                    </div>
                </xsl:for-each>
                <xsl:for-each select=".//reg">
                    <div class="note">
                        <xsl:variable name="noteid" select="count(preceding::note[@subtype != 'addition']) + count(ancestor::note[@subtype != 'addition']) + count(ancestor::reg) + count(preceding::reg) + 1"/>
                        <xsl:attribute name="id" select="concat('note',$noteid)"/>
                        <span class="notenumber">
                            <xsl:value-of select="$noteid"/>
                        </span>
                        <xsl:apply-templates mode="step3"/>
                    </div>
                </xsl:for-each>
            </div>
            <div class="mlcol">
                <div class="pagenumber">
                    <xsl:value-of select="./@n"/>
                </div>
                
                <xsl:choose>
                    <xsl:when test="ancestor::div/@hand = '#druckgraphik'">
                        <div class="accmatprefix">
                            <xsl:choose>
                                <xsl:when test="ancestor::div/@corresp">
                                    <a>
                                        <xsl:attribute name="href">                                        
                                            <xsl:value-of select="concat($wrkpath, substring-after(ancestor::div/@corresp, ':'), '.xhtml')"/>                                            
                                        </xsl:attribute>
                                        <xsl:text>[eingebundene Druckgraphik]</xsl:text>
                                    </a>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:text>[eingebundene Druckgraphik]</xsl:text>
                                </xsl:otherwise>
                            </xsl:choose>
                        </div>
                    </xsl:when>
                    <xsl:when test="(ancestor::div/@hand = '#fremde_hand' or ancestor::div/@hand = '#PH') and ancestor::div/@rend = 'accMat'">
                        <div class="accmatprefix">
                            <xsl:choose>
                                <xsl:when test="ancestor::div/@corresp">
                                    <a>
                                        <xsl:attribute name="href">                                        
                                            <xsl:value-of select="concat($wrkpath, substring-after(ancestor::div/@corresp, ':'), '.xhtml')"/>                                            
                                        </xsl:attribute>
                                        <xsl:text>[eingebundene Handschrift]</xsl:text>
                                    </a>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:text>[eingebundene Handschrift]</xsl:text>
                                </xsl:otherwise>
                            </xsl:choose>
                        </div>
                    </xsl:when>
                    <xsl:when test="ancestor::div/@hand = '#druckschrift'">
                        <div class="accmatprefix">
                            <xsl:choose>
                                <xsl:when test="ancestor::div/@corresp">
                                    <a>
                                        <xsl:attribute name="href">                                        
                                            <xsl:value-of select="concat($wrkpath, substring-after(ancestor::div/@corresp, ':'), '.xhtml')"/>                                            
                                        </xsl:attribute>
                                        <xsl:text>[eingebundene Druckschrift]</xsl:text>
                                    </a>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:text>[eingebundene Druckschrift]</xsl:text>
                                </xsl:otherwise>
                            </xsl:choose>
                        </div>
                    </xsl:when>
                    <xsl:when test="ancestor::div/@hand = '#handzeichnung'">
                        <div class="accmatprefix">
                            <xsl:choose>
                                <xsl:when test="ancestor::div/@corresp">
                                    <a>
                                        <xsl:attribute name="href">                                        
                                            <xsl:value-of select="concat($wrkpath, substring-after(ancestor::div/@corresp, ':'), '.xhtml')"/>                                           
                                        </xsl:attribute>
                                        <xsl:text>[eingebundene Handzeichnung]</xsl:text>
                                    </a>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:text>[eingebundene Handzeichnung]</xsl:text>
                                </xsl:otherwise>
                            </xsl:choose>
                        </div>
                    </xsl:when>
                </xsl:choose>
                
            </div>
            <div class="maincol">
                <xsl:choose>
                    <xsl:when test="ancestor::div/@rend = 'accMat'">
                        <div class="accmat">
                            <xsl:apply-templates mode="step3"/>
                        </div>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:apply-templates mode="step3"/>
                    </xsl:otherwise>
                </xsl:choose>
            </div>
            <div class="facscol">
                <img class="facsimile">
                    <xsl:attribute name="src">      
                        <xsl:choose>
                            <xsl:when test="contains(./@facs, 'img:')">
                                <xsl:value-of select="concat($imgpath,substring-after(./@facs, 'img:'))"/>
                            </xsl:when>
                            <xsl:when test="contains(./@facs, 'img3:')">
                                <xsl:value-of select="concat($imgpath3,substring-after(./@facs, 'img3:'))"/>
                            </xsl:when>
                        </xsl:choose>                        
                    </xsl:attribute>
                    <xsl:attribute name="alt">
                        <xsl:text>Faksimile</xsl:text>
                    </xsl:attribute>
                </img>
            </div>
        </div>
    </xsl:template>
    
    <xsl:template match="add" mode="step3">
        <xsl:text> &lt;</xsl:text>
        <xsl:apply-templates mode="step3"/>        
        <xsl:text>&gt;</xsl:text>
        <xsl:if test="not(following::*[1]/self::note[@type='annotation'])">
            <xsl:text> </xsl:text>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="citedRange[@target]" mode="step3">
        <a xmlns="http://www.w3.org/1999/xhtml">
            <xsl:attribute name="href" select="@target"/>
            <xsl:apply-templates mode="step3"/>
        </a>
    </xsl:template>
    
    <xsl:template match="ex" mode="step3">
        <span xmlns="http://www.w3.org/1999/xhtml" class="expansion">
            <xsl:apply-templates mode="step3"/>
        </span>
    </xsl:template>
    
    <xsl:template match="hi[@rendition = '#s']" mode="step3">
        <span xmlns="http://www.w3.org/1999/xhtml" class="strikethrough">
            <xsl:apply-templates mode="step3"/>
        </span>
    </xsl:template>
    
    <xsl:template match="hi[@rendition = '#aq']" mode="step3">
        <span xmlns="http://www.w3.org/1999/xhtml" class="latinletters">
            <xsl:apply-templates mode="step3"/>
        </span>
    </xsl:template>
    
    <xsl:template match="hi[@rendition = '#i']" mode="step3">
        <span xmlns="http://www.w3.org/1999/xhtml" class="italic">
            <xsl:apply-templates mode="step3"/>
        </span>
    </xsl:template>
    
    <xsl:template match="hi[@rendition = '#sup']" mode="step3">
        <span xmlns="http://www.w3.org/1999/xhtml" class="superscript">
            <xsl:apply-templates mode="step3"/>
        </span>
    </xsl:template>
    
    <xsl:template match="hi[not(@rendition)]" mode="step3">
        <span xmlns="http://www.w3.org/1999/xhtml" class="highlighted">
            <xsl:apply-templates mode="step3"/>
        </span>
    </xsl:template>
    
    <xsl:template match="note[@subtype = 'addition']" mode="step3">
        <xsl:text> </xsl:text>
        <span xmlns="http://www.w3.org/1999/xhtml" class="editorial">
            <xsl:text>[</xsl:text>
            <xsl:apply-templates mode="step3"/>
            <xsl:text>] </xsl:text>
        </span>
    </xsl:template>
    
    <xsl:template match="note[@subtype != 'addition'][@type != 'contemporary']" mode="step3">
        <xsl:variable name="noteid" select="count(preceding::note[@subtype != 'addition']) + count(ancestor::note[@subtype != 'addition']) + count(ancestor::reg) + count(preceding::reg) + 1"/>
        <span xmlns="http://www.w3.org/1999/xhtml" class="notenumber">
            
            <xsl:if test="preceding-sibling::node()[1][not(@subtype = 'addition')][not(@type = 'contemporary')][local-name() eq 'note' or local-name() eq 'app'] or (preceding-sibling::node()[1][local-name() eq 'foreign' or local-name() eq 'hi']/node()[last()][local-name() eq 'app'])">
                <xsl:text>, </xsl:text>
            </xsl:if>
            <a>
                <xsl:attribute name="href" select="concat('#note',$noteid)"/>
                <xsl:value-of select="$noteid"/>
            </a>
            <xsl:if test="parent::lem and not(following-sibling::node())">
                <xsl:text>, </xsl:text>
            </xsl:if>
        </span>
    </xsl:template>
    
    <xsl:template match="note[@type = 'contemporary']" mode="step3">
        <xsl:choose>
            <xsl:when test="@place = 'margin left'">
                <span xmlns="http://www.w3.org/1999/xhtml" class="marginleft">
                    <xsl:apply-templates mode="step3"/>
                </span>
            </xsl:when>
            <xsl:when test="@place = 'margin right'">
                <span xmlns="http://www.w3.org/1999/xhtml" class="marginright">
                    <xsl:text>&lt;</xsl:text>
                    <span class="marginrightprefix">Randnotiz: </span>
                    <xsl:apply-templates mode="step3"/>
                    <xsl:text>&gt;</xsl:text>
                </span>
            </xsl:when>
            <xsl:when test="@place = 'above'">
                <xsl:text>&lt;</xsl:text>
                <xsl:apply-templates mode="step3"/>
                <xsl:text>&gt;</xsl:text>
            </xsl:when>
        </xsl:choose>
        
    </xsl:template>
    
    <xsl:template match="p[name(./*[1]) ne 'pb']" mode="step3">
        <div xmlns="http://www.w3.org/1999/xhtml" class="p">
            
            <xsl:if test="*[1][local-name() = 'lb']/@xml:id">
                <xsl:attribute name="id" select="*[1][local-name() = 'lb']/@xml:id"/>
            </xsl:if>
            
            <xsl:apply-templates mode="step3"/>
        </div>
    </xsl:template>
    
    <xsl:template match="reg" mode="step3">
        <span xmlns="http://www.w3.org/1999/xhtml" class="notenumber">
            <xsl:value-of select="count(preceding::note[@subtype != 'addition']) + count(ancestor::note[@subtype != 'addition']) + count(ancestor::reg) + count(preceding::reg) + 1"/>
        </span>
    </xsl:template>
    
    <xsl:template match="lb[not(name(preceding-sibling::node()[1]) = 'pb')][not(parent::p and (count(preceding-sibling::node()) = 0))][* or matches(., '\w') or not(@xml:id)]" mode="step3">
        <!-- Letztere Klammer verhindert, dass 2 Zeilenumbrüche hintereinander stehen. -->
        <xsl:choose>
            <xsl:when test="not(parent::p/*[1][self::lb][not(* or matches(., '\w') or not(@xml:id))])">
                <!-- für den Fall <p><lb/><lb></lb></p> -->
                <br xmlns="http://www.w3.org/1999/xhtml">
                    <xsl:if test="@xml:id">
                        <xsl:attribute name="id" select="@xml:id"/>
                    </xsl:if>
                </br>
            </xsl:when>
            <xsl:when test="@xml:id">
                <!-- Sprungziel, falls kein Zeilenumbruch erwünscht: -->
                <a xmlns="http://www.w3.org/1999/xhtml">
                    <xsl:attribute name="id" select="@xml:id"/>
                </a>
            </xsl:when>
        </xsl:choose>
        <xsl:apply-templates mode="step3"/>
    </xsl:template>
    
    <xsl:template match="app" mode="step3">
        <xsl:apply-templates select="lem" mode="step3"/>
        <xsl:variable name="id" select="generate-id()"/>
        <span xmlns="http://www.w3.org/1999/xhtml">
            <a class="button" href="#{$id}">
                <sup>
                    <xsl:for-each select="rdg">
                        <xsl:sort select="//listWit/witness[@xml:id eq substring(current()/@wit,2)]/count(preceding-sibling::witness)"/>
                        <xsl:variable name="witid" select="substring-after(@wit, '#')"/>
                        <xsl:choose>
                            <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 1]">
                                <xsl:text>a</xsl:text>
                            </xsl:when>
                            <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 2]">
                                <xsl:text>b</xsl:text>
                            </xsl:when>
                            <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 3]">
                                <xsl:text>c</xsl:text>
                            </xsl:when>
                            <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 4]">
                                <xsl:text>d</xsl:text>
                            </xsl:when>
                            <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 5]">
                                <xsl:text>e</xsl:text>
                            </xsl:when>
                            <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 6]">
                                <xsl:text>f</xsl:text>
                            </xsl:when>
                            <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 7]">
                                <xsl:text>g</xsl:text>
                            </xsl:when>
                            <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 8]">
                                <xsl:text>h</xsl:text>
                            </xsl:when>
                            <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 9]">
                                <xsl:text>i</xsl:text>
                            </xsl:when>
                            <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 10]">
                                <xsl:text>j</xsl:text>
                            </xsl:when>
                        </xsl:choose>
                    </xsl:for-each>
                </sup>
            </a>
        </span>
        <span xmlns="http://www.w3.org/1999/xhtml" class="overlay">
            <xsl:attribute name="id">
                <xsl:value-of select="$id"/>
            </xsl:attribute>
            <span class="popup">
                <a class="close" href="#close">×</a>
                <span class="app-entry">
                    <span class="label"/>
                    <span class="bibl">
                        <xsl:choose>
                            <xsl:when test="//title eq 'Wildbad/Heidelberg/Durlach 1615'">
                                <xsl:choose>
                                    <xsl:when test="rdg/@wit eq '#muenchen_ub'">
                                        <xsl:text>Cod. Guelf. 83 Extrav.</xsl:text>
                                    </xsl:when>
                                    <xsl:when test="rdg/@wit eq '#cod_guelf_83_extrav'">
                                        <xsl:text>München, Universitätsbibliothek, 2° Cod. ms. 403</xsl:text>
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="//idno[@type eq 'shelfmark']"/>
                            </xsl:otherwise>
                        </xsl:choose>                        
                        <xsl:text>:</xsl:text>
                    </span>
                    <xsl:choose>
                        <xsl:when test="lem = ''">
                            <span class="reading editorial">
                                <xsl:text>[Zeichenfolge nicht vorhanden]</xsl:text>
                            </span>
                        </xsl:when>
                        <xsl:when test="lem/table">
                            <span class="reading">
                                <xsl:apply-templates select="lem/table/preceding-sibling::node()" mode="step3"/>
                                <xsl:value-of select="lem/table/row[1]/cell[1]"/>
                                <span class="editorial">
                                    <xsl:text> [...] </xsl:text>
                                </span>
                                <xsl:value-of select="lem/table/row[last()]/cell[last()]"/>
                                <xsl:apply-templates select="lem/table/following-sibling::node()" mode="step3"/>
                            </span>
                        </xsl:when>
                        <xsl:otherwise>
                            <span class="reading">
                                <xsl:apply-templates select="lem" mode="step3"/>
                            </span>
                        </xsl:otherwise>
                    </xsl:choose>
                </span>
                <xsl:for-each select="rdg">
                    <xsl:sort select="//listWit/witness[@xml:id eq substring(current()/@wit,2)]/count(preceding-sibling::witness)"/>
                    <span class="app-entry">
                        
                        <xsl:variable name="witid" select="substring-after(@wit, '#')"/>
                        <span class="label">
                            <xsl:choose>
                                <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 1]">
                                    <xsl:text>(a)</xsl:text>
                                </xsl:when>
                                <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 2]">
                                    <xsl:text>(b)</xsl:text>
                                </xsl:when>
                                <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 3]">
                                    <xsl:text>(c)</xsl:text>
                                </xsl:when>
                                <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 4]">
                                    <xsl:text>(d)</xsl:text>
                                </xsl:when>
                                <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 5]">
                                    <xsl:text>(e)</xsl:text>
                                </xsl:when>
                                <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 6]">
                                    <xsl:text>(f)</xsl:text>
                                </xsl:when>
                                <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 7]">
                                    <xsl:text>(g)</xsl:text>
                                </xsl:when>
                                <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 8]">
                                    <xsl:text>(h)</xsl:text>
                                </xsl:when>
                                <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 9]">
                                    <xsl:text>(i)</xsl:text>
                                </xsl:when>
                                <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[@xml:id = $witid] = /TEI/teiHeader/fileDesc/sourceDesc/listWit/witness[position() = 10]">
                                    <xsl:text>(j)</xsl:text>
                                </xsl:when>
                            </xsl:choose>
                        </span>
                        <span class="bibl">
                            <xsl:value-of select="//witness[@xml:id = $witid]/bibl"/>
                            <xsl:text>, </xsl:text>
                            <xsl:choose>
                                <xsl:when test="starts-with($witid, 'innsbruck') and contains(//witness[@xml:id = $witid]/bibl, '582')">
                                    <xsl:variable name="bookurl" select="substring-before(//witness[@xml:id = $witid]/ptr/@target,'/titleinfo')"/>
                                    <a>
                                        <xsl:attribute name="href">
                                            <xsl:choose>
                                                <xsl:when test="@n = 'fol. 3r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132576')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 3v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132577')"/>
                                                </xsl:when>                                                
                                                <xsl:when test="@n = 'fol. 4r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132578')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 4v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132579')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 5r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132580')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 5v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132581')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 6r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132588')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 6v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132590')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 8r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132631')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 8v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132632')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 10r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132636')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 10v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132641')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 11r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132642')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 11v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132643')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 12r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132644')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 12v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132645')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 14r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132651')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 14v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132655')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 15r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132657')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 15v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132658')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 16r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132659')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 16v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132660')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 17r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132661')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 17v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132662')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 18r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132664')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 18v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132665')"/>
                                                </xsl:when>
                                                <xsl:when test="@n = 'fol. 28r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132711')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 28v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132712')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 29r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132713')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 29v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132714')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 30r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132718')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 30v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132719')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 31r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132720')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 31v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132721')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 32r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132722')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 32v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132723')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 33r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132724')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 33v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132725')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 34r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132731')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 34v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132732')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 35r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132734')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 35v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132735')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 36r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132736')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 36v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132740')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 37r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132741')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 37v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132742')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 38r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132743')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 38v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132744')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 39r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132745')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 39v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132746')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 40r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132747')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 40v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132748')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 41r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132750')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 41v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132758')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 42r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132762')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 42v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132763')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 43r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132764')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 43v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132765')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 44r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132766')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 44v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132775')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 45r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132776')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 45v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132778')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 46r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132779')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 46v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132783')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 47r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132784')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 47v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132785')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 48r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132786')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 48v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132787')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 49r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132789')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 49v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132790')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 50r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132791')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 50v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132792')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 51r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132793')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 51v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132794')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 52r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132795')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 52v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132796')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 53r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132797')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 53v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132798')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 54r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132799')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 54v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132800')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 55r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132801')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 55v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132802')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 56r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132803')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 56v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132804')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 57r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132805')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 57v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132806')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 58r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132807')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 58v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132808')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 59r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132809')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 59v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132810')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 60r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132811')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 60v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132812')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 61r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132814')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 61v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132816')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 62r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132817')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 62v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132818')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 63r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132820')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 63v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132822')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 64r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132831')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 64v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132832')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 65r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132834')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 65v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132837')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 66r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132838')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 66v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132839')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 67r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132840')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 67v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132843')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 68r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132844')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 68v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132845')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 69r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132846')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 69v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132848')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 70r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132850')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 70v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132851')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 71r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132852')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 71v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132853')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 72r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132856')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 72v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132857')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 73r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132858')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 73v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132859')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 74r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132861')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 74v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132863')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 75r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132864')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 75v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132865')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 76r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132866')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 76v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132867')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 77r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132868')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 77v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132869')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 78r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132870')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 78v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132871')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 79r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132874')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 79v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132881')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 80r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132884')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 80v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132885')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 81r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132888')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 81v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132891')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 82r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132892')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 82v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132893')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 83r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132894')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 83v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132895')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 84r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132896')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 84v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132897')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 85r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132898')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 85v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132899')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 86r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132900')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 86v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132901')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 87r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132902')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 87v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132903')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 88r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132904')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 88v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132905')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 89r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132906')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 89v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132908')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 90r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132909')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 90v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132910')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 91r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132911')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 91v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132912')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 92r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132913')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 92v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132914')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 93r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132915')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 93v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132916')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 94r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132917')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 94v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132918')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 95r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132919')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 95v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132920')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 96r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132921')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 96v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132922')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 97r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132923')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 97v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132924')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 98r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132925')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 98v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132926')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 99r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132927')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 99v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132928')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 100r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132929')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 100v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132930')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 101r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132931')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 101v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132932')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 102r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132933')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 102v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132934')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 103r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132943')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 103v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132944')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 104r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132945')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 104v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132946')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 105r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132947')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 105v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132949')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 106r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132950')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 106v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132951')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 107r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132952')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 107v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132953')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 108r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132954')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 108v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132955')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 109r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132956')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 109v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132957')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 110r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132958')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 110v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132959')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 111r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132960')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 111v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132961')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 112r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132962')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 112v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132963')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 113r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132964')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 113v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132965')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 114r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132966')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 114v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132967')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 115r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6132968')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 115v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134667')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 116r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134668')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 116v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134669')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 117r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134670')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 117v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134671')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 118r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134672')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 118v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134673')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 119r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134674')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 119v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134676')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 120r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134677')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 120v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134678')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 121r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134679')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 121v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134681')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 122r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134682')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 122v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134683')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 123r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134690')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 123v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134691')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 124r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134692')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 124v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134693')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 125r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134694')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 125v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134695')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 126r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134696')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 126v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134697')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 127r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134698')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 127v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134699')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 128r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134700')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 128v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134701')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 129r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134702')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 129v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134703')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 130r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134704')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 130v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134705')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 131r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134706')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 131v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134707')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 132r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134708')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 132v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134709')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 133r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134710')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 133v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134712')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 134r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134713')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 134v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134714')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 135r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134715')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 135v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134716')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 136r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134717')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 136v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134718')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 137r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134719')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 137v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134720')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 138r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134721')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 138v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134722')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 139r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134723')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 139v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134724')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 140r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134725')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 140v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134726')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 141r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134727')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 141v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134728')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 142r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134733')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 142v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134734')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 143r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134735')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 143v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134736')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 144r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134743')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 144v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134744')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 145r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134745')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 145v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134746')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 146r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134747')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 146v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134748')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 147r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134750')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 147v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134751')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 148r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134752')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 148v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134753')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 149r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134754')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 149v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134774')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 150r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134817')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 150v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134818')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 151r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134819')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 151v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134820')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 152r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134821')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 152v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134822')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 153r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134823')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 153v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134824')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 154r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134825')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 154v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134827')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 155r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134828')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 155v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134829')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 156r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134830')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 156v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134831')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 157r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134832')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 157v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134833')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 158r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134834')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 158v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134835')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 159r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134839')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 159v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134841')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 160r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134842')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 160v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134843')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 161r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134844')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 161v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134846')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 162r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134847')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 162v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134848')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 163r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134849')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 163v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134850')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 164r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134851')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 164v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134852')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 165r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134853')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 165v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134854')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 166r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134855')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 166v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134856')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 167r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134857')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 167v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134858')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 168r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134859')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 168v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134860')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 169r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134861')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 169v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134862')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 170r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134863')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 170v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134864')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 171r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134865')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 171v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134866')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 172r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134867')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 172v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134868')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 173r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134869')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 173v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134870')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 174r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134871')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 174v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134872')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 175r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134873')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 175v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134874')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 176r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134875')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 176v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134876')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 177r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134877')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 177v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134878')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 178r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134879')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 178v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134880')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 179r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134881')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 179v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134882')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 180r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134883')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 180v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134884')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 181r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134885')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 181v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134886')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 182r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134887')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 182v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134888')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 183r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134889')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 183v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134890')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 184r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134891')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 184v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134892')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 185r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134899')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 185v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134900')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 186r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134901')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 186v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134902')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 187r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134903')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 187v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134904')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 188r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134905')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 188v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134909')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 189r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134910')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 189v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134911')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 190r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134912')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 190v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134913')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 191r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134914')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 191v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134915')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 192r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134916')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 192v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134917')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 193r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134919')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 193v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134920')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 194r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134921')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 194v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134922')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 195r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134923')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 195v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134924')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 196r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134925')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 196v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134926')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 197r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134927')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 197v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134928')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 198r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134929')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 198v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134930')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 199r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134931')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 199v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134932')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 200r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134933')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 200v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134934')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 201r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134935')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 201v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134936')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 202r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134937')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 202v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134938')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 203r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134939')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 203v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134940')"/>
                                                </xsl:when><!--<xsl:when test="@n = 'fol. 203'r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134941')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 203'v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134942')"/>
                                                </xsl:when>--><xsl:when test="@n = 'fol. 204r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134943')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 204v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134944')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 205r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134945')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 205v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134946')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 206r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134947')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 206v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134948')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 207r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134949')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 207v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134953')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 208r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134955')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 208v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134956')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 209r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134957')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 209v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134958')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 210r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134959')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 210v'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134960')"/>
                                                </xsl:when><xsl:when test="@n = 'fol. 211r'">                                                    
                                                    <xsl:value-of select="concat($bookurl,'/pageview/6134961')"/>
                                                </xsl:when>
                                            </xsl:choose>     
                                        </xsl:attribute>
                                        <xsl:value-of select="@n"/>
                                    </a>
                                </xsl:when>
                                <xsl:when test="$witid eq 'heidelberg' and not(//witness[@xml:id = $witid]/ptr)">
                                    <xsl:variable name="bookurl">https://doi.org/10.11588/diglit.302</xsl:variable>                                    
                                    <a>
                                        <xsl:attribute name="href">
                                            <xsl:choose>
                                                <xsl:when test="ends-with(@n, 'r')">
                                                    <xsl:variable name="imgid" select="concat('0', 2 * number(substring-after(substring-before(@n, 'r'),'fol. ')) + 3)"/>
                                                    <xsl:value-of select="concat($bookurl,'#',$imgid)"/>
                                                </xsl:when>
                                                <xsl:when test="ends-with(@n, 'v')">
                                                    <xsl:variable name="imgid" select="concat('0',2 * number(substring-after(substring-before(@n, 'v'),'fol. ')) + 4)"/>
                                                    <xsl:value-of select="concat($bookurl,'#',$imgid)"/>
                                                </xsl:when>
                                            </xsl:choose>                                            
                                        </xsl:attribute>
                                        <xsl:value-of select="@n"/>
                                    </a>
                                </xsl:when>
                                <xsl:when test="$witid eq 'berlin'">
                                    <xsl:variable name="bookurl" select="concat(//witness[@xml:id = $witid]/ptr/@target,'&amp;PHYSID=PHYS_')"/>
                                    <a>
                                        <xsl:attribute name="href">
                                            <xsl:choose>
                                                <xsl:when test="ends-with(@n, 'r')">
                                                    <xsl:variable name="imgid" select="format-number(2 * number(substring-after(substring-before(@n, 'r'),'fol. ')) + 3,'0000')"/>                                                    
                                                    <xsl:value-of select="concat($bookurl,$imgid)"/>
                                                </xsl:when>
                                                <xsl:when test="ends-with(@n, 'v')">
                                                    <xsl:variable name="imgid" select="format-number(2 * number(substring-after(substring-before(@n, 'v'),'fol. ')) + 4,'0000')"/>
                                                    <xsl:value-of select="concat($bookurl,$imgid)"/>
                                                </xsl:when>
                                            </xsl:choose>                                            
                                        </xsl:attribute>
                                        <xsl:value-of select="@n"/>
                                    </a>
                                </xsl:when>
                                <xsl:when test="$witid eq 'kopenhagen'">
                                    <xsl:variable name="bookurl" select="concat(//witness[@xml:id = $witid]/ptr/@target,'=page:')"/>
                                    <xsl:choose>
                                        <xsl:when test="matches(substring-after(@n,'fol. '), '(^58v$|^59r$)')"> <!-- fehlen im Online-Digitalisat -->
                                            <xsl:value-of select="@n"/>
                                        </xsl:when> 
                                        <xsl:otherwise>
                                            <a>
                                                <xsl:attribute name="href">
                                                    <xsl:choose>
                                                        <xsl:when test="ends-with(@n, 'r') and number(substring-after(substring-before(@n, 'r'),'fol. ')) &lt; 60">                                                    
                                                            <xsl:variable name="imgid" select="number(substring-after(substring-before(@n, 'r'),'fol. ')) + 1"/>                                                    
                                                            <xsl:value-of select="concat($bookurl,$imgid)"/>
                                                        </xsl:when>
                                                        <xsl:when test="ends-with(@n, 'r') and number(substring-after(substring-before(@n, 'r'),'fol. ')) &gt; 59">                                                    
                                                            <xsl:variable name="imgid" select="number(substring-after(substring-before(@n, 'r'),'fol. '))"/>                                                    
                                                            <xsl:value-of select="concat($bookurl,$imgid)"/>
                                                        </xsl:when>
                                                        <xsl:when test="ends-with(@n, 'v') and number(substring-after(substring-before(@n, 'v'),'fol. ')) &lt; 59">
                                                            <xsl:variable name="imgid" select="number(substring-after(substring-before(@n, 'v'),'fol. ')) + 2"/>
                                                            <xsl:value-of select="concat($bookurl,$imgid)"/>
                                                        </xsl:when>
                                                        <xsl:when test="ends-with(@n, 'v') and number(substring-after(substring-before(@n, 'v'),'fol. ')) &gt; 58">
                                                            <xsl:variable name="imgid" select="number(substring-after(substring-before(@n, 'v'),'fol. ')) + 1"/>
                                                            <xsl:value-of select="concat($bookurl,$imgid)"/>
                                                        </xsl:when>
                                                    </xsl:choose>                                            
                                                </xsl:attribute>
                                                <xsl:value-of select="@n"/>
                                            </a>
                                        </xsl:otherwise>
                                    </xsl:choose>                                    
                                </xsl:when>
                                <xsl:when test="$witid eq 'muenchen_bsb'">
                                    <xsl:variable name="bookurl" select="concat(//witness[@xml:id = $witid]/ptr/@target,'?page=')"/>
                                    <a>
                                        <xsl:attribute name="href">
                                            <xsl:choose>
                                                <xsl:when test="ends-with(@n, 'r')">
                                                    <xsl:variable name="imgid" select="2 * number(substring-after(substring-before(@n, 'r'),'fol. ')) + 15"/>                                                    
                                                    <xsl:value-of select="concat($bookurl,$imgid)"/>
                                                </xsl:when>
                                                <xsl:when test="ends-with(@n, 'v')">
                                                    <xsl:variable name="imgid" select="2 * number(substring-after(substring-before(@n, 'v'),'fol. ')) + 16"/>
                                                    <xsl:value-of select="concat($bookurl,$imgid)"/>
                                                </xsl:when>
                                            </xsl:choose>                                            
                                        </xsl:attribute>
                                        <xsl:value-of select="@n"/>
                                    </a>
                                </xsl:when>                                
                                <xsl:when test="$witid eq 'greifswald'">
                                    <xsl:variable name="bookurl" select="substring-before(//witness[@xml:id = $witid]/ptr/@target,'/facsimile.xml')"/>
                                    <a>
                                        <xsl:attribute name="href">
                                            <xsl:variable name="witpagenum" select="substring-after(@n, 'fol. ')"/>
                                            <xsl:variable name="imgid" select="substring-before(tokenize(document(//witness[@xml:id = $witid]/ptr/@target)/facsimile/graphic[starts-with(@n, $witpagenum) or ends-with(@n, concat(' / ',$witpagenum))]/@url,'/')[last()],'.jpg')"/>
                                            <xsl:value-of select="concat($bookurl,'/start.htm?image=',$imgid)"/>
                                        </xsl:attribute>                                            
                                        <xsl:value-of select="@n"/>
                                    </a>
                                </xsl:when>                                
                                <xsl:when test="//witness[@xml:id = $witid]/ptr">
                                    <xsl:variable name="bookurl" select="substring-before(//witness[@xml:id = $witid]/ptr/@target,'/facsimile.xml')"/>
                                    
                                    <xsl:choose>
                                        <xsl:when test="not(contains(@n,'-'))">
                                            <xsl:variable name="witpagenum" select="@n"/>                                    
                                            <xsl:variable name="imgid" select="substring-before(tokenize(document(//witness[@xml:id = $witid]/ptr/@target)/facsimile/graphic[@n eq substring-after($witpagenum,' ')]/@url,'/')[last()],'.jpg')"/>
                                            <a>
                                                <xsl:attribute name="href">
                                                    <xsl:value-of select="concat($bookurl,'/start.htm?image=',$imgid)"/>
                                                </xsl:attribute>
                                                <xsl:value-of select="@n"/>
                                            </a>
                                        </xsl:when>
                                        <xsl:when test="contains(@n,'-')">
                                            <xsl:variable name="witpagenum" select="substring-before(@n,'-')"/>                                    
                                            <xsl:variable name="imgid" select="substring-before(tokenize(document(//witness[@xml:id = $witid]/ptr/@target)/facsimile/graphic[@n eq substring-after($witpagenum,' ')]/@url,'/')[last()],'.jpg')"/>
                                            <a>
                                                <xsl:attribute name="href">
                                                    <xsl:value-of select="concat($bookurl,'/start.htm?image=',$imgid)"/>
                                                </xsl:attribute>
                                                <xsl:value-of select="@n"/>
                                            </a>
                                        </xsl:when>
                                    </xsl:choose>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="@n"/>
                                </xsl:otherwise>
                            </xsl:choose>                            
                            
                            <xsl:text>:</xsl:text>
                        </span>
                        <xsl:choose>
                            <xsl:when test=". = ''">
                                <span class="reading editorial">
                                    <xsl:text>[Zeichenfolge nicht vorhanden]</xsl:text>
                                </span>
                            </xsl:when>
                            <xsl:otherwise>
                                <span class="reading">
                                    <xsl:apply-templates select="." mode="step3"/>
                                </span>
                            </xsl:otherwise>
                        </xsl:choose>
                    </span>
                </xsl:for-each>
            </span>
        </span>
        
    </xsl:template>
    
    <xsl:template match="cb" mode="step3">
        <br xmlns="http://www.w3.org/1999/xhtml"/>
    </xsl:template>
    
    <xsl:template match="choice" mode="step3">
        <xsl:choose>
            <xsl:when test="sic and corr">
                <span xmlns="http://www.w3.org/1999/xhtml" class="tooltip">
                    <xsl:value-of select="normalize-space(corr)"/>
                    <span class="custom help">
                        <xsl:choose>
                            <xsl:when test="sic ne ''">
                                <span class="editorial">im Original: </span>
                                <xsl:value-of select="normalize-space(sic)"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <span class="editorial">fehlt im Original</span>
                            </xsl:otherwise>
                        </xsl:choose>                        
                    </span>
                </span>
            </xsl:when>
            <xsl:when test="abbr and expan">
                <span xmlns="http://www.w3.org/1999/xhtml" class="tooltip">
                    <xsl:choose>
                        <xsl:when test="abbr/g">
                            <xsl:apply-templates select="abbr/node()" mode="step3"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="abbr"/>
                        </xsl:otherwise>
                    </xsl:choose>
                    <span class="custom help">
                        <xsl:value-of select="expan"/>
                    </span>
                </span>
            </xsl:when>
            <xsl:when test="orig and reg">
                <xsl:apply-templates mode="step3"/>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="date" mode="step3">
        <span xmlns="http://www.w3.org/1999/xhtml" class="tooltip">
            <xsl:apply-templates mode="step3"/>
            <span class="custom help">
                <xsl:choose>
                    <xsl:when test="@when-custom">
                        <xsl:value-of select="@when-custom"/>
                    </xsl:when>
                    <xsl:when test="@notBefore-custom and @notAfter-custom">
                        <xsl:text>zwischen </xsl:text>
                        <xsl:value-of select="@notBefore-custom"/>
                        <xsl:text> und </xsl:text>
                        <xsl:value-of select="@notAfter-custom"/>
                    </xsl:when>
                </xsl:choose>
                <xsl:choose>
                    <xsl:when test="@datingMethod = '#julian'">
                        <span class="calsuffix">jul.</span>
                    </xsl:when>
                    <xsl:when test="@datingMethod = '#gregorian'">
                        <span class="calsuffix">greg.</span>
                    </xsl:when>
                </xsl:choose>
            </span>
        </span>
    </xsl:template>
    
    <xsl:template match="del" mode="step3">
        <span xmlns="http://www.w3.org/1999/xhtml" class="strikethrough">
            <xsl:apply-templates mode="step3"/>
        </span>
    </xsl:template>
    
    <xsl:template match="g" mode="step3">
        <xsl:variable name="charid" select="substring-after(@ref, '#')"/>
        <img xmlns="http://www.w3.org/1999/xhtml">
            <xsl:attribute name="alt" select="/TEI/teiHeader/encodingDesc/charDecl/char[@xml:id = $charid]/note"/>
            <xsl:attribute name="src" select="concat($imgpath2, substring-after(/TEI/teiHeader/encodingDesc/charDecl/char[@xml:id = $charid]/figure/graphic/@url,':'))"/>
            <xsl:attribute name="class" select="$charid"/>
        </img>
    </xsl:template>
    
    <xsl:template match="gap" mode="step3">
        <xsl:text>[...]</xsl:text>
    </xsl:template>
    
    <xsl:template match="ref[@target]" mode="step3">
        <xsl:choose>
            <xsl:when test="matches(@target, '^lit')">
                <a xmlns="http://www.w3.org/1999/xhtml">
                    <xsl:attribute name="href">
                        <xsl:value-of select="concat($litpath, substring-after(@target, ':'), '.xhtml')"/>
                    </xsl:attribute>
                    <xsl:apply-templates mode="step3"/>
                </a>
            </xsl:when>
            <xsl:when test="matches(@target, '^http')">
                <a xmlns="http://www.w3.org/1999/xhtml">
                    <xsl:attribute name="href">
                        <xsl:value-of select="@target"/>
                    </xsl:attribute>
                    <xsl:apply-templates mode="step3"/>
                </a>
            </xsl:when>
            <xsl:otherwise>
                <xsl:apply-templates mode="step3"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="ref[@cRef]" mode="step3"> <!-- vgl. http://diglib.hab.de/rules/documentation/quoting_biblical.xml -->
        <xsl:apply-templates mode="step3"/>
        <a xmlns="http://www.w3.org/1999/xhtml">
            <xsl:attribute name="href">
                <xsl:value-of select="$cRef-biblical-start"/>
                <xsl:value-of select="translate(@cRef,' ._,','+++:')"/>
                <xsl:value-of select="$cRef-biblical-end"/>
            </xsl:attribute>    
            <span class="extlinkarrow">↗</span>
        </a>
    </xsl:template>
    
    <xsl:template match="rs" mode="step3">       
        <a xmlns="http://www.w3.org/1999/xhtml">
            <xsl:attribute name="href">
                <xsl:choose>
                    <xsl:when test="matches(@ref, '^psn')">
                        <xsl:value-of select="concat($psnpath, substring-after(@ref, ':'), '.xhtml')"/>
                    </xsl:when>
                    <xsl:when test="matches(@ref, '^plc')">
                        <xsl:value-of select="concat($plcpath, substring-after(@ref, ':'), '.xhtml')"/>
                    </xsl:when>
                    <xsl:when test="matches(@ref, '^wrk')">
                        <xsl:value-of select="concat($wrkpath, substring-after(@ref, ':'), '.xhtml')"/>
                    </xsl:when>
                    <xsl:when test="matches(@ref, '^org')">
                        <xsl:value-of select="concat($orgpath, substring-after(@ref, ':'), '.xhtml')"/>
                    </xsl:when>
                    <xsl:when test="matches(@ref, '^lit')">
                        <xsl:value-of select="concat($litpath, substring-after(@ref, ':'), '.xhtml')"/>
                    </xsl:when>
                </xsl:choose>
            </xsl:attribute>
            <xsl:apply-templates select="node()[not(self::rs)]" mode="step3"/>
        </a>              
    </xsl:template>
    
    <xsl:template match="seg" mode="step3">
        <xsl:choose>
            <xsl:when test="ends-with(@xml:lang, '-Latn')">
                <span xmlns="http://www.w3.org/1999/xhtml" class="latinletters">
                    <xsl:apply-templates mode="step3"/>
                </span>
            </xsl:when>
            <xsl:when test="not(ends-with(@xml:lang, '-Latn'))">
                <xsl:apply-templates mode="step3"/>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="sic[not(../name() = 'choice')]" mode="step3">
        <xsl:apply-templates mode="step3"/>
        <xsl:text> [!]</xsl:text>
    </xsl:template>
    
    <xsl:template match="unclear" mode="step3">
        <xsl:apply-templates mode="step3"/>
        <xsl:text> [?]</xsl:text>
    </xsl:template>
    
    <xsl:template match="table" mode="step3">
        <table xmlns="http://www.w3.org/1999/xhtml">
            <xsl:apply-templates mode="step3"/>
        </table>
    </xsl:template>
    
    <xsl:template match="row" mode="step3">
        <tr xmlns="http://www.w3.org/1999/xhtml">
            <xsl:apply-templates mode="step3"/>
        </tr>
    </xsl:template>
    
    <xsl:template match="cell" mode="step3">
        <td xmlns="http://www.w3.org/1999/xhtml">
            <xsl:if test="@rows">
                <xsl:attribute name="rowspan">
                    <xsl:value-of select="@rows"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="@cols">
                <xsl:attribute name="colspan">
                    <xsl:value-of select="@cols"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:apply-templates mode="step3"/>
        </td>
    </xsl:template>
    
    <!-- entfernt Leerzeichen vor <note>/Fussnotenzeichen: -->
    <xsl:template match="text()[following-sibling::*[1][self::note]]" mode="step3">
        <xsl:sequence select="replace(., '\s$', '')"/>
    </xsl:template>
    
    <!-- ************************************** step 4 (Aufsplitten von geschachtelten Links/Tooltips): ********************************************* -->
    
    <xsl:template match="@*|node()" mode="step4">
        <xsl:copy>
            <xsl:apply-templates select="@*|node()" mode="step4"/>
        </xsl:copy>
    </xsl:template>
    <xsl:template match="xhtml:a[descendant::xhtml:a]" mode="step4">
        <xsl:apply-templates mode="step4"/>
    </xsl:template>
    <xsl:template match="xhtml:a[descendant::xhtml:a]/text()[matches(.,'\S')]" mode="step4">       
        <a xmlns="http://www.w3.org/1999/xhtml">
            <xsl:attribute name="href" select="../@href"/>
            <xsl:value-of select="."/>
        </a>        
    </xsl:template>
    
    <xsl:template match="xhtml:span[@class='tooltip'][descendant::xhtml:span[@class='tooltip']]" mode="step4">
        <xsl:apply-templates mode="step4"/>
    </xsl:template>
    <xsl:template match="xhtml:span[@class='tooltip'][descendant::xhtml:span[@class='tooltip']]/xhtml:span[@class='custom help']" mode="step4"/>
    <xsl:template match="xhtml:span[@class='tooltip'][descendant::xhtml:span[@class='tooltip']]/text()[matches(.,'\S')]" mode="step4">       
        <span xmlns="http://www.w3.org/1999/xhtml" class="tooltip">            
            <xsl:value-of select="."/>
            <xsl:copy-of select="../xhtml:span[@class='custom help']"/>
        </span>
    </xsl:template>
    <xsl:template match="xhtml:span[@class='tooltip'][descendant::xhtml:span[@class='tooltip']]/xhtml:span[@class ne 'custom help'][@class ne 'tooltip']/text()[matches(.,'\S')]" mode="step4">        <!-- z.B. <span class="latinletters"> -->
        <span xmlns="http://www.w3.org/1999/xhtml" class="tooltip">            
            <xsl:value-of select="."/>
            <xsl:copy-of select="../../xhtml:span[@class='custom help']"/>
        </span>
    </xsl:template>
    <xsl:template match="xhtml:span[@class='tooltip'][descendant::xhtml:span[@class='tooltip']]/xhtml:span[@class ne 'custom help'][@class ne 'tooltip']/xhtml:span[@class ne 'custom help'][@class ne 'tooltip']/text()[matches(.,'\S')]" mode="step4"> <!-- z.B. <span class="latinletters">A<span class="expansion">nn</span>o</span> -->       
        <span xmlns="http://www.w3.org/1999/xhtml" class="tooltip">            
            <xsl:value-of select="."/>
            <xsl:copy-of select="../../../xhtml:span[@class='custom help']"/>
        </span>
    </xsl:template>
    
</xsl:stylesheet>