<?xml version="1.0" encoding="UTF-8"?>
<!-- Dieses Stylesheet erzeugt aus der TEI/XML-Datei der Bibliographie eine einzelne XHTML-Datei für jeden Eintrag.
Für die Links zu den Registern werden die Vorzugsbenennungen der Registereinträge aus den Registern extrahiert. -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:tei="http://www.tei-c.org/ns/1.0" xmlns:xhtml="http://www.w3.org/1999/xhtml" exclude-result-prefixes="tei xhtml xs" version="2.0">
    <xsl:output method="xhtml" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" indent="yes"/>
    
    <!-- Hier die Dateipfade angeben: -->
    <xsl:variable name="transcrpath">../</xsl:variable>    
    <xsl:variable name="wrkpath">../wrk/</xsl:variable>
    <xsl:variable name="psnpath">../psn/</xsl:variable>
    <xsl:variable name="plcpath">../plc/</xsl:variable>
    <xsl:variable name="orgpath">../org/</xsl:variable>
    
    <xsl:template match="/">
        <xsl:apply-templates select="tei:TEI/tei:text/tei:body/tei:listBibl"/>
    </xsl:template>
    
    <xsl:template match="tei:listBibl">
        <xsl:apply-templates select="tei:bibl"/>            
    </xsl:template>
    
    <xsl:template match="tei:bibl">
        <xsl:variable name="unsorted">
            <html xmlns="http://www.w3.org/1999/xhtml">
                <head>
                    <link rel="stylesheet" type="text/css" href="lit-output.css"/>
                    <title>Bibliographie – <xsl:value-of select="concat(substring(tei:seg, 1, 30), '...')"/></title>
                </head>
                <body>
                    <xsl:attribute name="id" select="@xml:id"/>                        
                    <div class="bibldesc">
                        <p>
                            <xsl:value-of select="tei:seg"/>
                        </p>
                    </div>  
                   <xsl:if test=".//tei:ptr"> <div class="links">
                        <ul>
                            <xsl:if test="tei:seg/tei:ptr">                                
                                <li class="collection">
                                    <a class="collectionlink">
                                        <xsl:attribute name="href">
                                            <xsl:value-of select="concat(substring-after(tei:seg/tei:ptr/@target, '#'), '.xhtml')"/>
                                        </xsl:attribute>
                                        <xsl:text>zum übergeordneten Werk</xsl:text>
                                    </a>
                                </li>
                            </xsl:if>
                            
                            <xsl:for-each select="tei:ptr[@type = 'fulltext']">
                                <li class="fulltext">
                                    <a class="fulltextlink">
                                        <xsl:attribute name="href">
                                            <xsl:value-of select="./@target"/>
                                        </xsl:attribute>
                                        <xsl:text>Volltext</xsl:text>
                                    </a>
                                </li>
                            </xsl:for-each>
                            <xsl:if test="tei:ptr[@type = 'opac']">
                                <li class="opac">
                                    <a class="opaclink">
                                        <xsl:attribute name="href">
                                            <xsl:value-of select="concat('http://opac.lbs-braunschweig.gbv.de/DB=2/XMLPRS=N/PPN?PPN=', tei:ptr[@type = 'opac']/@cRef)"/>
                                        </xsl:attribute>
                                        <xsl:text>Katalogisat im OPAC der HAB</xsl:text>
                                    </a>
                                </li>
                            </xsl:if>
                            <xsl:if test="tei:ptr[@type = 'gbv']">
                                <li class="gbv">
                                    <a class="gbvlink">
                                        <xsl:attribute name="href">
                                            <xsl:value-of select="concat('https://kxp.k10plus.de/DB=2.1/PPNSET?PPN=', tei:ptr[@type = 'gbv']/@cRef)"/>
                                        </xsl:attribute>
                                        <xsl:text>Katalogisat im Gemeinsamen Verbundkatalog (GVK)</xsl:text>
                                    </a>
                                </li>
                            </xsl:if>
                            <xsl:if test="tei:ptr[@type = 'bvb']">
                                <li class="bvb">
                                    <a class="bvblink">
                                        <xsl:attribute name="href">
                                            <xsl:value-of select="concat('https://gateway-bayern.de/', tei:ptr[@type = 'bvb']/@cRef)"/>
                                        </xsl:attribute>
                                        <xsl:text>Katalogisat in Gateway Bayern</xsl:text>
                                    </a>
                                </li>
                            </xsl:if>
                        </ul>
                    </div>
                   </xsl:if>
                    <xsl:variable name="xmlid" select="@xml:id"/>
                    <xsl:if test="(document('../Register/bibliography/bibliography-a.xml')|document('../Register/bibliography/bibliography-b.xml')|document('../Register/bibliography/bibliography-c.xml')|document('../Register/bibliography/bibliography-d.xml')|document('../Register/bibliography/bibliography-e.xml')|document('../Register/bibliography/bibliography-f.xml')|document('../Register/bibliography/bibliography-g.xml')|document('../Register/bibliography/bibliography-h.xml')|document('../Register/bibliography/bibliography-i.xml')|document('../Register/bibliography/bibliography-j.xml')|document('../Register/bibliography/bibliography-k.xml')|document('../Register/bibliography/bibliography-l.xml')|document('../Register/bibliography/bibliography-m.xml')|document('../Register/bibliography/bibliography-n.xml')|document('../Register/bibliography/bibliography-o.xml')|document('../Register/bibliography/bibliography-p.xml')|document('../Register/bibliography/bibliography-qr.xml')|document('../Register/bibliography/bibliography-s.xml')|document('../Register/bibliography/bibliography-t.xml')|document('../Register/bibliography/bibliography-u.xml')|document('../Register/bibliography/bibliography-v.xml')|document('../Register/bibliography/bibliography-w.xml')|document('../Register/bibliography/bibliography-xyz.xml'))//tei:ptr[@type = 'isPartOf'][substring-after(@target,'#') = $xmlid]">
                        <div class="contains">
                            <h2 class="containshead">Enthält</h2>
                            <ul>
                                <xsl:variable name="xmlid" select="@xml:id"/>
                                <xsl:for-each select="(document('../Register/bibliography/bibliography-a.xml')|document('../Register/bibliography/bibliography-b.xml')|document('../Register/bibliography/bibliography-c.xml')|document('../Register/bibliography/bibliography-d.xml')|document('../Register/bibliography/bibliography-e.xml')|document('../Register/bibliography/bibliography-f.xml')|document('../Register/bibliography/bibliography-g.xml')|document('../Register/bibliography/bibliography-h.xml')|document('../Register/bibliography/bibliography-i.xml')|document('../Register/bibliography/bibliography-j.xml')|document('../Register/bibliography/bibliography-k.xml')|document('../Register/bibliography/bibliography-l.xml')|document('../Register/bibliography/bibliography-m.xml')|document('../Register/bibliography/bibliography-n.xml')|document('../Register/bibliography/bibliography-o.xml')|document('../Register/bibliography/bibliography-p.xml')|document('../Register/bibliography/bibliography-qr.xml')|document('../Register/bibliography/bibliography-s.xml')|document('../Register/bibliography/bibliography-t.xml')|document('../Register/bibliography/bibliography-u.xml')|document('../Register/bibliography/bibliography-v.xml')|document('../Register/bibliography/bibliography-w.xml')|document('../Register/bibliography/bibliography-xyz.xml'))//tei:ptr[@type = 'isPartOf'][substring-after(@target,'#') = $xmlid]">                                
                                    <li>
                                        <a>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="concat(../../@xml:id, '.xhtml')"/>
                                            </xsl:attribute>
                                            <xsl:value-of select="../."/>
                                        </a>
                                    </li>
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:if>                       
                    <xsl:if test="tei:linkGrp[not(@ana = 'http://purl.org/dc/elements/1.1/creator')]/tei:link/@target">
                        <div class="occurrences">
                            <h2 class="occurrenceshead">Verwendet/erwähnt in</h2> 
                            <ul>
                                <xsl:for-each select="tei:linkGrp[not(@ana = 'http://purl.org/dc/elements/1.1/creator')]/tei:link[@target]">                               
                                    <xsl:choose>                                    
                                        <xsl:when test="parent::tei:linkGrp[@ana = 'http://erlangen-crm.org/current/P70_documents']">                                
                                            <xsl:choose>
                                                <xsl:when test="contains(@target, ' psn:')">
                                                    <xsl:variable name="psnid" select="substring-after(@target, ' psn:')"/>
                                                    <li>
                                                        <xsl:text>Personenregister: </xsl:text>                                                    
                                                        <a>
                                                            <xsl:attribute name="href">
                                                                <xsl:value-of select="concat($psnpath, substring-after(@target, ' psn:'), '.xhtml')"/>
                                                            </xsl:attribute>
                                                            <xsl:value-of select="(document('../Register/register-person/register-person-a.xml')|document('../Register/register-person/register-person-b.xml')|document('../Register/register-person/register-person-c.xml')|document('../Register/register-person/register-person-d.xml')|document('../Register/register-person/register-person-e.xml')|document('../Register/register-person/register-person-f.xml')|document('../Register/register-person/register-person-g.xml')|document('../Register/register-person/register-person-h.xml')|document('../Register/register-person/register-person-i.xml')|document('../Register/register-person/register-person-j.xml')|document('../Register/register-person/register-person-k.xml')|document('../Register/register-person/register-person-l.xml')|document('../Register/register-person/register-person-m.xml')|document('../Register/register-person/register-person-n.xml')|document('../Register/register-person/register-person-o.xml')|document('../Register/register-person/register-person-p.xml')|document('../Register/register-person/register-person-qr.xml')|document('../Register/register-person/register-person-s.xml')|document('../Register/register-person/register-person-t.xml')|document('../Register/register-person/register-person-u.xml')|document('../Register/register-person/register-person-v.xml')|document('../Register/register-person/register-person-w.xml')|document('../Register/register-person/register-person-xyz.xml'))//*[@xml:id eq $psnid]/tei:persName[@type = 'preferred']/tei:term//*"/>
                                                        </a>
                                                    </li>
                                                </xsl:when>
                                                <xsl:when test="contains(@target, ' plc:')">
                                                    <xsl:variable name="plcid" select="substring-after(@target, ' plc:')"/>
                                                    <li>
                                                        <xsl:text>Ortsregister: </xsl:text>                                                    
                                                        <a>
                                                            <xsl:attribute name="href">
                                                                <xsl:value-of select="concat($plcpath, substring-after(@target, ' plc:'), '.xhtml')"/>
                                                            </xsl:attribute>                                                            
                                                            <xsl:if test="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link/@ana = 'http://erlangen-crm.org/current/P89_falls_within'">
                                                                <xsl:choose>
                                                                    <xsl:when test="contains((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target,' #')">
                                                                        <xsl:variable name="plcid" select="substring-after((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' #')"/>
                                                                        <xsl:if test="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link/@ana = 'http://erlangen-crm.org/current/P89_falls_within'">
                                                                            <xsl:choose>
                                                                                <xsl:when test="contains((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target,' #')">
                                                                                    <xsl:variable name="plcid" select="substring-after((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' #')"/>                                                                                    
                                                                                    <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                                                    <xsl:text>, </xsl:text>
                                                                                </xsl:when>
                                                                                <xsl:when test="contains((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target,' wrk:')">
                                                                                    <xsl:variable name="workid" select="substring-after((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' wrk:')"/>                                                                                    
                                                                                    <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term"/>
                                                                                    <xsl:text>, </xsl:text>
                                                                                </xsl:when>
                                                                            </xsl:choose>
                                                                        </xsl:if>
                                                                        <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                                        <xsl:text>, </xsl:text>
                                                                    </xsl:when>
                                                                    <xsl:when test="contains((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target,' wrk:')">
                                                                        <xsl:variable name="workid" select="substring-after((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' wrk:')"/>
                                                                        <xsl:if test="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link/@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location' and (document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:objectType[@n eq '1'][@ref eq '#architektur']">                                                                            
                                                                            <xsl:variable name="plcid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' plc:')"/>                                                                                    
                                                                            <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                                            <xsl:text>, </xsl:text>                                                                               
                                                                        </xsl:if>
                                                                        <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term"/>
                                                                        <xsl:text>, </xsl:text>
                                                                    </xsl:when>
                                                                </xsl:choose>
                                                            </xsl:if>                                                            
                                                            <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                        </a>
                                                    </li>
                                                </xsl:when>
                                                <xsl:when test="contains(@target, ' wrk:')">
                                                    <xsl:variable name="workid" select="substring-after(@target, ' wrk:')"/>
                                                    <li>
                                                        <xsl:text>Objektregister: </xsl:text>                                                    
                                                        <a>
                                                            <xsl:attribute name="href">
                                                                <xsl:value-of select="concat($wrkpath, substring-after(@target, ' wrk:'), '.xhtml')"/>
                                                            </xsl:attribute>
                                                            <xsl:if test="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link/@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location' and (document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:objectType[@n eq '1'][@ref eq '#architektur']">
                                                                <xsl:choose>
                                                                    <xsl:when test="contains((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target,' #')">
                                                                        <xsl:variable name="workid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' #')"/>
                                                                        <xsl:if test="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link/@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location'">
                                                                            <xsl:choose>
                                                                                <xsl:when test="contains((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target,' #')">
                                                                                    <xsl:variable name="workid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' #')"/>                                                                                    
                                                                                    <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term"/>
                                                                                    <xsl:text>, </xsl:text>
                                                                                </xsl:when>
                                                                                <xsl:when test="contains((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target,' plc:')">
                                                                                    <xsl:variable name="plcid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' plc:')"/>                                                                                    
                                                                                    <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                                                    <xsl:text>, </xsl:text>
                                                                                </xsl:when>
                                                                            </xsl:choose>
                                                                        </xsl:if>
                                                                        <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term"/>
                                                                        <xsl:text>, </xsl:text>
                                                                    </xsl:when>
                                                                    <xsl:when test="contains((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target,' plc:')">
                                                                        <xsl:variable name="plcid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' plc:')"/>
                                                                        <xsl:if test="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link/@ana = 'http://erlangen-crm.org/current/P89_falls_within'">                                                                            
                                                                            <xsl:variable name="plcid" select="substring-after((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' #')"/>                                                                                    
                                                                            <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                                            <xsl:text>, </xsl:text>                                                                               
                                                                        </xsl:if>
                                                                        <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                                        <xsl:text>, </xsl:text>
                                                                    </xsl:when>
                                                                </xsl:choose>
                                                            </xsl:if>
                                                            <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term"/>
                                                        </a>
                                                    </li>
                                                </xsl:when>
                                                <xsl:when test="contains(@target, ' org:')">
                                                    <xsl:variable name="orgid" select="substring-after(@target, ' org:')"/>
                                                    <li>
                                                        <xsl:text>Körperschaftsregister: </xsl:text>                                                    
                                                        <a>
                                                            <xsl:attribute name="href">
                                                                <xsl:value-of select="concat($orgpath, substring-after(@target, ' org:'), '.xhtml')"/>
                                                            </xsl:attribute>
                                                            <xsl:value-of select="(document('../Register/register-org/register-org-a.xml')|document('../Register/register-org/register-org-b.xml')|document('../Register/register-org/register-org-c.xml')|document('../Register/register-org/register-org-d.xml')|document('../Register/register-org/register-org-e.xml')|document('../Register/register-org/register-org-f.xml')|document('../Register/register-org/register-org-g.xml')|document('../Register/register-org/register-org-h.xml')|document('../Register/register-org/register-org-i.xml')|document('../Register/register-org/register-org-j.xml')|document('../Register/register-org/register-org-k.xml')|document('../Register/register-org/register-org-l.xml')|document('../Register/register-org/register-org-m.xml')|document('../Register/register-org/register-org-n.xml')|document('../Register/register-org/register-org-o.xml')|document('../Register/register-org/register-org-p.xml')|document('../Register/register-org/register-org-qr.xml')|document('../Register/register-org/register-org-s.xml')|document('../Register/register-org/register-org-t.xml')|document('../Register/register-org/register-org-u.xml')|document('../Register/register-org/register-org-v.xml')|document('../Register/register-org/register-org-w.xml')|document('../Register/register-org/register-org-xyz.xml'))//tei:org[@xml:id eq $orgid]/tei:orgName[@type = 'preferred']/tei:term"/>
                                                        </a>
                                                    </li>
                                                </xsl:when>
                                            </xsl:choose>
                                        </xsl:when>
                                        <xsl:when test="parent::tei:linkGrp[@ana = 'http://purl.org/dc/terms/references']">                     
                                            <xsl:choose>
                                                <xsl:when test="contains(@target, '/person[')">
                                                    <xsl:variable name="psnid" select="substring-before(substring-after(@target, '/person[@xml:id='''), ''']//')"/>
                                                    <xsl:if test="not(../../tei:linkGrp[@ana = 'http://erlangen-crm.org/current/P70_documents']/tei:link[substring-after(./@target, ' psn:') = $psnid])">
                                                        <li>
                                                            <xsl:text>Personenregister: </xsl:text>                                                        
                                                            <a>
                                                                <xsl:attribute name="href">
                                                                    <xsl:value-of select="concat($psnpath, $psnid, '.xhtml')"/>
                                                                </xsl:attribute>
                                                                <xsl:value-of select="(document('../Register/register-person/register-person-a.xml')|document('../Register/register-person/register-person-b.xml')|document('../Register/register-person/register-person-c.xml')|document('../Register/register-person/register-person-d.xml')|document('../Register/register-person/register-person-e.xml')|document('../Register/register-person/register-person-f.xml')|document('../Register/register-person/register-person-g.xml')|document('../Register/register-person/register-person-h.xml')|document('../Register/register-person/register-person-i.xml')|document('../Register/register-person/register-person-j.xml')|document('../Register/register-person/register-person-k.xml')|document('../Register/register-person/register-person-l.xml')|document('../Register/register-person/register-person-m.xml')|document('../Register/register-person/register-person-n.xml')|document('../Register/register-person/register-person-o.xml')|document('../Register/register-person/register-person-p.xml')|document('../Register/register-person/register-person-qr.xml')|document('../Register/register-person/register-person-s.xml')|document('../Register/register-person/register-person-t.xml')|document('../Register/register-person/register-person-u.xml')|document('../Register/register-person/register-person-v.xml')|document('../Register/register-person/register-person-w.xml')|document('../Register/register-person/register-person-xyz.xml'))//*[@xml:id eq $psnid]/tei:persName[@type = 'preferred']/tei:term"/>
                                                            </a>
                                                        </li>
                                                    </xsl:if>
                                                </xsl:when>
                                                <xsl:when test="contains(@target, '/personGrp[')">
                                                    <xsl:variable name="psnid" select="substring-before(substring-after(@target, '/personGrp[@xml:id='''), ''']//')"/>
                                                    <xsl:if test="not(../../tei:linkGrp[@ana = 'http://erlangen-crm.org/current/P70_documents']/tei:link[substring-after(./@target, ' psn:') = $psnid])">
                                                        <li>
                                                            <xsl:text>Personenregister: </xsl:text>                                                        
                                                            <a>
                                                                <xsl:attribute name="href">
                                                                    <xsl:value-of select="concat($psnpath, $psnid, '.xhtml')"/>
                                                                </xsl:attribute>
                                                                <xsl:value-of select="(document('../Register/register-person/register-person-a.xml')|document('../Register/register-person/register-person-b.xml')|document('../Register/register-person/register-person-c.xml')|document('../Register/register-person/register-person-d.xml')|document('../Register/register-person/register-person-e.xml')|document('../Register/register-person/register-person-f.xml')|document('../Register/register-person/register-person-g.xml')|document('../Register/register-person/register-person-h.xml')|document('../Register/register-person/register-person-i.xml')|document('../Register/register-person/register-person-j.xml')|document('../Register/register-person/register-person-k.xml')|document('../Register/register-person/register-person-l.xml')|document('../Register/register-person/register-person-m.xml')|document('../Register/register-person/register-person-n.xml')|document('../Register/register-person/register-person-o.xml')|document('../Register/register-person/register-person-p.xml')|document('../Register/register-person/register-person-qr.xml')|document('../Register/register-person/register-person-s.xml')|document('../Register/register-person/register-person-t.xml')|document('../Register/register-person/register-person-u.xml')|document('../Register/register-person/register-person-v.xml')|document('../Register/register-person/register-person-w.xml')|document('../Register/register-person/register-person-xyz.xml'))//*[@xml:id eq $psnid]/tei:persName[@type = 'preferred']/tei:term"/>
                                                            </a>
                                                        </li>
                                                    </xsl:if>
                                                </xsl:when>
                                                <xsl:when test="contains(@target, '/place[')">
                                                    <xsl:variable name="plcid" select="substring-before(substring-after(@target, '/place[@xml:id='''), ''']//')"/>
                                                    <xsl:if test="not(../../tei:linkGrp[@ana = 'http://erlangen-crm.org/current/P70_documents']/tei:link[substring-after(./@target, ' plc:') = $plcid])">
                                                        <li>
                                                            <xsl:text>Ortsregister: </xsl:text>                                                        
                                                            <a>
                                                                <xsl:attribute name="href">
                                                                    <xsl:value-of select="concat($plcpath, $plcid, '.xhtml')"/>
                                                                </xsl:attribute>
                                                                
                                                                <xsl:if test="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link/@ana = 'http://erlangen-crm.org/current/P89_falls_within'">
                                                                    <xsl:choose>
                                                                        <xsl:when test="contains((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target,' #')">
                                                                            <xsl:variable name="plcid" select="substring-after((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' #')"/>
                                                                            <xsl:if test="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link/@ana = 'http://erlangen-crm.org/current/P89_falls_within'">
                                                                                <xsl:choose>
                                                                                    <xsl:when test="contains((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target,' #')">
                                                                                        <xsl:variable name="plcid" select="substring-after((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' #')"/>                                                                                    
                                                                                        <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                                                        <xsl:text>, </xsl:text>
                                                                                    </xsl:when>
                                                                                    <xsl:when test="contains((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target,' wrk:')">
                                                                                        <xsl:variable name="workid" select="substring-after((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' wrk:')"/>                                                                                    
                                                                                        <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term"/>
                                                                                        <xsl:text>, </xsl:text>
                                                                                    </xsl:when>
                                                                                </xsl:choose>
                                                                            </xsl:if>
                                                                            <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                                            <xsl:text>, </xsl:text>
                                                                        </xsl:when>
                                                                        <xsl:when test="contains((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target,' wrk:')">
                                                                            <xsl:variable name="workid" select="substring-after((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' wrk:')"/>
                                                                            <xsl:if test="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link/@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location' and (document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:objectType[@n eq '1'][@ref eq '#architektur']">                                                                            
                                                                                <xsl:variable name="plcid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' plc:')"/>                                                                                    
                                                                                <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                                                <xsl:text>, </xsl:text>                                                                               
                                                                            </xsl:if>
                                                                            <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term"/>
                                                                            <xsl:text>, </xsl:text>
                                                                        </xsl:when>
                                                                    </xsl:choose>
                                                                </xsl:if>   
                                                                
                                                                <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                            </a>
                                                        </li>
                                                    </xsl:if>
                                                </xsl:when>
                                                <xsl:when test="contains(@target, '/item[')">
                                                    <xsl:variable name="workid" select="substring-before(substring-after(@target, '/item[@xml:id='''), ''']//')"/>
                                                    <xsl:if test="not(../../tei:linkGrp[@ana = 'http://erlangen-crm.org/current/P70_documents']/tei:link[substring-after(./@target, ' wrk:') = $workid])">
                                                        <li>
                                                            <xsl:text>Objektregister: </xsl:text>                                                        
                                                            <a>
                                                                <xsl:attribute name="href">
                                                                    <xsl:value-of select="concat($wrkpath, $workid, '.xhtml')"/>
                                                                </xsl:attribute>
                                                                
                                                                <xsl:if test="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link/@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location' and (document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:objectType[@n eq '1'][@ref eq '#architektur']">
                                                                    <xsl:choose>
                                                                        <xsl:when test="contains((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target,' #')">
                                                                            <xsl:variable name="workid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' #')"/>
                                                                            <xsl:if test="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link/@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location'">
                                                                                <xsl:choose>
                                                                                    <xsl:when test="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location'][contains(@target,' #')]">
                                                                                        <xsl:variable name="workid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' #')"/>                                                                                    
                                                                                        <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term"/>
                                                                                        <xsl:text>, </xsl:text>
                                                                                    </xsl:when>
                                                                                    <xsl:when test="contains((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target,' plc:')">
                                                                                        <xsl:variable name="plcid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' plc:')"/>                                                                                    
                                                                                        <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                                                        <xsl:text>, </xsl:text>
                                                                                    </xsl:when>
                                                                                </xsl:choose>
                                                                            </xsl:if>
                                                                            <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term"/>
                                                                            <xsl:text>, </xsl:text>
                                                                        </xsl:when>
                                                                        <xsl:when test="contains((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target,' plc:')">
                                                                            <xsl:variable name="plcid" select="substring-after((document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P53_has_former_or_current_location']/@target, ' plc:')"/>
                                                                            <xsl:if test="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link/@ana = 'http://erlangen-crm.org/current/P89_falls_within'">                                                                            
                                                                                <xsl:variable name="plcid" select="substring-after((document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:linkGrp/tei:link[@ana = 'http://erlangen-crm.org/current/P89_falls_within']/@target, ' #')"/>                                                                                    
                                                                                <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                                                <xsl:text>, </xsl:text>                                                                               
                                                                            </xsl:if>
                                                                            <xsl:value-of select="(document('../Register/register-place/register-place-a.xml')|document('../Register/register-place/register-place-b.xml')|document('../Register/register-place/register-place-c.xml')|document('../Register/register-place/register-place-d.xml')|document('../Register/register-place/register-place-e.xml')|document('../Register/register-place/register-place-f.xml')|document('../Register/register-place/register-place-g.xml')|document('../Register/register-place/register-place-h.xml')|document('../Register/register-place/register-place-i.xml')|document('../Register/register-place/register-place-j.xml')|document('../Register/register-place/register-place-k.xml')|document('../Register/register-place/register-place-l.xml')|document('../Register/register-place/register-place-m.xml')|document('../Register/register-place/register-place-n.xml')|document('../Register/register-place/register-place-o.xml')|document('../Register/register-place/register-place-p.xml')|document('../Register/register-place/register-place-qr.xml')|document('../Register/register-place/register-place-s.xml')|document('../Register/register-place/register-place-t.xml')|document('../Register/register-place/register-place-u.xml')|document('../Register/register-place/register-place-v.xml')|document('../Register/register-place/register-place-w.xml')|document('../Register/register-place/register-place-xyz.xml'))//tei:place[@xml:id eq $plcid]/tei:placeName[@type = 'preferred']/tei:term"/>
                                                                            <xsl:text>, </xsl:text>
                                                                        </xsl:when>
                                                                    </xsl:choose>
                                                                </xsl:if>
                                                                
                                                                <xsl:value-of select="(document('../Register/register-work/register-work-a.xml')|document('../Register/register-work/register-work-b.xml')|document('../Register/register-work/register-work-c.xml')|document('../Register/register-work/register-work-d.xml')|document('../Register/register-work/register-work-e.xml')|document('../Register/register-work/register-work-f.xml')|document('../Register/register-work/register-work-g.xml')|document('../Register/register-work/register-work-h.xml')|document('../Register/register-work/register-work-i.xml')|document('../Register/register-work/register-work-j.xml')|document('../Register/register-work/register-work-k.xml')|document('../Register/register-work/register-work-l.xml')|document('../Register/register-work/register-work-m.xml')|document('../Register/register-work/register-work-n.xml')|document('../Register/register-work/register-work-o.xml')|document('../Register/register-work/register-work-p.xml')|document('../Register/register-work/register-work-qr.xml')|document('../Register/register-work/register-work-s.xml')|document('../Register/register-work/register-work-t.xml')|document('../Register/register-work/register-work-u.xml')|document('../Register/register-work/register-work-v.xml')|document('../Register/register-work/register-work-w.xml')|document('../Register/register-work/register-work-xyz.xml'))//tei:item[@xml:id eq $workid]/tei:name[@type = 'preferred']/tei:term"/>
                                                            </a>
                                                        </li>
                                                    </xsl:if>
                                                </xsl:when>
                                                <xsl:when test="contains(@target, '/org[')">
                                                    <xsl:variable name="orgid" select="substring-before(substring-after(@target, '/org[@xml:id='''), ''']//')"/>
                                                    <xsl:if test="not(../../tei:linkGrp[@ana = 'http://erlangen-crm.org/current/P70_documents']/tei:link[substring-after(./@target, ' org:') = $orgid])">
                                                        <li>
                                                            <xsl:text>Körperschaftsregister: </xsl:text>                                                        
                                                            <a>
                                                                <xsl:attribute name="href">
                                                                    <xsl:value-of select="concat($orgpath, $orgid, '.xhtml')"/>
                                                                </xsl:attribute>
                                                                <xsl:value-of select="(document('../Register/register-org/register-org-a.xml')|document('../Register/register-org/register-org-b.xml')|document('../Register/register-org/register-org-c.xml')|document('../Register/register-org/register-org-d.xml')|document('../Register/register-org/register-org-e.xml')|document('../Register/register-org/register-org-f.xml')|document('../Register/register-org/register-org-g.xml')|document('../Register/register-org/register-org-h.xml')|document('../Register/register-org/register-org-i.xml')|document('../Register/register-org/register-org-j.xml')|document('../Register/register-org/register-org-k.xml')|document('../Register/register-org/register-org-l.xml')|document('../Register/register-org/register-org-m.xml')|document('../Register/register-org/register-org-n.xml')|document('../Register/register-org/register-org-o.xml')|document('../Register/register-org/register-org-p.xml')|document('../Register/register-org/register-org-qr.xml')|document('../Register/register-org/register-org-s.xml')|document('../Register/register-org/register-org-t.xml')|document('../Register/register-org/register-org-u.xml')|document('../Register/register-org/register-org-v.xml')|document('../Register/register-org/register-org-w.xml')|document('../Register/register-org/register-org-xyz.xml'))//tei:org[@xml:id eq $orgid]/tei:orgName[@type = 'preferred']/tei:term"/>
                                                            </a>
                                                        </li>
                                                    </xsl:if>
                                                </xsl:when>
                                                
                                                
                                                <xsl:when test="starts-with(@target,'transcr:')">
                                                    
                                                    <xsl:if test="not(preceding-sibling::tei:link[@target eq current()/@target])">
                                                        <xsl:variable name="pagenum" select="replace(substring-before(substring-after(@target,'pb[@n='''),''']/following'),'%20',' ')"/>
                                                    <li>
                                                        <xsl:text>Kommentar: </xsl:text>                                                    
                                                        <a>
                                                            <xsl:attribute name="href">
                                                                
                                                                <xsl:value-of select="concat($transcrpath, replace(replace(replace(replace(replace(substring-after(substring-before(lower-case(@target),'.xml'),'transcr:'),'%20',''),'ü','ue'),'ä','ae'),'ö','oe'),'–','_'), '.xhtml#fol', substring-after($pagenum,'fol. '))"/>                                                                                                                               
                                                            </xsl:attribute>
                                                            <xsl:value-of select="replace(substring-before(substring-after(@target,'transcr:'),'.xml'),'%20',' ')"/>
                                                            <xsl:text>, </xsl:text>
                                                            <xsl:value-of select="$pagenum"/>                                                            
                                                        </a>
                                                    </li>
                                                    </xsl:if>
                                                    
                                                </xsl:when>
                                                
                                                
                                            </xsl:choose>
                                        </xsl:when>
                                        
                                        <xsl:when test="parent::tei:linkGrp[@ana = 'http://schema.org/mentions']">
                                            <xsl:variable name="pagenum" select="substring-before(substring-after(@target, 'fol.%20'), ''']/following')"/>
                                            <li>
                                                
                                                <a>
                                                    <xsl:attribute name="href">
                                                        <xsl:value-of select="concat($transcrpath, replace(replace(replace(replace(replace(substring-after(substring-before(lower-case(@target),'.xml'),'transcr:'),'%20',''),'ü','ue'),'ä','ae'),'ö','oe'),'–','_'), '.xhtml#fol', $pagenum)"/>
                                                    </xsl:attribute>
                                                    <xsl:value-of select="replace(substring-after(substring-before(@target,'.xml'),'transcr:'),'%20',' ')"/>
                                                    <xsl:text>, fol. </xsl:text>
                                                    <xsl:value-of select="$pagenum"/>
                                                </a>
                                            </li>
                                        </xsl:when>
                                    </xsl:choose>
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:if>
                    <xsl:if test="tei:linkGrp[@ana = 'http://purl.org/dc/elements/1.1/creator']">
                        <div class="indexcreator">
                            <h2 class="indexcreatorhead">Verfasser im Personenregister:</h2>
                            <ul>
                                <xsl:for-each select="tei:linkGrp[@ana = 'http://purl.org/dc/elements/1.1/creator']/tei:link[@target]">
                                    <xsl:variable name="psnid" select="substring-after(@target, ' psn:')"/>
                                    <li>
                                        <a>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="concat($psnpath, $psnid, '.xhtml')"/>
                                            </xsl:attribute>
                                            <xsl:value-of select="(document('../Register/register-person/register-person-a.xml')|document('../Register/register-person/register-person-b.xml')|document('../Register/register-person/register-person-c.xml')|document('../Register/register-person/register-person-d.xml')|document('../Register/register-person/register-person-e.xml')|document('../Register/register-person/register-person-f.xml')|document('../Register/register-person/register-person-g.xml')|document('../Register/register-person/register-person-h.xml')|document('../Register/register-person/register-person-i.xml')|document('../Register/register-person/register-person-j.xml')|document('../Register/register-person/register-person-k.xml')|document('../Register/register-person/register-person-l.xml')|document('../Register/register-person/register-person-m.xml')|document('../Register/register-person/register-person-n.xml')|document('../Register/register-person/register-person-o.xml')|document('../Register/register-person/register-person-p.xml')|document('../Register/register-person/register-person-qr.xml')|document('../Register/register-person/register-person-s.xml')|document('../Register/register-person/register-person-t.xml')|document('../Register/register-person/register-person-u.xml')|document('../Register/register-person/register-person-v.xml')|document('../Register/register-person/register-person-w.xml')|document('../Register/register-person/register-person-xyz.xml'))//tei:person[@xml:id eq $psnid]/tei:persName[@type = 'preferred']/tei:term/*"/>
                                        </a>
                                    </li>
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:if>                        
                </body>
            </html>
        </xsl:variable>
        <xsl:call-template name="sort">
            <xsl:with-param name="unsorted" select="$unsorted"/>
        </xsl:call-template>
    </xsl:template>
    
    <xsl:template name="sort">
        <xsl:param name="unsorted"/>                
        
        <xsl:variable name="outputpath" select="concat('../../HTML-Dateien/lit/',$unsorted/xhtml:html/xhtml:body/@id,'.xhtml')"/>
        
        <xsl:result-document href="{$outputpath}">
            <html xmlns="http://www.w3.org/1999/xhtml">                
                <xsl:copy-of select="$unsorted/xhtml:html/xhtml:head"/>
                <body>                   
                    <xsl:apply-templates select="$unsorted/xhtml:html/xhtml:body/xhtml:div" mode="sort">
                        <xsl:with-param name="unsorted" select="$unsorted"/>
                    </xsl:apply-templates>                                       
                </body>
            </html>
        </xsl:result-document>
    </xsl:template>
    
    <xsl:template match="xhtml:body/xhtml:div[@class ne 'occurrences']" mode="sort">        
        <xsl:param name="unsorted"/>        
        <xsl:copy-of select="."/>
    </xsl:template>
    
    <xsl:template match="xhtml:div[@class='occurrences']" mode="sort">
        <xsl:param name="unsorted"/>
        <xsl:copy>
            <xsl:copy-of select="@*"/>
            <xsl:copy-of select="xhtml:h2"/>
            <ul xmlns="http://www.w3.org/1999/xhtml">
                <xsl:for-each select="xhtml:ul/xhtml:li">
                    <xsl:sort select="substring-before(.,': ')"/>
                    <xsl:sort select="substring-before(.,', fol. ')"/>
                    <xsl:sort select="replace(.,'.*fol\.\s([0-9]+).*','$1')" data-type="number"/>
                    <xsl:sort select="replace(replace(replace(lower-case(translate(xhtml:a, '()', '')), 'ä', 'ae'), 'ö', 'oe'), 'ü', 'ue')" lang="de"/>
                    <xsl:copy-of select="."/>
                </xsl:for-each>
            </ul>
        </xsl:copy>
    </xsl:template>
    
</xsl:stylesheet>
